@@ -62,33 +62,24 @@
     )
   )
 
-(define lw6-config-map-rules-defaults
-  (lambda ()
-    (map (lambda (key) (lw6-config-set-number! key (c-lw6map-rules-get-default key))) (c-lw6hlp-list-map-rules))    
-      ))
-
-(define lw6-config-map-hints-defaults
-  (lambda ()
-    (map (lambda (key) (lw6-config-set-string! key (c-lw6ldr-hints-get-default key))) (c-lw6hlp-list-map-hints))    
-      ))
-
-(define lw6-config-map-style-defaults
-  (lambda ()
-    (map (lambda (key) (lw6-config-set-string! key (c-lw6map-style-get-default key))) (c-lw6hlp-list-map-style))    
-      ))
-
 (define lw6-config-defaults
   (lambda ()
     (begin 
       (c-lw6cfg-defaults)
       (lw6-config-set-string! lw6def-gfx-backend (lw6-get-default-gfx-backend))
       (lw6-config-set-string! lw6def-snd-backend (lw6-get-default-snd-backend))
-					; not 100% sure the following are needed, 
-					; logicqlly c-lw6cfg-defaults does this
-					; too but well, just in case...
-      (lw6-config-map-rules-defaults)
-      (lw6-config-map-hints-defaults)
-      (lw6-config-map-style-defaults)
+      )
+    )
+  )
+
+(define lw6-config-fix
+  (lambda ()
+    (begin 
+      ;;      (lw6-config-set-string! lw6def-public-url 
+      ;;			      (c-lw6sys-url-canonize 
+      ;;			       (lw6-config-get-string 
+      ;;				lw6def-public-url)))
+      #f
       )
     )
   )
@@ -100,6 +91,7 @@
       (c-lw6cfg-load (c-lw6sys-get-config-file))
       (c-lw6cfg-save (c-lw6sys-get-config-file))
       (c-lw6cfg-load (c-lw6sys-get-config-file))      
+      (lw6-config-fix)
       )
     )
   )
@@ -155,7 +147,8 @@
 
 (define lw6-save-config 
   (lambda () 
-    (c-lw6cfg-save (c-lw6sys-get-config-file))))
+    (c-lw6cfg-save (c-lw6sys-get-config-file))      
+    ))
 
 (define lw6-config-subset
   (lambda (key-list)
