@@ -18,23 +18,13 @@
 ;Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
 ;Contact author        : ufoot@ufoot.org
 
-(define lw6-options-menu-map-item
-  (lambda ()
-    (let (
-	  (item (lw6-menu-item-template (_ "Map")))
-	  )
-      (begin
-	(assoc-set! item "selected" #t)
-	(assoc-set! item "on-valid" (lambda (mi) (lw6-push-menu (lw6-map-options-menu))))
-	item
-	))))
-
 (define lw6-options-menu-time-item
   (lambda ()
     (let (
 	  (item (lw6-menu-item-template (_ "Time & speed")))
 	  )
       (begin
+	(assoc-set! item "selected" #t)
 	(assoc-set! item "on-valid" (lambda (mi) (lw6-push-menu (lw6-time-options-menu))))
 	item
 	))))
@@ -49,6 +39,16 @@
 	item
 	))))
 
+(define lw6-options-menu-map-item
+  (lambda ()
+    (let (
+	  (item (lw6-menu-item-template (_ "Map")))
+	  )
+      (begin
+	(assoc-set! item "on-valid" (lambda (mi) (lw6-push-menu (lw6-map-options-menu))))
+	item
+	))))
+
 (define lw6-options-menu-video-item
   (lambda ()
     (let (
@@ -88,7 +88,9 @@
 	(assoc-set! item "on-valid" (lambda (mi) (begin
 						   (lw6-pop-menu (lw6-current-menu))
 						   (lw6-pop-menu (lw6-current-menu))
-						   (lw6-game-idle))))
+						   (lw6-game-idle)
+						   (lw6-music-ambiance)
+						   )))
 	item
 	))))
 
@@ -98,9 +100,9 @@
 	  (menu (lw6-menu-template (_ "Options")))
 	  )
       (begin
-	(lw6-append-menuitem! menu (lw6-options-menu-map-item))
 	(lw6-append-menuitem! menu (lw6-options-menu-time-item))
 	(lw6-append-menuitem! menu (lw6-options-menu-rules-item))
+	(lw6-append-menuitem! menu (lw6-options-menu-map-item))
 	(lw6-append-menuitem! menu (lw6-options-menu-video-item))
 	(lw6-append-menuitem! menu (lw6-options-menu-sound-item))
 	(lw6-append-menuitem! menu (lw6-options-menu-system-item))
