@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ _mod_random_init (int argc, char *argv[], lw6bot_data_t * data)
 {
   _mod_random_context_t *random_context = NULL;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _("random init"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("random init"));
 
   random_context =
     (_mod_random_context_t *) LW6SYS_CALLOC (sizeof (_mod_random_context_t));
@@ -49,6 +49,6 @@ _mod_random_init (int argc, char *argv[], lw6bot_data_t * data)
 void
 _mod_random_quit (_mod_random_context_t * random_context)
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _("random quit"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("random quit"));
   LW6SYS_FREE (random_context);
 }
