@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ _lw6cfg_get_option (_lw6cfg_context_t * context, char *key)
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("option \"%s\" is not set"), key);
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("option \"%s\" is not set"), key);
     }
 
   return ret;
