@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ _lw6cfg_init (int argc, char *argv[])
 
   if (!cfg_context)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to initialize config"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to initialize config"));
     }
 
   return cfg_context;
