@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,10 +28,18 @@
 #include "mod-http.h"
 #include "mod-http-internal.h"
 
+/*
+ * http://www.gnu.org/prep/standards/html_node/Dynamic-Plug_002dIn-Interfaces.html
+ */
+void
+mod_http_is_GPL_compatible ()
+{
+}
+
 static void *
 _init (int argc, char *argv[])
 {
-  _http_context_t *http_context = _mod_http_init (argc, argv);
+  _mod_http_context_t *http_context = _mod_http_init (argc, argv);
 
   return (void *) http_context;
 }
@@ -39,7 +47,7 @@ _init (int argc, char *argv[])
 static void
 _quit (void *cli_context)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
 
   if (http_context)
     {
@@ -51,7 +59,7 @@ static int
 _process_oob (void *cli_context, lw6nod_info_t * node_info,
 	      lw6cli_oob_data_t * oob_data)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
   int ret = 0;
 
   if (http_context)
@@ -62,26 +70,31 @@ _process_oob (void *cli_context, lw6nod_info_t * node_info,
   return ret;
 }
 
-static lw6cli_connection_t *
-_connect (void *cli_context, char *server_url, char *client_url,
-	  char *password)
+static lw6cnx_connection_t *
+_open (void *cli_context, char *local_url, char *remote_url, char *remote_ip,
+       int remote_port, char *password, u_int64_t local_id,
+       u_int64_t remote_id, int dns_ok, int network_reliability,
+       lw6cnx_recv_callback_t recv_callback_func, void *recv_callback_data)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
-  lw6cli_connection_t *ret = NULL;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
+  lw6cnx_connection_t *ret = NULL;
 
   if (http_context)
     {
       ret =
-	_mod_http_connect (http_context, server_url, client_url, password);
+	_mod_http_open (http_context, local_url, remote_url, remote_ip,
+			remote_port, password, local_id, remote_id, dns_ok,
+			network_reliability, recv_callback_func,
+			recv_callback_data);
     }
 
   return ret;
 }
 
 static void
-_close (void *cli_context, lw6cli_connection_t * connection)
+_close (void *cli_context, lw6cnx_connection_t * connection)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
 
   if (http_context)
     {
@@ -90,51 +103,39 @@ _close (void *cli_context, lw6cli_connection_t * connection)
 }
 
 static int
-_send (void *cli_context, lw6cli_connection_t * connection, char *message)
+_send (void *cli_context, lw6cnx_connection_t * connection,
+       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
+       u_int64_t logical_from_id, u_int64_t logical_to_id, char *message)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
   int ret = 0;
 
   if (http_context)
     {
-      ret = _mod_http_send (http_context, connection, message);
+      ret =
+	_mod_http_send (http_context, connection, physical_ticket_sig,
+			logical_ticket_sig, logical_from_id, logical_to_id,
+			message);
     }
 
   return ret;
 }
 
-static char *
-_recv (void *cli_context, lw6cli_connection_t * connection)
+static void
+_poll (void *cli_context, lw6cnx_connection_t * connection)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
-  char *ret = NULL;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
 
   if (http_context)
     {
-      ret = _mod_http_recv (http_context, connection);
+      _mod_http_poll (http_context, connection);
     }
-
-  return ret;
-}
-
-static int
-_is_alive (void *cli_context, lw6cli_connection_t * connection)
-{
-  _http_context_t *http_context = (_http_context_t *) cli_context;
-  int ret = 0;
-
-  if (http_context)
-    {
-      ret = _mod_http_is_alive (http_context, connection);
-    }
-
-  return ret;
 }
 
 static char *
-_repr (void *cli_context, lw6cli_connection_t * connection)
+_repr (void *cli_context, lw6cnx_connection_t * connection)
 {
-  _http_context_t *http_context = (_http_context_t *) cli_context;
+  _mod_http_context_t *http_context = (_mod_http_context_t *) cli_context;
   char *ret = NULL;
 
   if (http_context)
@@ -145,20 +146,6 @@ _repr (void *cli_context, lw6cli_connection_t * connection)
   return ret;
 }
 
-static char *
-_error (void *cli_context, lw6cli_connection_t * connection)
-{
-  _http_context_t *http_context = (_http_context_t *) cli_context;
-  char *ret = NULL;
-
-  if (http_context)
-    {
-      ret = _mod_http_error (http_context, connection);
-    }
-
-  return ret;
-}
-
 lw6sys_module_pedigree_t *
 mod_http_get_pedigree ()
 {
@@ -171,13 +158,13 @@ mod_http_get_pedigree ()
     {
       module_pedigree->id = "http";
       module_pedigree->category = "cli";
-      module_pedigree->name = _("HTTP (Curl)");
+      module_pedigree->name = _x_ ("HTTP (Curl)");
       module_pedigree->readme =
-	_
+	_x_
 	("A network client which uses Curl to encapsulate the LW6 protocol into HTTP requests.");
       module_pedigree->version = VERSION;
       module_pedigree->copyright =
-	"Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>";
+	"Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -199,13 +186,11 @@ mod_http_create_backend ()
       backend->init = _init;
       backend->quit = _quit;
       backend->process_oob = _process_oob;
-      backend->connect = _connect;
+      backend->open = _open;
       backend->close = _close;
       backend->send = _send;
-      backend->recv = _recv;
-      backend->is_alive = _is_alive;
+      backend->poll = _poll;
       backend->repr = _repr;
-      backend->error = _error;
     }
 
   return backend;
