@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,14 @@
 #include "mod-udp.h"
 #include "mod-udp-internal.h"
 
+/*
+ * http://www.gnu.org/prep/standards/html_node/Dynamic-Plug_002dIn-Interfaces.html
+ */
+void
+mod_udp_is_GPL_compatible ()
+{
+}
+
 static void *
 _init (int argc, char *argv[])
 {
@@ -62,23 +70,29 @@ _process_oob (void *cli_context, lw6nod_info_t * node_info,
   return ret;
 }
 
-static lw6cli_connection_t *
-_connect (void *cli_context, char *server_url, char *client_url,
-	  char *password)
+static lw6cnx_connection_t *
+_open (void *cli_context, char *local_url, char *remote_url, char *remote_ip,
+       int remote_port, char *password, u_int64_t local_id,
+       u_int64_t remote_id, int dns_ok, int network_reliability,
+       lw6cnx_recv_callback_t recv_callback_func, void *recv_callback_data)
 {
   _udp_context_t *udp_context = (_udp_context_t *) cli_context;
-  lw6cli_connection_t *ret = NULL;
+  lw6cnx_connection_t *ret = NULL;
 
   if (udp_context)
     {
-      ret = _mod_udp_connect (udp_context, server_url, client_url, password);
+      ret =
+	_mod_udp_open (udp_context, local_url, remote_url, remote_ip,
+		       remote_port, password, local_id, remote_id, dns_ok,
+		       network_reliability, recv_callback_func,
+		       recv_callback_data);
     }
 
   return ret;
 }
 
 static void
-_close (void *cli_context, lw6cli_connection_t * connection)
+_close (void *cli_context, lw6cnx_connection_t * connection)
 {
   _udp_context_t *udp_context = (_udp_context_t *) cli_context;
 
@@ -89,49 +103,37 @@ _close (void *cli_context, lw6cli_connection_t * connection)
 }
 
 static int
-_send (void *cli_context, lw6cli_connection_t * connection, char *message)
+_send (void *cli_context, lw6cnx_connection_t * connection,
+       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
+       u_int64_t logical_from_id, u_int64_t logical_to_id, char *message)
 {
   _udp_context_t *udp_context = (_udp_context_t *) cli_context;
   int ret = 0;
 
   if (udp_context)
     {
-      ret = _mod_udp_send (udp_context, connection, message);
+      ret =
+	_mod_udp_send (udp_context, connection, physical_ticket_sig,
+		       logical_ticket_sig, logical_from_id, logical_to_id,
+		       message);
     }
 
   return ret;
 }
 
-static char *
-_recv (void *cli_context, lw6cli_connection_t * connection)
+static void
+_poll (void *cli_context, lw6cnx_connection_t * connection)
 {
   _udp_context_t *udp_context = (_udp_context_t *) cli_context;
-  char *ret = NULL;
 
   if (udp_context)
     {
-      ret = _mod_udp_recv (udp_context, connection);
+      _mod_udp_poll (udp_context, connection);
     }
-
-  return ret;
-}
-
-static int
-_is_alive (void *cli_context, lw6cli_connection_t * connection)
-{
-  _udp_context_t *udp_context = (_udp_context_t *) cli_context;
-  int ret = 0;
-
-  if (udp_context)
-    {
-      ret = _mod_udp_is_alive (udp_context, connection);
-    }
-
-  return ret;
 }
 
 static char *
-_repr (void *cli_context, lw6cli_connection_t * connection)
+_repr (void *cli_context, lw6cnx_connection_t * connection)
 {
   _udp_context_t *udp_context = (_udp_context_t *) cli_context;
   char *ret = NULL;
@@ -144,20 +146,6 @@ _repr (void *cli_context, lw6cli_connection_t * connection)
   return ret;
 }
 
-static char *
-_error (void *cli_context, lw6cli_connection_t * connection)
-{
-  _udp_context_t *udp_context = (_udp_context_t *) cli_context;
-  char *ret = NULL;
-
-  if (udp_context)
-    {
-      ret = _mod_udp_error (udp_context, connection);
-    }
-
-  return ret;
-}
-
 lw6sys_module_pedigree_t *
 mod_udp_get_pedigree ()
 {
@@ -170,13 +158,13 @@ mod_udp_get_pedigree ()
     {
       module_pedigree->id = "udp";
       module_pedigree->category = "cli";
-      module_pedigree->name = _("UDP");
+      module_pedigree->name = _x_ ("UDP");
       module_pedigree->readme =
-	_
+	_x_
 	("A simple network client which uses raw UDP/IP sockets. The fastest way to communicate.");
       module_pedigree->version = VERSION;
       module_pedigree->copyright =
-	"Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>";
+	"Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -198,13 +186,11 @@ mod_udp_create_backend ()
       backend->init = _init;
       backend->quit = _quit;
       backend->process_oob = _process_oob;
-      backend->connect = _connect;
+      backend->open = _open;
       backend->close = _close;
       backend->send = _send;
-      backend->recv = _recv;
-      backend->is_alive = _is_alive;
+      backend->poll = _poll;
       backend->repr = _repr;
-      backend->error = _error;
     }
 
   return backend;
