@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,23 +28,13 @@
 #include "mod-udp-internal.h"
 
 char *
-_mod_udp_repr (_udp_context_t * udp_context, lw6cli_connection_t * connection)
+_mod_udp_repr (_udp_context_t * udp_context, lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
   ret =
-    lw6sys_new_sprintf (_("udp connexion on \"%s\""), connection->server_url);
-
-  return ret;
-}
-
-char *
-_mod_udp_error (_udp_context_t * udp_context,
-		lw6cli_connection_t * connection)
-{
-  char *ret = NULL;
-
-  // todo
+    lw6sys_new_sprintf (_x_ ("udp connexion on \"%s\""),
+			connection->remote_url);
 
   return ret;
 }
