@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,6 +44,12 @@ typedef struct _udp_context_s
 }
 _udp_context_t;
 
+typedef struct _udp_specific_data_s
+{
+  int sock;
+}
+_udp_specific_data_t;
+
 /* mod-udp-data.c */
 extern int _mod_udp_load_data (_udp_data_t * udp_data, char *data_dir);
 extern void _mod_udp_unload_data (_udp_data_t * udp_data);
@@ -54,21 +60,21 @@ extern void _mod_udp_unload_data (_udp_data_t * udp_data);
 extern _udp_context_t *_mod_udp_init (int argc, char *argv[]);
 extern void _mod_udp_quit (_udp_context_t * udp_context);
 
-/*
- * In handshake.c
- */
-extern lw6cli_connection_t *_mod_udp_connect (_udp_context_t * udp_context,
-					      char *server_url,
-					      char *client_url,
-					      char *password);
-
 /*
  * In state.c
  */
+extern lw6cnx_connection_t *_mod_udp_open (_udp_context_t * udp_context,
+					   char *local_url, char *remote_url,
+					   char *remote_ip, int remote_port,
+					   char *password, u_int64_t local_id,
+					   u_int64_t remote_id,
+					   int dns_ok,
+					   int network_reliability,
+					   lw6cnx_recv_callback_t
+					   recv_callback_func,
+					   void *recv_callback_data);
 extern void _mod_udp_close (_udp_context_t * udp_context,
-			    lw6cli_connection_t * connection);
-extern int _mod_udp_is_alive (_udp_context_t * udp_context,
-			      lw6cli_connection_t * connection);
+			    lw6cnx_connection_t * connection);
 extern int _mod_udp_timeout_ok (_udp_context_t * udp_context,
 				int64_t origin_timestamp, int broadcast);
 
@@ -76,17 +82,19 @@ extern int _mod_udp_timeout_ok (_udp_context_t * udp_context,
  * In message.c
  */
 extern int _mod_udp_send (_udp_context_t * udp_context,
-			  lw6cli_connection_t * connection, char *message);
-extern char *_mod_udp_recv (_udp_context_t * udp_context,
-			    lw6cli_connection_t * connection);
+			  lw6cnx_connection_t * connection,
+			  u_int32_t physical_ticket_sig,
+			  u_int32_t logical_ticket_sig,
+			  u_int64_t logical_from_id, u_int64_t logical_to_id,
+			  char *message);
+extern void _mod_udp_poll (_udp_context_t * udp_context,
+			   lw6cnx_connection_t * connection);
 
 /*
  * In info.c
  */
 extern char *_mod_udp_repr (_udp_context_t * udp_context,
-			    lw6cli_connection_t * connection);
-extern char *_mod_udp_error (_udp_context_t * udp_context,
-			     lw6cli_connection_t * connection);
+			    lw6cnx_connection_t * connection);
 
 /*
  * In oob.c
