@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,7 +47,6 @@ typedef struct _lw6dsp_data_s
   int run;
   int started;
   int failed;
-  int quit;
   lw6gui_resize_callback_func_t resize_callback;
   int64_t start_ticks;
   int64_t ticks;
@@ -65,11 +64,16 @@ typedef struct _lw6dsp_data_s
   lw6dsp_param_t param;
   lw6gui_input_t *input;
   lw6pil_local_cursors_t local_cursors;
-  void *macosx_handler;
+#ifdef LW6_MAC_OS_X
+  void *macosx_vthread_handler;
+  void *macosx_thread_handler;
+#endif
 } _lw6dsp_data_t;
 
+/*
 typedef void *(*lw6dsp_macosx_init_func_t) (void);
 typedef void (*lw6dsp_macosx_quit_func_t) (void *ptr);
+*/
 
 /* dsp-data.c */
 extern _lw6dsp_data_t *_lw6dsp_data_new ();
