@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ verbose_dlopen (char *file)
   if ((nb_errs = lt_dlinit ()) > 0)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("couldn't initialize libltdl, %d errors"), nb_errs);
+		  _x_ ("couldn't initialize libltdl, %d errors"), nb_errs);
     }
   else
     {
@@ -45,14 +45,14 @@ verbose_dlopen (char *file)
 
   if (ret)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("load module \"%s\""), file);
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("load module \"%s\""), file);
     }
   else
     {
       if (lw6sys_file_exists (file))
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _
+		      _x_
 		      ("couldn't open shared library \"%s\" lt_dlerror=\"%s\""),
 		      file, lt_dlerror ());
 	}
@@ -63,7 +63,7 @@ verbose_dlopen (char *file)
 	   * as a warning, only an information.
 	   */
 	  lw6sys_log (LW6SYS_LOG_INFO,
-		      _("shared library \"%s\" doesn't exist"), file);
+		      _x_ ("shared library \"%s\" doesn't exist"), file);
 	}
     }
 
@@ -144,6 +144,7 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
   lw6sys_module_pedigree_t *module_pedigree = NULL;
   char *create_backend_func_str = NULL;
   void *(*create_backend_func) () = NULL;
+  char *is_GPL_compatible_sym_str = NULL;
   int ok = 0;
   static int first_load = 1;
 
@@ -196,91 +197,124 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 					      (lw6sys_build_get_version (),
 					       module_pedigree->version))
 					    {
-					      if (first_load)
-						{
-						  /*
-						   * the first time we
-						   * load a .so file,
-						   * log it to console
-						   * just to make sure
-						   * paths are right.
-						   */
-						  lw6sys_log
-						    (LW6SYS_LOG_NOTICE,
-						     _
-						     ("loaded module \"%s\""),
-						     so_file);
-						  first_load = 0;
-						}
 
-					      lw6sys_log
-						(LW6SYS_LOG_INFO,
-						 _
-						 ("module \"%s\" loaded, looks fine"),
-						 so_file);
-					      /*
-					       * Verbose dlopen did log the so name
-					       */
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("id for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  id);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("category for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  category);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("name for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  name);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("readme for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  readme);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("version for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  version);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("copyright for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  copyright);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("license for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  license);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("date for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  date);
-					      lw6sys_log (LW6SYS_LOG_INFO,
-							  _
-							  ("time for \"%s\" is \"%s\""),
-							  so_file,
-							  module_pedigree->
-							  time);
-					      ok = 1;
+					      is_GPL_compatible_sym_str =
+						lw6sys_new_sprintf
+						(LW6DYN_IS_GPL_COMPATIBLE_SYM_FORMAT,
+						 backend_name);
+					      if (is_GPL_compatible_sym_str)
+						{
+						  if (lw6dyn_dlsym
+						      (ret,
+						       is_GPL_compatible_sym_str))
+						    {
+						      if (first_load)
+							{
+							  /*
+							   * the first time we
+							   * load a .so file,
+							   * log it to console
+							   * just to make sure
+							   * paths are right.
+							   */
+							  lw6sys_log
+							    (LW6SYS_LOG_NOTICE,
+							     _x_
+							     ("loaded module \"%s\""),
+							     so_file);
+							  first_load = 0;
+							}
+
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("module \"%s\" loaded, looks fine"),
+							 so_file);
+						      /*
+						       * Verbose dlopen did log the so name
+						       */
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("id for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->id);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("category for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 category);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("name for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 name);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("readme for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 readme);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("version for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 version);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("copyright for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 copyright);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("license for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 license);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("date for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 date);
+						      lw6sys_log
+							(LW6SYS_LOG_INFO,
+							 _x_
+							 ("time for \"%s\" is \"%s\""),
+							 so_file,
+							 module_pedigree->
+							 time);
+						      ok = 1;
+						    }
+						  else
+						    {
+						      lw6sys_log
+							(LW6SYS_LOG_WARNING,
+							 _x_
+							 ("module mod_%s \"%s\" in \"%s\" is not GPL compatible"),
+							 backend_name,
+							 module_pedigree->
+							 name, so_file);
+						    }
+						  LW6SYS_FREE
+						    (is_GPL_compatible_sym_str);
+						}
 					    }
 					  else
 					    {
 					      lw6sys_log (LW6SYS_LOG_WARNING,
-							  _
+							  _x_
 							  ("bad version for module mod_%s \"%s\" in \"%s\", module version is \"%s\" but main program version is \"%s\""),
 							  backend_name,
 							  module_pedigree->
@@ -294,7 +328,7 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 				      else
 					{
 					  lw6sys_log (LW6SYS_LOG_WARNING,
-						      _
+						      _x_
 						      ("bad category for module mod_%s \"%s\" in \"%s\", module category is \"%s\" but main program requested \"%s\""),
 						      backend_name,
 						      module_pedigree->name,
@@ -307,7 +341,7 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 				  else
 				    {
 				      lw6sys_log (LW6SYS_LOG_WARNING,
-						  _
+						  _x_
 						  ("bad id for module mod_%s \"%s\" in \"%s\", module id is \"%s\""),
 						  backend_name,
 						  module_pedigree->name,
@@ -321,7 +355,7 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 		      else
 			{
 			  lw6sys_log (LW6SYS_LOG_WARNING,
-				      _
+				      _x_
 				      ("bad pedigree for mod_%s in \"%s\""),
 				      backend_name, so_file);
 			}
@@ -330,7 +364,7 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 		  else
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _
+				  _x_
 				  ("can't get pedigree for mod_%s in \"%s\""),
 				  backend_name, so_file);
 		    }
@@ -343,8 +377,11 @@ lw6dyn_dlopen_backend (int argc, char *argv[], char *top_level_lib,
 
   if (!ok)
     {
-      lw6dyn_dlclose_backend (ret);
-      ret = NULL;
+      if (ret)
+	{
+	  lw6dyn_dlclose_backend (ret);
+	  ret = NULL;
+	}
     }
 
   return ret;
@@ -374,7 +411,7 @@ lw6dyn_dlclose_backend (lw6dyn_dl_handle_t * handle)
        * a loaded shared library, we know *what* we're freeing,
        * which can be pretty usefull when debugging.
        */
-      lw6sys_log (LW6SYS_LOG_INFO, _("unload module \"%s\""),
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("unload module \"%s\""),
 		  handle->library_path);
       if (handle->handle)
 	{
@@ -385,29 +422,30 @@ lw6dyn_dlclose_backend (lw6dyn_dl_handle_t * handle)
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _("couldn't unload shared library"));
+			  _x_ ("couldn't unload shared library"));
 	    }
 	}
 
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("lt_dlclose done for \"%s\""),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("lt_dlclose done for \"%s\""),
 		  handle->library_path);
 
       if ((nb_errs = lt_dlexit ()) > 0)
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("couldn't exit libltdl, %d errors"), nb_errs);
+		      _x_ ("couldn't exit libltdl, %d errors"), nb_errs);
 	  ret = 0;
 	}
 
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("lt_dlexit done for \"%s\""),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("lt_dlexit done for \"%s\""),
 		  handle->library_path);
+
+      LW6SYS_FREE (handle->library_path);
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL dl_handle"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL dl_handle"));
     }
 
-  LW6SYS_FREE (handle->library_path);
   LW6SYS_FREE (handle);
 
   return ret;
@@ -432,14 +470,14 @@ lw6dyn_dlsym (lw6dyn_dl_handle_t * handle, char *func_name)
   if (ret)
     {
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("found function \"%s\" in library \"%s\""),
+		  _x_ ("found symbol \"%s\" in library \"%s\""),
 		  func_name, handle->library_path);
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
-		  ("unable to find function \"%s\" in library \"%s\""),
+		  _x_
+		  ("unable to find symbol \"%s\" in library \"%s\""),
 		  func_name, handle->library_path);
     }
 
