@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,8 +31,11 @@
 #define TEST_FULLSCREEN 0
 #define TEST_SLEEP 0.01
 #define TEST_DURATION_SETUP 100
-#define TEST_DURATION_BACKGROUND 2000
-#define TEST_DURATION_MENU 3000
+#define TEST_DURATION_SPLASH 500
+#define TEST_DURATION_BACKGROUND 500
+#define TEST_DURATION_MENU 500
+#define TEST_DURATION_VIEW 500
+#define TEST_DURATION_HUD 10000
 #define TEST_MENU_LABEL "My menu"
 #define TEST_MENU_ESC "Esc"
 #define TEST_MENU_ENABLE_ESC 0
@@ -63,16 +66,17 @@ test_resolution (lw6gfx_backend_t * backend)
 
     if (lw6gfx_get_fullscreen_modes (backend, &modes))
       {
-	lw6sys_log (LW6SYS_LOG_NOTICE, _("low resolution is %dx%d"),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("low resolution is %dx%d"),
 		    modes.low.width, modes.low.height);
-	lw6sys_log (LW6SYS_LOG_NOTICE, _("standard resolution is %dx%d"),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("standard resolution is %dx%d"),
 		    modes.standard.width, modes.standard.height);
-	lw6sys_log (LW6SYS_LOG_NOTICE, _("high resolution is %dx%d"),
+	lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("high resolution is %dx%d"),
 		    modes.high.width, modes.high.height);
       }
     else
       {
-	lw6sys_log (LW6SYS_LOG_WARNING, _("unable to get fullscreen modes"));
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _x_ ("unable to get fullscreen modes"));
       }
   }
 
@@ -84,7 +88,7 @@ static void
 resize_callback (lw6gui_video_mode_t * video_mode)
 {
   lw6sys_log (LW6SYS_LOG_NOTICE,
-	      _("resize callback called %dx%d fullscreen=%d"),
+	      _x_ ("resize callback called %dx%d fullscreen=%d"),
 	      video_mode->width, video_mode->height, video_mode->fullscreen);
 }
 
@@ -109,7 +113,8 @@ test_init (lw6gfx_backend_t * backend)
 	repr = lw6gfx_repr (backend);
 	if (repr)
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE, _("display repr is \"%s\""), repr);
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("display repr is \"%s\""),
+			repr);
 	    LW6SYS_FREE (repr);
 	  }
 	ticks = lw6sys_get_uptime ();
@@ -124,6 +129,40 @@ test_init (lw6gfx_backend_t * backend)
   return ret;
 }
 
+static int
+test_splash (lw6gfx_backend_t * backend)
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6gui_look_t *look = NULL;
+    int64_t ticks;
+
+    look = lw6gui_look_new (NULL);
+    if (look)
+      {
+	ticks = lw6sys_get_uptime ();
+	while (lw6sys_get_uptime () < ticks + TEST_DURATION_SPLASH)
+	  {
+	    if (!lw6gfx_display (backend,
+				 LW6GUI_DISPLAY_BACKGROUND |
+				 LW6GUI_DISPLAY_SPLASH, look, NULL, NULL,
+				 NULL, 0, NULL, 0.0f, 0, 0, NULL, 0, 0, 0, 0))
+	      {
+		lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("display error"));
+		ret = 0;
+	      }
+	    lw6sys_sleep (TEST_SLEEP);
+	  }
+	lw6gui_look_free (look);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 test_background (lw6gfx_backend_t * backend)
 {
@@ -153,7 +192,7 @@ test_background (lw6gfx_backend_t * backend)
 				     NULL, NULL, 0, NULL, 0.0f, 0, 0, NULL, 0,
 				     0, 0, 0))
 		  {
-		    lw6sys_log (LW6SYS_LOG_WARNING, _("display error"));
+		    lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("display error"));
 		    ret = 0;
 		  }
 		lw6sys_sleep (TEST_SLEEP);
@@ -194,7 +233,7 @@ test_menu (lw6gfx_backend_t * backend)
 	    for (i = 0; i < TEST_MENU_NB_MENUITEMS; ++i)
 	      {
 		menuitem_label =
-		  lw6sys_new_sprintf (_("Test menuitem %d"), i);
+		  lw6sys_new_sprintf (_x_ ("Test menuitem %d"), i);
 		if (menuitem_label)
 		  {
 		    menuitem =
@@ -224,7 +263,7 @@ test_menu (lw6gfx_backend_t * backend)
 				     NULL, NULL, 0, menu, progress, 0, 0,
 				     NULL, 0, 0, 0, 0))
 		  {
-		    lw6sys_log (LW6SYS_LOG_WARNING, _("display error"));
+		    lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("display error"));
 		    ret = 0;
 		  }
 		lw6sys_sleep (TEST_SLEEP);
@@ -239,6 +278,138 @@ test_menu (lw6gfx_backend_t * backend)
   return ret;
 }
 
+static int
+test_view (lw6gfx_backend_t * backend)
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6gui_look_t *look = NULL;
+    int64_t ticks;
+    lw6map_level_t *level = NULL;
+    lw6ker_game_struct_t *game_struct = NULL;
+    lw6ker_game_state_t *game_state = NULL;
+
+    look = lw6gui_look_new (NULL);
+    if (look)
+      {
+	level = lw6map_builtin_defaults ();
+	if (level)
+	  {
+	    game_struct = lw6ker_game_struct_new (level, NULL);
+	    if (game_struct)
+	      {
+		game_state = lw6ker_game_state_new (game_struct, NULL);
+		if (game_state)
+		  {
+		    ticks = lw6sys_get_uptime ();
+		    while (lw6sys_get_uptime () < ticks + TEST_DURATION_VIEW)
+		      {
+			if (!lw6gfx_display (backend,
+					     LW6GUI_DISPLAY_BACKGROUND |
+					     LW6GUI_DISPLAY_MAP |
+					     LW6GUI_DISPLAY_FIGHTERS, look,
+					     level, game_struct, game_state,
+					     NULL, NULL, 0.0f, 0.0f, 0.0f,
+					     NULL, 0, 0, 0, 0))
+			  {
+			    lw6sys_log (LW6SYS_LOG_WARNING,
+					_x_ ("display error"));
+			    ret = 0;
+			  }
+			lw6sys_sleep (TEST_SLEEP);
+		      }
+		    lw6ker_game_state_free (game_state);
+		  }
+		lw6ker_game_struct_free (game_struct);
+	      }
+	    lw6map_free (level);
+	  }
+	lw6gui_look_free (look);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+static int
+test_hud (lw6gfx_backend_t * backend)
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6gui_look_t *look = NULL;
+    int64_t ticks;
+    lw6map_level_t *level = NULL;
+    lw6ker_game_struct_t *game_struct = NULL;
+    lw6ker_game_state_t *game_state = NULL;
+    lw6pil_local_cursors_t local_cursors;
+    u_int64_t node_id;
+
+    look = lw6gui_look_new (NULL);
+    if (look)
+      {
+	level = lw6map_builtin_defaults ();
+	level->param.rules.total_time = LW6MAP_RULES_MIN_TOTAL_TIME;
+	if (level)
+	  {
+	    game_struct = lw6ker_game_struct_new (level, NULL);
+	    if (game_struct)
+	      {
+		game_state = lw6ker_game_state_new (game_struct, NULL);
+		if (game_state)
+		  {
+		    lw6pil_local_cursors_reset (&local_cursors);
+		    node_id = lw6sys_generate_id_64 ();
+		    lw6ker_game_state_register_node (game_state, node_id);
+		    lw6ker_game_state_add_cursor (game_state, node_id,
+						  lw6sys_generate_id_16 (),
+						  LW6MAP_TEAM_COLOR_RED);
+		    lw6ker_game_state_add_cursor (game_state, node_id,
+						  lw6sys_generate_id_16 (),
+						  LW6MAP_TEAM_COLOR_GREEN);
+		    lw6ker_game_state_add_cursor (game_state, node_id,
+						  lw6sys_generate_id_16 (),
+						  LW6MAP_TEAM_COLOR_BLUE);
+		    while (lw6ker_game_state_get_time_left (game_state) > 0)
+		      {
+			lw6ker_game_state_do_round (game_state);
+		      }
+
+		    ticks = lw6sys_get_uptime ();
+		    while (lw6sys_get_uptime () < ticks + TEST_DURATION_HUD)
+		      {
+			if (!lw6gfx_display (backend,
+					     LW6GUI_DISPLAY_BACKGROUND |
+					     LW6GUI_DISPLAY_HUD |
+					     LW6GUI_DISPLAY_SCORE, look,
+					     level, game_struct, game_state,
+					     &local_cursors, NULL, 0.0f, 0.0f,
+					     0.0f, NULL, 0, 0, 0, 0))
+			  {
+			    lw6sys_log (LW6SYS_LOG_WARNING,
+					_x_ ("display error"));
+			    ret = 0;
+			  }
+			lw6sys_sleep (TEST_SLEEP);
+		      }
+		    lw6ker_game_state_free (game_state);
+		  }
+		lw6ker_game_struct_free (game_struct);
+	      }
+	    lw6map_free (level);
+	  }
+	lw6gui_look_free (look);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 test_events (lw6gfx_backend_t * backend)
 {
@@ -257,19 +428,19 @@ test_events (lw6gfx_backend_t * backend)
       {
 	ticks = lw6sys_get_uptime ();
 	lw6sys_log (LW6SYS_LOG_NOTICE,
-		    _
+		    _x_
 		    ("now for %d seconds you can move mouse, touch keyboard, punch joystick"),
 		    TEST_DURATION_EVENTS / 1000);
 	input = lw6gfx_pump_events (backend);
 	while (lw6sys_get_uptime () < ticks + TEST_DURATION_EVENTS
-	       && !input->quit)
+	       && !lw6sys_signal_poll_quit ())
 	  {
 	    if (!lw6gfx_display (backend,
 				 LW6GUI_DISPLAY_BACKGROUND, look, NULL,
 				 NULL, NULL, 0, NULL, 0.0f, 0, 0, NULL, 0, 0,
 				 0, 0))
 	      {
-		lw6sys_log (LW6SYS_LOG_WARNING, _("display error"));
+		lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("display error"));
 		ret = 0;
 	      }
 	    lw6sys_sleep (TEST_SLEEP);
@@ -277,22 +448,22 @@ test_events (lw6gfx_backend_t * backend)
 	    if (lw6gui_button_pop_press (&(input->mouse.button_left)))
 	      {
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("left mouse button pressed at %dx%d"),
+			    _x_ ("left mouse button pressed at %dx%d"),
 			    input->mouse.x, input->mouse.y);
 	      }
 	    if (lw6gui_button_pop_press (&(input->mouse.button_right)))
 	      {
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("right mouse button pressed at %d,%d"),
+			    _x_ ("right mouse button pressed at %d,%d"),
 			    input->mouse.x, input->mouse.y);
 	      }
 	    if (lw6gui_button_pop_press (&(input->mouse.wheel_up)))
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _("mouse wheel up"));
+		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("mouse wheel up"));
 	      }
 	    if (lw6gui_button_pop_press (&(input->mouse.wheel_down)))
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _("mouse wheel down"));
+		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("mouse wheel down"));
 	      }
 	    keypress = lw6gui_keyboard_pop_keypress (&(input->keyboard));
 	    if (keypress)
@@ -300,15 +471,15 @@ test_events (lw6gfx_backend_t * backend)
 		repr = lw6gui_keypress_repr (keypress);
 		if (repr)
 		  {
-		    lw6sys_log (LW6SYS_LOG_NOTICE, _("%s"), repr);
+		    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("%s"), repr);
 		    LW6SYS_FREE (repr);
 		  }
 		lw6gui_keypress_free (keypress);
 	      }
-	    if (input->quit)
+	    if (lw6sys_signal_poll_quit ())
 	      {
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("a QUIT event was detected"));
+			    _x_ ("a QUIT event was detected"));
 	      }
 	  }
 	lw6gui_look_free (look);
@@ -375,7 +546,10 @@ lw6gfx_test (int mode)
       if (backend)
 	{
 	  ret = (test_init (backend) && test_resolution (backend)
+		 && test_splash (backend)
 		 && test_background (backend) && test_menu (backend)
+		 && test_view (backend)
+		 && test_hud (backend)
 		 && test_events (backend) && test_quit (backend)) || ret;
 	  lw6gfx_destroy_backend (backend);
 	}
