@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -70,7 +70,6 @@ display_gauges (mod_gl_utils_context_t * utils_context,
   float size_factor_score;
   float size_factor;
   float ratio;
-  int percent;
   float inner, outer;
   int slices, loops;
   int i;
@@ -87,7 +86,6 @@ display_gauges (mod_gl_utils_context_t * utils_context,
       start = floating_context->const_data.gauge_start;
       for (i = floating_context->score_array.nb_scores - 1; i >= 0; --i)
 	{
-	  percent = floating_context->score_array.scores[i].fighters_percent;
 	  ratio = floating_context->score_array.scores[i].fighters_ratio;
 	  /*
 	   * sqrt because what's important is what happens near zero
@@ -316,11 +314,164 @@ mod_gl_hud_floating_display_hud (mod_gl_utils_context_t * utils_context,
 				    local_cursors);
 }
 
+void
+display_pie (mod_gl_utils_context_t * utils_context,
+	     _mod_gl_hud_floating_context_t * floating_context)
+{
+  int i = 0;
+  float x0, y0, dx, dy, angle1, angle2, angle_offset;
+  float text_w, text_h, text_dw, text_dh;
+  float text_x1, text_y1, text_x2, text_y2;
+  int percent = 0;
+  float size_factor_screen =
+    sqrt (utils_context->video_mode.width * utils_context->video_mode.height);
+  float radius_scale;
+  float inner, outer;
+  float heartbeat_factor = 1.0f;
+  int slices, loops;
+  int team_color;
+  int cycle = 0;
+
+  if (floating_context->game_state)
+    {
+      x0 = utils_context->video_mode.width / 2;
+      y0 = utils_context->video_mode.height / 2;
+      cycle = lw6sys_get_cycle ();
+
+      inner =
+	floating_context->const_data.score_pie_inner *
+	size_factor_screen / 2.0f;
+      outer =
+	floating_context->const_data.score_pie_outer *
+	size_factor_screen / 2.0f;
+      slices = floating_context->const_data.score_pie_slices;
+      loops = floating_context->const_data.score_pie_loops;
+
+      angle1 = angle2 =
+	-(cycle * 360.0f) /
+	floating_context->const_data.score_pie_rotation_period;
+      for (i = 0; i < floating_context->score_array.nb_scores;
+	   ++i, angle1 = angle2)
+	{
+	  percent =
+	    floating_context->score_array.scores[i].consolidated_percent;
+	  angle2 = angle1 + percent * 3.6f;
+	  angle_offset =
+	    M_PI / 2.0f - ((angle1 + angle2) / 2.0f) * M_PI / 180.0f;
+	  dx =
+	    cos (angle_offset) * size_factor_screen *
+	    floating_context->const_data.score_pie_offset / 2.0f;
+	  dy =
+	    sin (angle_offset) * size_factor_screen *
+	    floating_context->const_data.score_pie_offset / 2.0f;
+
+	  team_color = floating_context->score_array.scores[i].team_color;
+
+	  if (i == 0)
+	    {
+	      heartbeat_factor =
+		lw6sys_math_heartbeat (cycle,
+				       floating_context->
+				       const_data.score_pie_heartbeat_period,
+				       floating_context->
+				       const_data.score_pie_heartbeat_factor1,
+				       floating_context->
+				       const_data.score_pie_heartbeat_factor2);
+	    }
+	  else
+	    {
+	      heartbeat_factor = 1.0f;
+	    }
+
+	  if (team_color >= 0)
+	    {
+	      glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	      glEnable (GL_BLEND);
+
+	      glMatrixMode (GL_MODELVIEW);
+	      glPushMatrix ();
+	      glLoadIdentity ();
+	      glTranslatef (x0 + dx, y0 + dy, 0.0f);
+	      mod_gl_utils_bitmap_bind (utils_context,
+					utils_context->
+					textures_1x1.team_colors[team_color]);
+	      gluQuadricTexture (floating_context->score_pie.disk, GL_TRUE);
+	      gluPartialDisk (floating_context->score_pie.disk,
+			      inner * heartbeat_factor,
+			      outer * heartbeat_factor, slices, loops, angle1,
+			      angle2 - angle1);
+	      glPopMatrix ();
+	    }
+	}
+
+      glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+      glEnable (GL_BLEND);
+
+      glMatrixMode (GL_MODELVIEW);
+      glPushMatrix ();
+      glLoadIdentity ();
+
+      angle1 = angle2 =
+	-(cycle * 360.0f) /
+	floating_context->const_data.score_pie_rotation_period;
+      for (i = 0; i < floating_context->score_array.nb_scores;
+	   ++i, angle1 = angle2)
+	{
+	  percent =
+	    floating_context->score_array.scores[i].consolidated_percent;
+	  angle2 = angle1 + percent * 3.6f;
+	  angle_offset =
+	    M_PI / 2.0f - ((angle1 + angle2) / 2.0f) * M_PI / 180.0f;
+	  radius_scale =
+	    (floating_context->const_data.score_pie_text_radius_min *
+	     (floating_context->score_array.nb_scores - i) +
+	     floating_context->const_data.score_pie_text_radius_max * i) /
+	    floating_context->score_array.nb_scores;
+	  dx = cos (angle_offset) * size_factor_screen * radius_scale / 2.0f;
+	  dy = sin (angle_offset) * size_factor_screen * radius_scale / 2.0f;
+
+	  text_h =
+	    size_factor_screen *
+	    floating_context->const_data.score_pie_text_size;
+	  text_dw = size_factor_screen *
+	    floating_context->const_data.score_pie_text_dw;
+	  text_dh = size_factor_screen *
+	    floating_context->const_data.score_pie_text_dh;
+
+	  if (floating_context->score_pie.score_texts[i]
+	      && floating_context->score_pie.score_texts[i]->texture_h > 0)
+	    {
+	      text_w =
+		text_h *
+		((float) floating_context->score_pie.score_texts[i]->
+		 texture_w) /
+		((float) floating_context->score_pie.
+		 score_texts[i]->texture_h);
+	      text_x1 = x0 - text_w / 2 + dx;
+	      text_y1 = y0 - text_h / 2 + dy;
+	      text_x2 = text_x1 + text_w;
+	      text_y2 = text_y1 + text_h;
+	      mod_gl_utils_shaded_text_display (utils_context,
+						floating_context->score_pie.
+						score_texts[i], text_x1,
+						text_y1, text_x2, text_y2,
+						text_dw, text_dh);
+	    }
+	}
+      glPopMatrix ();
+    }
+}
+
 static void
 display_score (mod_gl_utils_context_t * utils_context,
 	       _mod_gl_hud_floating_context_t * floating_context)
 {
-  // todo
+  glMatrixMode (GL_TEXTURE);
+  glPushMatrix ();
+  glLoadIdentity ();
+  display_pie (utils_context, floating_context);
+  glMatrixMode (GL_TEXTURE);
+  glPopMatrix ();
 }
 
 void
@@ -334,6 +485,7 @@ _mod_gl_hud_floating_display_score (mod_gl_utils_context_t * utils_context,
   _mod_gl_hud_floating_context_update_score (utils_context, floating_context,
 					     look, game_state, local_cursors);
 
+  mod_gl_utils_set_render_mode_2d_blend (utils_context);
   display_score (utils_context, floating_context);
 }
 
