@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -110,7 +110,7 @@ _load_consts (mod_gl_utils_context_t * utils_context,
 
   if (const_file)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), const_file);
+      lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading \"%s\""), const_file);
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, _read_callback,
@@ -207,10 +207,10 @@ _load_game (mod_gl_utils_context_t * utils_context,
 					    _GAME_COLOR4);
 	      splash_context->game.bitmap =
 		mod_gl_utils_bitmap_new (utils_context,
-					 splash_context->game.game_struct->
-					 map_struct.shape.w,
-					 splash_context->game.game_struct->
-					 map_struct.shape.h);
+					 lw6ker_game_state_get_w
+					 (splash_context->game.game_state),
+					 lw6ker_game_state_get_h
+					 (splash_context->game.game_state));
 	      if (splash_context->game.bitmap)
 		{
 		  mod_gl_utils_bitmap_set_wrap (utils_context,
