@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -34,12 +34,12 @@ log_event (SDL_Event * event)
     {
     case SDL_ACTIVEEVENT:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("SDL event type=SDL_ACTIVEEVENT gain=%d state=%d"),
+		  _x_ ("SDL event type=SDL_ACTIVEEVENT gain=%d state=%d"),
 		  (int) event->active.gain, (int) event->active.state);
       break;
     case SDL_KEYDOWN:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_KEYDOWN state=%d scancode=%d sym=%d unicode=%d"),
 		  (int) event->key.state,
 		  (int) event->key.keysym.scancode,
@@ -49,7 +49,7 @@ log_event (SDL_Event * event)
       break;
     case SDL_KEYUP:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_KEYUP state=%d scancode=%d sym=%d unicode=%d"),
 		  (int) event->key.state,
 		  (int) event->key.keysym.scancode,
@@ -59,7 +59,7 @@ log_event (SDL_Event * event)
       break;
     case SDL_MOUSEMOTION:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_MOUSEMOTION state=%d x=%d y=%d xrel=%d yrel=%d"),
 		  (int) event->motion.state, (int) event->motion.x,
 		  (int) event->motion.y, (int) event->motion.xrel,
@@ -67,75 +67,75 @@ log_event (SDL_Event * event)
       break;
     case SDL_MOUSEBUTTONDOWN:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_MOUSEBUTTONDOWN button=%d state=%d x=%d y=%d"),
 		  (int) event->button.button, (int) event->button.state,
 		  (int) event->motion.x, (int) event->motion.y);
       break;
     case SDL_MOUSEBUTTONUP:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_MOUSEBUTTONUP button=%d state=%d x=%d y=%d"),
 		  (int) event->button.button, (int) event->button.state,
 		  (int) event->motion.x, (int) event->motion.y);
       break;
     case SDL_JOYAXISMOTION:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_JOYAXISMOTION which=%d axis=%d value=%d"),
 		  (int) event->jaxis.which, event->jaxis.axis,
 		  (int) event->jaxis.value);
       break;
     case SDL_JOYBALLMOTION:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_JOYBALLMOTION which=%d ball=%d xrel=%d yrel=%d"),
 		  (int) event->jball.which, (int) event->jball.ball,
 		  (int) event->jball.xrel, (int) event->jball.yrel);
       break;
     case SDL_JOYHATMOTION:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_JOYHATMOTION which=%d hat=%d value=%d"),
 		  (int) event->jhat.which, (int) event->jhat.hat,
 		  (int) event->jhat.value);
       break;
     case SDL_JOYBUTTONDOWN:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_JOYBUTTONDOWN which=%d button=%d state=%d"),
 		  (int) event->jbutton.which, (int) event->jbutton.button,
 		  (int) event->jbutton.state);
       break;
     case SDL_JOYBUTTONUP:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("SDL event type=SDL_JOYBUTTONUP which=%d button=%d state=%d"),
 		  (int) event->jbutton.which, (int) event->jbutton.button,
 		  (int) event->jbutton.state);
       break;
     case SDL_QUIT:
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("SDL event type=SDL_QUIT"));
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("SDL event type=SDL_QUIT"));
       break;
     case SDL_SYSWMEVENT:
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("SDL event type=SDL_SYSWMEVENT"));
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("SDL event type=SDL_SYSWMEVENT"));
       break;
     case SDL_VIDEORESIZE:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("SDL event type=SDL_VIDEORESIZE w=%d h=%d"),
+		  _x_ ("SDL event type=SDL_VIDEORESIZE w=%d h=%d"),
 		  (int) event->resize.w, (int) event->resize.h);
       break;
     case SDL_VIDEOEXPOSE:
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("SDL event type=SDL_VIDEOEXPOSE"));
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("SDL event type=SDL_VIDEOEXPOSE"));
       break;
     case SDL_USEREVENT:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("SDL event type=SDL_USEREVENT code=%d"),
+		  _x_ ("SDL event type=SDL_USEREVENT code=%d"),
 		  (int) event->user.code);
       break;
     default:
 // should never get there, unless API changes...
-      lw6sys_log (LW6SYS_LOG_WARNING, _("SDL event with unknown type=%d"),
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("SDL event with unknown type=%d"),
 		  event->type);
     }
 }
@@ -444,7 +444,7 @@ joystick_move (lw6gui_joystick_t * joystick, SDL_Event * event, int limit,
       break;
     default:
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("joystick %d axis %d with value %d ignored"),
+		  _x_ ("joystick %d axis %d with value %d ignored"),
 		  event->jaxis.which, event->jaxis.axis, event->jaxis.value);
       break;
     }
@@ -469,7 +469,7 @@ joystick_button_down (lw6gui_joystick_t * joystick, int b, SDL_Event * event,
       lw6gui_button_register_down (&(joystick->button_d), timestamp);
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("joystick %d button %d ignored"),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("joystick %d button %d ignored"),
 		  event->jbutton.which, event->jbutton.button);
       break;
     }
@@ -493,7 +493,7 @@ joystick_button_up (lw6gui_joystick_t * joystick, int b, SDL_Event * event)
       lw6gui_button_register_up (&(joystick->button_d));
       break;
     default:
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("joystick %d button %d ignored"),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("joystick %d button %d ignored"),
 		  event->jbutton.which, event->jbutton.button);
       break;
     }
@@ -524,7 +524,7 @@ mod_gl_utils_pump_events (mod_gl_utils_context_t * utils_context)
 	  key_down (&(input->keyboard), &event, const_data, timestamp);
 	  if (event.key.keysym.sym == const_data->keysym_quit)
 	    {
-	      input->quit = 1;
+	      lw6sys_signal_send_quit ();
 	    }
 	  break;
 	case SDL_KEYUP:
@@ -533,7 +533,7 @@ mod_gl_utils_pump_events (mod_gl_utils_context_t * utils_context)
 	  break;
 	case SDL_QUIT:
 	  lw6gui_input_register_change (input);
-	  input->quit = 1;
+	  lw6sys_signal_send_quit ();
 	  break;
 	case SDL_MOUSEMOTION:
 	  lw6gui_input_register_change (input);
