@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ mod_gl_utils_create_surface (mod_gl_utils_context_t * context, int w, int h)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create image"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to create image"));
     }
 
   return image;
@@ -72,7 +72,7 @@ mod_gl_utils_delete_surface (mod_gl_utils_context_t * context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL surface"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL surface"));
     }
 }
 
