@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -528,6 +528,19 @@ extern SDL_Surface *mod_gl_utils_colorize_surface (mod_gl_utils_context_t *
 extern int mod_gl_utils_load_consts (mod_gl_utils_context_t * context);
 extern void mod_gl_utils_unload_consts (mod_gl_utils_context_t * context);
 
+/*
+ * In cursor.c
+ */
+extern mod_gl_utils_bitmap_t
+  * mod_gl_utils_cursor_create_fg_bg (mod_gl_utils_context_t * utils_context,
+				      lw6gui_look_t * look,
+				      lw6map_level_t * level);
+extern mod_gl_utils_bitmap_t
+  * mod_gl_utils_cursor_create_color (mod_gl_utils_context_t * utils_context,
+				      lw6gui_look_t * look,
+				      lw6map_level_t * level,
+				      lw6ker_cursor_t * cursor);
+
 /*
  * In data.c
  */
@@ -657,7 +670,7 @@ extern void mod_gl_utils_update_game_bitmap_array (mod_gl_utils_context_t *
 extern SDL_Surface
   * mod_gl_utils_create_gradient_surface (mod_gl_utils_context_t *
 					  utils_context,
-					  lw6ker_map_state_t * map_state,
+					  lw6ker_game_state_t * game_state,
 					  int team_id, int layer_id);
 
 /*
@@ -943,7 +956,7 @@ extern void mod_gl_utils_viewport_drawable_max (mod_gl_utils_context_t *
  */
 extern SDL_Surface *mod_gl_utils_create_zones_surface (mod_gl_utils_context_t
 						       * utils_context,
-						       lw6ker_map_struct_t *
+						       lw6ker_game_struct_t *
 						       map_struct);
 
 #endif
