@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include "gl-flat.h"
 #include "gl-flat-internal.h"
 
+/*
 static mod_gl_utils_bitmap_t *
 _cursor_bitmap (mod_gl_utils_context_t * utils_context, int w, int h,
 		int border_width, int blur_width, char letter,
@@ -40,7 +41,6 @@ _cursor_bitmap (mod_gl_utils_context_t * utils_context, int w, int h,
   mod_gl_utils_bitmap_t *ret = NULL;
   SDL_Color color_font;
   SDL_Color color_background;
-  SDL_Color color_outline;
   SDL_Surface *text_surface;
   SDL_Surface *cursor_surface;
   SDL_Rect text_rect;
@@ -54,7 +54,6 @@ _cursor_bitmap (mod_gl_utils_context_t * utils_context, int w, int h,
   color_font = mod_gl_utils_color_8_to_sdl (color->fg);
   color_background =
     mod_gl_utils_color_8_to_sdl (even_odd ? color->bg : team_color);
-  color_outline = mod_gl_utils_color_8_to_sdl (color->fg);
   text_buffer[0] = letter;
 
   text_surface =
@@ -133,6 +132,7 @@ _cursor_bitmap (mod_gl_utils_context_t * utils_context, int w, int h,
 
   return ret;
 }
+*/
 
 int
 _mod_gl_view_flat_cursor_context_init (mod_gl_utils_context_t *
@@ -142,38 +142,46 @@ _mod_gl_view_flat_cursor_context_init (mod_gl_utils_context_t *
 				       _mod_gl_view_flat_const_data_t
 				       * const_data,
 				       lw6gui_look_t * look,
+				       lw6map_level_t * level,
 				       lw6ker_cursor_t * cursor)
 {
   int ret = 0;
+  lw6map_color_couple_t color_couple;
+  char text[2] = { 0, 0 };
 
   if (cursor->enabled)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("view_flat cursor init %x '%c' %d"),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("view_flat cursor init %x '%c' %d"),
 		  (int) cursor->cursor_id, cursor->letter,
 		  cursor->team_color);
       cursor_context->cursor_id = cursor->cursor_id;
       cursor_context->letter = cursor->letter;
       cursor_context->team_color = cursor->team_color;
-      cursor_context->bitmap_even =
-	_cursor_bitmap (utils_context, const_data->cursor_texture_size,
-			const_data->cursor_texture_size,
-			const_data->cursor_border_width,
-			const_data->cursor_blur_width, cursor_context->letter,
-			&look->style.color_set.view_color_cursor,
-			look->style.color_set.team_colors[cursor_context->
-							  team_color], 1);
-      cursor_context->bitmap_odd =
-	_cursor_bitmap (utils_context, const_data->cursor_texture_size,
-			const_data->cursor_texture_size,
-			const_data->cursor_border_width,
-			const_data->cursor_blur_width, cursor_context->letter,
-			&look->style.color_set.view_color_cursor,
-			look->style.color_set.team_colors[cursor_context->
-							  team_color], 0);
-      ret = (cursor_context->bitmap_even != NULL)
-	&& (cursor_context->bitmap_odd != NULL);
+      cursor_context->bitmap_color =
+	mod_gl_utils_cursor_create_color (utils_context, look, level, cursor);
+
+      if (cursor->team_color >= 0)
+	{
+	  color_couple.fg =
+	    look->style.color_set.team_colors[cursor->team_color];
+	}
+      else
+	{
+	  color_couple.fg = look->style.color_set.team_color_dead;
+	}
+      color_couple.bg = look->style.color_set.team_color_dead;
+
+      text[0] = cursor->letter;
+      cursor_context->shaded_text_letter =
+	mod_gl_utils_shaded_text_new (utils_context,
+				      utils_context->font_data.cursor, text,
+				      &color_couple);
+
+      ret = (cursor_context->bitmap_color != NULL)
+	&& (cursor_context->shaded_text_letter != NULL);
     }
-  else
+
+  if (!ret)
     {
       _mod_gl_view_flat_cursor_context_clear (utils_context, cursor_context);
     }
@@ -189,6 +197,7 @@ _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
 					 _mod_gl_view_flat_const_data_t
 					 * const_data,
 					 lw6gui_look_t * look,
+					 lw6map_level_t * level,
 					 lw6ker_cursor_t * cursor)
 {
   int ret = 0;
@@ -196,7 +205,7 @@ _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
   if (cursor_context->cursor_id == cursor->cursor_id
       && cursor_context->letter == cursor->letter
       && cursor_context->team_color == cursor->team_color
-      && cursor_context->bitmap_even && cursor_context->bitmap_odd)
+      && cursor_context->bitmap_color)
     {
       // nothing to do
       ret = 1;
@@ -206,7 +215,8 @@ _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
       _mod_gl_view_flat_cursor_context_clear (utils_context, cursor_context);
       ret =
 	_mod_gl_view_flat_cursor_context_init (utils_context, cursor_context,
-					       const_data, look, cursor);
+					       const_data, look, level,
+					       cursor);
     }
 
   return ret;
@@ -220,13 +230,14 @@ _mod_gl_view_flat_cursor_context_clear (mod_gl_utils_context_t *
 {
   int ret = 1;
 
-  if (cursor_context->bitmap_even)
+  if (cursor_context->bitmap_color)
     {
-      mod_gl_utils_bitmap_free (utils_context, cursor_context->bitmap_even);
+      mod_gl_utils_bitmap_free (utils_context, cursor_context->bitmap_color);
     }
-  if (cursor_context->bitmap_odd)
+  if (cursor_context->shaded_text_letter)
     {
-      mod_gl_utils_bitmap_free (utils_context, cursor_context->bitmap_odd);
+      mod_gl_utils_shaded_text_free (utils_context,
+				     cursor_context->shaded_text_letter);
     }
   memset (cursor_context, 0, sizeof (_mod_gl_view_flat_cursor_context_t));
 
@@ -245,16 +256,23 @@ _mod_gl_view_flat_cursors_context_init (mod_gl_utils_context_t *
 {
   int ret = 1;
   int i;
+  lw6ker_cursor_t cursor;
+  lw6map_level_t *level = NULL;
 
+  level = game_state->game_struct->level;
+  cursors_context->level_id = level->id;
   cursors_context->color = look->style.color_set.view_color_cursor;
+  cursors_context->bitmap_fg_bg =
+    mod_gl_utils_cursor_create_fg_bg (utils_context, look, level);
+  ret = ret && (cursors_context->bitmap_fg_bg != NULL);
   for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
     {
+      lw6ker_game_state_get_cursor_by_index (game_state, &cursor, i);
       ret = ret
 	&& _mod_gl_view_flat_cursor_context_init (utils_context,
 						  &(cursors_context->cursor
 						    [i]), const_data, look,
-						  &game_state->map_state.
-						  cursor_array.cursors[i]);
+						  level, &cursor);
     }
 
   return ret;
@@ -272,10 +290,14 @@ _mod_gl_view_flat_cursors_context_update (mod_gl_utils_context_t *
 {
   int ret = 1;
   int i;
+  lw6ker_cursor_t cursor;
+  lw6map_level_t *level = NULL;
 
-
-  if (!lw6map_color_is_same
-      (&cursors_context->color, &look->style.color_set.view_color_cursor))
+  level = game_state->game_struct->level;
+  if ((cursors_context->level_id != level->id) || (!lw6map_color_is_same
+						   (&cursors_context->color,
+						    &look->style.
+						    color_set.view_color_cursor)))
     {
       _mod_gl_view_flat_cursors_context_clear (utils_context,
 					       cursors_context);
@@ -289,16 +311,14 @@ _mod_gl_view_flat_cursors_context_update (mod_gl_utils_context_t *
     {
       for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
 	{
+	  lw6ker_game_state_get_cursor_by_index (game_state, &cursor, i);
 	  ret = ret
 	    && _mod_gl_view_flat_cursor_context_update (utils_context,
 							&
 							(cursors_context->
 							 cursor[i]),
 							const_data, look,
-							&game_state->
-							map_state.
-							cursor_array.
-							cursors[i]);
+							level, &cursor);
 	}
     }
 
@@ -314,6 +334,10 @@ _mod_gl_view_flat_cursors_context_clear (mod_gl_utils_context_t *
   int ret = 1;
   int i;
 
+  if (cursors_context->bitmap_fg_bg)
+    {
+      mod_gl_utils_bitmap_free (utils_context, cursors_context->bitmap_fg_bg);
+    }
   for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
     {
       ret = ret
