@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -234,6 +234,11 @@ _display_armies (mod_gl_utils_context_t * utils_context,
 		 _mod_gl_view_flat_context_t *
 		 flat_context, lw6gui_look_t * look)
 {
+  lw6sys_whd_t shape;
+
+  lw6ker_game_state_get_shape (flat_context->game_context.armies.game_state,
+			       &shape);
+
   mod_gl_utils_update_game_bitmap_array (utils_context,
 					 &(flat_context->game_context.armies.
 					   armies_bitmap_array),
@@ -241,14 +246,10 @@ _display_armies (mod_gl_utils_context_t * utils_context,
 					 armies.game_state, look);
   _set_fighters_rules (utils_context, flat_context);
   _display_bitmap_array (utils_context, flat_context,
-			 flat_context->game_context.armies.game_state->
-			 map_state.shape.w,
-			 flat_context->game_context.armies.game_state->
-			 map_state.shape.h,
-			 flat_context->game_context.armies.game_state->
-			 map_state.shape.w,
-			 flat_context->game_context.armies.game_state->
-			 map_state.shape.h,
+			 shape.w,
+			 shape.h,
+			 shape.w,
+			 shape.h,
 			 &(flat_context->game_context.armies.
 			   armies_bitmap_array), look);
 }
@@ -266,7 +267,7 @@ _display_map (mod_gl_utils_context_t * utils_context,
 	      lw6ker_game_state_t * game_state,
 	      lw6pil_local_cursors_t * local_cursors)
 {
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("display map"));
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("display map"));
   _display_map_preview (utils_context, flat_context, look,
 			game_state->game_struct->level);
 }
@@ -337,7 +338,7 @@ _display_fighters (mod_gl_utils_context_t * utils_context,
 		   lw6ker_game_state_t * game_state,
 		   lw6pil_local_cursors_t * local_cursors)
 {
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("display fighters"));
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("display fighters"));
   _display_armies (utils_context, flat_context, look);
 }
 
@@ -409,6 +410,13 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
   float cursor_y = 0.0f;
   float cursor_w = 0.0f;
   float cursor_h = 0.0f;
+  float cursor_avg = 0.0f;
+  float text_x1 = 0.0f;
+  float text_y1 = 0.0f;
+  float text_x2 = 0.0f;
+  float text_y2 = 0.0f;
+  float text_dw = 0.0f;
+  float text_dh = 0.0f;
 
   if (local_cursor && local_cursor->is_main && local_cursor->mouse_controlled)
     {
@@ -421,7 +429,7 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
 
   if (local_cursor)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("cursor %x is local"),
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("cursor %x is local"),
 		  local_cursor->cursor_id);
       if (local_cursor->mouse_controlled)
 	{
@@ -442,7 +450,7 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("displaying non-local cursor"));
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("displaying non-local cursor"));
     }
 
   if (cursor_x >= flat_context->viewport.map_visible.x1 &&
@@ -459,14 +467,57 @@ _display_cursor (mod_gl_utils_context_t * utils_context,
 			       flat_context->const_data.cursor_size_min,
 			       flat_context->const_data.cursor_size_max) *
 	look->style.cursor_size;
+      cursor_avg =
+	(utils_context->video_mode.width +
+	 utils_context->video_mode.height) *
+	((flat_context->const_data.cursor_size_min +
+	  flat_context->const_data.cursor_size_max) / 2.0f) *
+	look->style.cursor_size;
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("display cursor %d %0.1f , %0.1f - %0.1f x %0.1f"), i,
+		  _x_ ("display cursor %d %0.1f , %0.1f - %0.1f x %0.1f"), i,
 		  cursor_x, cursor_y, cursor_w, cursor_h);
-      _display_cursor_bitmap (utils_context, flat_context, cursor_x, cursor_y,
-			      cursor_w, cursor_h,
-			      even_odd ? flat_context->cursors_context.
-			      cursor[i].bitmap_even : flat_context->
-			      cursors_context.cursor[i].bitmap_odd);
+      if (even_odd || !look->style.blink_cursor)
+	{
+	  _display_cursor_bitmap (utils_context, flat_context, cursor_x,
+				  cursor_y, cursor_w, cursor_h,
+				  flat_context->cursors_context.bitmap_fg_bg);
+	  _display_cursor_bitmap (utils_context, flat_context, cursor_x,
+				  cursor_y, cursor_w, cursor_h,
+				  flat_context->cursors_context.
+				  cursor[i].bitmap_color);
+	}
+      if (flat_context->cursors_context.cursor[i].
+	  shaded_text_letter->texture_h > 0)
+	{
+	  text_y1 =
+	    cursor_y + (flat_context->const_data.cursor_relative_text_y1 -
+			0.5) * cursor_avg;
+	  text_y2 =
+	    cursor_y + (flat_context->const_data.cursor_relative_text_y2 -
+			0.5) * cursor_avg;
+	  text_x1 =
+	    cursor_x + (flat_context->const_data.cursor_relative_text_x1 -
+			0.5) * cursor_avg;
+	  text_x2 =
+	    text_x1 +
+	    ((text_y2 -
+	      text_y1) *
+	     (flat_context->cursors_context.cursor[i].
+	      shaded_text_letter->texture_w)) /
+	    flat_context->cursors_context.cursor[i].
+	    shaded_text_letter->texture_h;
+	  text_dw =
+	    flat_context->const_data.cursor_relative_text_dw * cursor_avg;
+	  text_dh =
+	    flat_context->const_data.cursor_relative_text_dh * cursor_avg;
+
+	  mod_gl_utils_shaded_text_display (utils_context,
+					    flat_context->
+					    cursors_context.cursor[i].
+					    shaded_text_letter, text_x1,
+					    text_y1, text_x2, text_y2,
+					    text_dw, text_dh);
+	}
     }
 }
 
@@ -478,24 +529,23 @@ _display_cursors (mod_gl_utils_context_t * utils_context,
 		  lw6pil_local_cursors_t * local_cursors)
 {
   int i;
-  lw6ker_cursor_t *cursor;
+  lw6ker_cursor_t cursor;
   lw6pil_local_cursor_t *local_cursor;
   int blink_state;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("display cursors"));
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("display cursors"));
   for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
     {
-      cursor = &(game_state->map_state.cursor_array.cursors[i]);
-      if (cursor->enabled)
+      lw6ker_game_state_get_cursor_by_index (game_state, &cursor, i);
+      if (cursor.enabled)
 	{
 	  local_cursor =
-	    lw6pil_local_cursors_get_cursor (local_cursors,
-					     cursor->cursor_id);
+	    lw6pil_local_cursors_get_cursor (local_cursors, cursor.cursor_id);
 	  blink_state =
 	    lw6sys_math_blink (mod_gl_utils_timer_get_uptime (utils_context),
 			       flat_context->const_data.cursor_blink_period);
 	  _display_cursor (utils_context, flat_context, look, local_cursor, i,
-			   cursor->pos.x, cursor->pos.y, blink_state);
+			   cursor.pos.x, cursor.pos.y, blink_state);
 	}
     }
 }
