@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ _mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
 
   ret = 1;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("init map"));
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("init map"));
   memset (&
 	  (game_context_map->map_bitmap_array), 0,
 	  sizeof (mod_gl_utils_bitmap_array_t));
@@ -111,7 +111,7 @@ _mod_gl_view_flat_game_context_init_map (mod_gl_utils_context_t *
     {
 
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to init game_context (map) for flat backend"));
+		  _x_ ("unable to init game_context (map) for flat backend"));
     }
 
   return ret;
@@ -132,7 +132,7 @@ _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t *
 
   ret = 1;
 
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("init armies"));
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("init armies"));
 
   game_struct = game_state->game_struct;
 
@@ -141,8 +141,8 @@ _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t *
 				       &
 				       (game_context_armies->
 					armies_bitmap_array),
-				       game_struct->map_struct.shape.w,
-				       game_struct->map_struct.shape.h,
+				       lw6ker_game_struct_get_w (game_struct),
+				       lw6ker_game_struct_get_h (game_struct),
 				       flat_context->const_data.
 				       tile_size_armies);
 
@@ -152,7 +152,8 @@ _mod_gl_view_flat_game_context_init_armies (mod_gl_utils_context_t *
   if (!ret)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to init game_context (armies) for flat backend"));
+		  _x_
+		  ("unable to init game_context (armies) for flat backend"));
     }
 
   return ret;
@@ -284,7 +285,7 @@ _mod_gl_view_flat_game_context_update_armies (mod_gl_utils_context_t *
       if (game_context_armies->game_state != game_state)
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _
+		      _x_
 		      ("game_state is changed while game_struct remains the same, there's nothing wrong with that but not synchronizing the game_state in this special case has caused a historical, hard to track bug, so it's worth noting it"));
 	  game_context_armies->game_state = game_state;
 	}
