@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -53,14 +53,16 @@ typedef struct _mod_gl_view_flat_cursor_context_s
   u_int16_t cursor_id;
   char letter;
   int team_color;
-  mod_gl_utils_bitmap_t *bitmap_even;
-  mod_gl_utils_bitmap_t *bitmap_odd;
+  mod_gl_utils_bitmap_t *bitmap_color;
+  mod_gl_utils_shaded_text_t *shaded_text_letter;
 }
 _mod_gl_view_flat_cursor_context_t;
 
 typedef struct _mod_gl_view_flat_cursors_context_s
 {
+  u_int32_t level_id;
   lw6map_color_couple_t color;
+  mod_gl_utils_bitmap_t *bitmap_fg_bg;
   _mod_gl_view_flat_cursor_context_t cursor[LW6MAP_MAX_NB_CURSORS];
 }
 _mod_gl_view_flat_cursors_context_t;
@@ -73,32 +75,21 @@ typedef struct _mod_gl_view_flat_const_data_s
   int scroll_min_offset;
   int cursor_blink_period;
   int cursor_heartbeat_period;
-  int cursor_texture_size;
-  int cursor_border_width;
-  int cursor_blur_width;
+  float cursor_relative_text_y1;
+  float cursor_relative_text_y2;
+  float cursor_relative_text_x1;
+  float cursor_relative_text_dw;
+  float cursor_relative_text_dh;
   int tile_size_map;
   int tile_size_armies;
 }
 _mod_gl_view_flat_const_data_t;
 
-/*
-typedef struct _mod_gl_view_flat_smoothers_s
-{
-  //float last_zoom;
-  //int last_center_x;
-  //int last_center_y;
-  lw6gui_smoother_t center_x;
-  lw6gui_smoother_t center_y;
-}
-_mod_gl_view_flat_smoothers_t;
-*/
-
 typedef struct _mod_gl_view_flat_context_s
 {
   _mod_gl_view_flat_game_context_t game_context;
   _mod_gl_view_flat_cursors_context_t cursors_context;
   _mod_gl_view_flat_const_data_t const_data;
-  //_mod_gl_view_flat_smoother_t smoothers;
   lw6gui_viewport_t viewport;
 }
 _mod_gl_view_flat_context_t;
@@ -113,6 +104,7 @@ extern int _mod_gl_view_flat_cursor_context_init (mod_gl_utils_context_t *
 						  _mod_gl_view_flat_const_data_t
 						  * const_data,
 						  lw6gui_look_t * look,
+						  lw6map_level_t * level,
 						  lw6ker_cursor_t * cursor);
 extern int _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
 						    utils_context,
@@ -121,6 +113,7 @@ extern int _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
 						    _mod_gl_view_flat_const_data_t
 						    * const_data,
 						    lw6gui_look_t * look,
+						    lw6map_level_t * level,
 						    lw6ker_cursor_t * cursor);
 extern int _mod_gl_view_flat_cursor_context_clear (mod_gl_utils_context_t *
 						   utils_context,
