@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -89,14 +89,22 @@ _mod_gl_view_flat_viewport_update (mod_gl_utils_context_t *
   lw6gui_viewport_t test;
   float test_cursor_x = 0.0f;
   float test_cursor_y = 0.0f;
-  int main_cursor_x = game_state->map_state.shape.w / 2;
-  int main_cursor_y = game_state->map_state.shape.h / 2;
+  int main_cursor_x;
+  int main_cursor_y;
   float dw, dh;
+  lw6sys_whd_t shape;
 
-  if (!lw6pil_local_cursors_get_main_info
-      (local_cursors, NULL, &main_cursor_x, &main_cursor_y, NULL))
+  lw6ker_game_state_get_shape (game_state, &shape);
+  main_cursor_x = shape.w / 2;
+  main_cursor_y = shape.h / 2;
+
+  if (local_cursors)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("no main cursor"));
+      if (!lw6pil_local_cursors_get_main_info
+	  (local_cursors, NULL, &main_cursor_x, &main_cursor_y, NULL))
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("no main cursor"));
+	}
     }
 
   global_zoom = look->dynamic_zoom * look->style.zoom;
@@ -114,8 +122,8 @@ _mod_gl_view_flat_viewport_update (mod_gl_utils_context_t *
 			utils_context->smoothed.drawable.y2,
 			utils_context->smoothed.center_x,
 			utils_context->smoothed.center_y,
-			game_state->map_state.shape.w,
-			game_state->map_state.shape.h,
+			shape.w,
+			shape.h,
 			game_state->game_struct->rules.x_polarity,
 			game_state->game_struct->rules.y_polarity,
 			look->style.x_wrap,
@@ -150,8 +158,8 @@ _mod_gl_view_flat_viewport_update (mod_gl_utils_context_t *
 			utils_context->smoothed.drawable.y2,
 			utils_context->smoothed.center_x,
 			utils_context->smoothed.center_y,
-			game_state->map_state.shape.w,
-			game_state->map_state.shape.h,
+			shape.w,
+			shape.h,
 			game_state->game_struct->rules.x_polarity,
 			game_state->game_struct->rules.y_polarity,
 			look->style.x_wrap,
