@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,11 +47,11 @@ lw6gui_input_init (lw6gui_input_t * input)
   if (input->keyboard.queue)
     {
       ret = 1;
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("new input queue created"));
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("new input queue created"));
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to initialize input"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to initialize input"));
     }
 
   return ret;
@@ -120,7 +120,7 @@ lw6gui_input_free (lw6gui_input_t * input)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL input"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL input"));
     }
 }
 
@@ -138,12 +138,9 @@ int
 lw6gui_input_reset (lw6gui_input_t * input)
 {
   int ret = 0;
-  int quit = 0;
 
-  quit = input->quit;
   lw6gui_input_quit (input);
   ret = lw6gui_input_init (input);
-  input->quit = quit;		// quit is never resetted
 
   return ret;
 }
@@ -235,7 +232,6 @@ lw6gui_input_sync (lw6gui_input_t * dst, lw6gui_input_t * src)
   int ret = 1;
   int i = 0;
 
-  dst->quit = src->quit || dst->quit;	// quit never becomes 0 again
   dst->need_sync = src->need_sync;
   src->need_sync = 0;		// we've been synced, need to reset the flag
   ret = lw6gui_keyboard_sync (&(dst->keyboard), &(src->keyboard)) && ret;
@@ -248,39 +244,3 @@ lw6gui_input_sync (lw6gui_input_t * dst, lw6gui_input_t * src)
 
   return ret;
 }
-
-/**
- * lw6gui_input_poll_quit
- *
- * @input: the input to query
- *
- * Asks the display manager wether a quit event (usually CTRL-C or
- * click on close button) has been detected.
- *
- * Return value: 1 if quit was receivedm 0 if not
- */
-int
-lw6gui_input_poll_quit (lw6gui_input_t * input)
-{
-  int ret = 0;
-
-  ret = input->quit;
-
-  return ret;
-}
-
-/**
- * lw6gui_input_send_quit
- *
- * @input: the input to send an event to
- *
- * Artificially send a QUIT event (equivalent of CTRL-C or click on close
- * button). This allow a uniform treatment of game stopping.
- *
- * Return value: none
- */
-void
-lw6gui_input_send_quit (lw6gui_input_t * input)
-{
-  input->quit = 1;
-}
