@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,7 +47,8 @@ lw6gui_joystick_check_index (int i)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("joystick index %d out of range"), i);
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("joystick index %d out of range"),
+		  i);
     }
 
   return ret;
