@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -83,7 +83,7 @@ lw6gui_keypress_free (lw6gui_keypress_t * keypress)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL keypress"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL keypress"));
     }
 }
 
@@ -106,7 +106,7 @@ lw6gui_keypress_repr (lw6gui_keypress_t * keypress)
       if (keypress->unicode >= 32 && keypress->unicode <= 127)
 	{
 	  ret =
-	    lw6sys_new_sprintf (_
+	    lw6sys_new_sprintf (_x_
 				("keypress keysym=%d ascii=%d ('%c') label=\"%s\""),
 				keypress->keysym, keypress->unicode,
 				keypress->unicode, keypress->label);
@@ -114,7 +114,7 @@ lw6gui_keypress_repr (lw6gui_keypress_t * keypress)
       else
 	{
 	  ret =
-	    lw6sys_new_sprintf (_
+	    lw6sys_new_sprintf (_x_
 				("keypress keysym=%d unicode=%d label=\"%s\""),
 				keypress->keysym, keypress->unicode,
 				keypress->label);
@@ -123,7 +123,7 @@ lw6gui_keypress_repr (lw6gui_keypress_t * keypress)
   else
     {
       ret =
-	lw6sys_new_sprintf (_("keypress keysym=%d unicode=%d label=NULL"),
+	lw6sys_new_sprintf (_x_ ("keypress keysym=%d unicode=%d label=NULL"),
 			    keypress->keysym, keypress->unicode);
     }
 
