@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -108,7 +108,7 @@ lw6gui_menu_free (lw6gui_menu_t * menu)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("menu with NULL title"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menu with NULL title"));
 	}
 
       if (menu->esc_item)
@@ -127,7 +127,7 @@ lw6gui_menu_free (lw6gui_menu_t * menu)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL menu"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL menu"));
     }
 }
 
@@ -160,7 +160,7 @@ lw6gui_menu_memory_footprint (lw6gui_menu_t * menu)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("calling memory_footprint on NULL menu"));
+		  _x_ ("calling memory_footprint on NULL menu"));
     }
 
   return memory_footprint;
@@ -184,8 +184,8 @@ lw6gui_menu_repr (lw6gui_menu_t * menu)
   char *repr;
 
   repr =
-    lw6sys_new_sprintf (_("%u \"%s\" (nb_items=%d)"), menu->id, menu->title,
-			menu->nb_items);
+    lw6sys_new_sprintf (_x_ ("%u \"%s\" (nb_items=%d)"), menu->id,
+			menu->title, menu->nb_items);
 
   return repr;
 }
@@ -211,7 +211,7 @@ lw6gui_menu_set_title (lw6gui_menu_t * menu, char *title)
   if (!(menu->title))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("couldn't set menu title \"%s\""), title);
+		  _x_ ("couldn't set menu title \"%s\""), title);
     }
 }
 
@@ -238,7 +238,8 @@ lw6gui_menu_get_item (lw6gui_menu_t * menu, int position)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("requesting menuitem %d but there are only %d in \"%s\""),
+		  _x_
+		  ("requesting menuitem %d but there are only %d in \"%s\""),
 		  position, menu->nb_items, menu->title);
     }
 
@@ -280,7 +281,7 @@ lw6gui_menu_select (lw6gui_menu_t * menu, int position, int allow_scroll,
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("menu select out of range (%d/%d)"), position,
+		      _x_ ("menu select out of range (%d/%d)"), position,
 		      menu->nb_items);
 	}
     }
@@ -460,7 +461,7 @@ lw6gui_menu_insert (lw6gui_menu_t * menu, lw6gui_menuitem_t * menuitem,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("trying to insert menuitem \"%s\" at position %d but menu \"%s\" has only %d items"),
 		  menu->title, position, menu->nb_items, menu->title,
 		  menu->nb_items);
@@ -555,7 +556,7 @@ lw6gui_menu_remove (lw6gui_menu_t * menu, int position, int64_t now)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("trying to remove menuitem \"%s\" at position %d but menu \"%s\" has only %d items"),
 		  menu->title, position, menu->nb_items, menu->title,
 		  menu->nb_items);
@@ -729,7 +730,7 @@ get_position_using_id (lw6gui_menu_t * menu, int id)
   if (ret < 0)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("error, no menuitem with id %d in menu %d \"%s\""), id,
+		  _x_ ("error, no menuitem with id %d in menu %d \"%s\""), id,
 		  menu->id, menu->title);
     }
 
@@ -998,14 +999,14 @@ lw6gui_menu_sync (lw6gui_menu_t * dst, lw6gui_menu_t * src)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _
+		      _x_
 		      ("unable to sync menus, dst has %d items while src has %d items"),
 		      dst->nb_items, src->nb_items);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("menus are not syncable"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("menus are not syncable"));
     }
 
   return ret;
