@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -193,14 +193,15 @@ lw6gui_video_mode_sync_ratio (lw6gui_video_mode_t * dst,
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("can't handle dst resolution %dx%d"), dst->width > 0
-		      && dst->height > 0);
+		      _x_ ("can't handle dst resolution %dx%d"),
+		      dst->width > 0 && dst->height > 0);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("can't handle src resolution %dx%d"),
-		  src->width > 0 && src->height > 0);
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("can't handle src resolution %dx%d"), src->width > 0
+		  && src->height > 0);
     }
 
   return ret;
