@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include "ker-internal.h"
 
 void
-_lw6ker_cursor_array_init (lw6ker_cursor_array_t * cursor_array)
+_lw6ker_cursor_array_init (_lw6ker_cursor_array_t * cursor_array)
 {
   int i = 0;
 
@@ -42,7 +42,7 @@ _lw6ker_cursor_array_init (lw6ker_cursor_array_t * cursor_array)
 }
 
 void
-_lw6ker_cursor_array_update_checksum (lw6ker_cursor_array_t *
+_lw6ker_cursor_array_update_checksum (_lw6ker_cursor_array_t *
 				      cursor_array, u_int32_t * checksum)
 {
   int i = 0;
@@ -55,7 +55,7 @@ _lw6ker_cursor_array_update_checksum (lw6ker_cursor_array_t *
 }
 
 lw6ker_cursor_t *
-_lw6ker_cursor_array_find_free (lw6ker_cursor_array_t * cursor_array)
+_lw6ker_cursor_array_find_free (_lw6ker_cursor_array_t * cursor_array)
 {
   lw6ker_cursor_t *ret = NULL;
   int i;
@@ -70,14 +70,14 @@ _lw6ker_cursor_array_find_free (lw6ker_cursor_array_t * cursor_array)
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_DEBUG, _("unable to find free cursor"));
+      lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("unable to find free cursor"));
     }
 
   return ret;
 }
 
 int
-_lw6ker_cursor_array_is_color_owned_by (lw6ker_cursor_array_t * cursor_array,
+_lw6ker_cursor_array_is_color_owned_by (_lw6ker_cursor_array_t * cursor_array,
 					u_int64_t node_id, int team_color)
 {
   int ret = 1;
@@ -91,7 +91,7 @@ _lw6ker_cursor_array_is_color_owned_by (lw6ker_cursor_array_t * cursor_array,
 	{
 	  // this team_color is owned at least one by another node
 	  lw6sys_log (LW6SYS_LOG_NOTICE,
-		      _("color %d owned by %" LW6SYS_PRINTF_LL "x"),
+		      _x_ ("color %d owned by %" LW6SYS_PRINTF_LL "x"),
 		      team_color, node_id);
 	  ret = 0;
 	}
@@ -101,20 +101,20 @@ _lw6ker_cursor_array_is_color_owned_by (lw6ker_cursor_array_t * cursor_array,
 }
 
 void
-_lw6ker_cursor_array_reset (lw6ker_cursor_array_t * cursor_array)
+_lw6ker_cursor_array_reset (_lw6ker_cursor_array_t * cursor_array)
 {
   int i;
 
   cursor_array->nb_cursors = 0;
   for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
     {
-      _lw6ker_cursor_reset (&(cursor_array->cursors[i]));
+      lw6ker_cursor_reset (&(cursor_array->cursors[i]));
     }
 }
 
 lw6ker_cursor_t *
-lw6ker_cursor_array_get (lw6ker_cursor_array_t *
-			 cursor_array, u_int16_t cursor_id)
+_lw6ker_cursor_array_get (_lw6ker_cursor_array_t *
+			  cursor_array, u_int16_t cursor_id)
 {
   lw6ker_cursor_t *ret = NULL;
   int i;
@@ -131,21 +131,22 @@ lw6ker_cursor_array_get (lw6ker_cursor_array_t *
 }
 
 int
-lw6ker_cursor_array_enable (lw6ker_cursor_array_t * cursor_array,
-			    u_int64_t node_id,
-			    u_int16_t cursor_id, int team_color,
-			    int32_t x, int32_t y)
+_lw6ker_cursor_array_enable (_lw6ker_cursor_array_t * cursor_array,
+			     u_int64_t node_id,
+			     u_int16_t cursor_id, int team_color,
+			     int32_t x, int32_t y)
 {
   int ret = 0;
   lw6ker_cursor_t *cursor;
 
-  cursor = lw6ker_cursor_array_get (cursor_array, cursor_id);
+  cursor = _lw6ker_cursor_array_get (cursor_array, cursor_id);
   if (!cursor)
     {
       cursor = _lw6ker_cursor_array_find_free (cursor_array);
       if (cursor)
 	{
-	  lw6ker_cursor_enable (cursor, node_id, cursor_id, team_color, x, y);
+	  _lw6ker_cursor_enable (cursor, node_id, cursor_id, team_color, x,
+				 y);
 	  cursor_array->nb_cursors++;
 	  ret = 1;
 	}
@@ -153,7 +154,7 @@ lw6ker_cursor_array_enable (lw6ker_cursor_array_t * cursor_array,
   else
     {
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("cursor %x already exists, can't enable it twice"),
+		  _x_ ("cursor %x already exists, can't enable it twice"),
 		  cursor_id);
     }
 
@@ -161,18 +162,18 @@ lw6ker_cursor_array_enable (lw6ker_cursor_array_t * cursor_array,
 }
 
 int
-lw6ker_cursor_array_disable (lw6ker_cursor_array_t * cursor_array,
-			     u_int64_t node_id, u_int16_t cursor_id)
+_lw6ker_cursor_array_disable (_lw6ker_cursor_array_t * cursor_array,
+			      u_int64_t node_id, u_int16_t cursor_id)
 {
   int ret = 0;
   lw6ker_cursor_t *cursor;
 
-  cursor = lw6ker_cursor_array_get (cursor_array, cursor_id);
+  cursor = _lw6ker_cursor_array_get (cursor_array, cursor_id);
   if (cursor)
     {
       if (_lw6ker_cursor_check_node_id (cursor, node_id))
 	{
-	  lw6ker_cursor_disable (cursor);
+	  _lw6ker_cursor_disable (cursor);
 	  cursor_array->nb_cursors--;
 	  ret = 1;
 	}
@@ -180,7 +181,7 @@ lw6ker_cursor_array_disable (lw6ker_cursor_array_t * cursor_array,
   else
     {
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("cursor %x already does not exist, can't disable it"),
+		  _x_ ("cursor %x already does not exist, can't disable it"),
 		  cursor_id);
     }
 
@@ -188,30 +189,31 @@ lw6ker_cursor_array_disable (lw6ker_cursor_array_t * cursor_array,
 }
 
 int
-lw6ker_cursor_array_update (lw6ker_cursor_array_t * cursor_array,
-			    u_int64_t node_id,
-			    u_int16_t cursor_id, int32_t x,
-			    int32_t y, int32_t pot_offset,
-			    lw6sys_whd_t * shape, lw6map_rules_t * rules)
+_lw6ker_cursor_array_update (_lw6ker_cursor_array_t * cursor_array,
+			     u_int64_t node_id,
+			     u_int16_t cursor_id, int32_t x,
+			     int32_t y, int32_t pot_offset,
+			     lw6sys_whd_t * shape, lw6map_rules_t * rules)
 {
   int ret = 0;
   lw6ker_cursor_t *cursor;
 
   lw6sys_log (LW6SYS_LOG_DEBUG,
-	      _("cursor array update %" LW6SYS_PRINTF_LL "x %x %d %d %d"),
+	      _x_ ("cursor array update %" LW6SYS_PRINTF_LL "x %x %d %d %d"),
 	      node_id, cursor_id, x, y, pot_offset);
-  cursor = lw6ker_cursor_array_get (cursor_array, cursor_id);
+  cursor = _lw6ker_cursor_array_get (cursor_array, cursor_id);
   if (cursor)
     {
       if (_lw6ker_cursor_check_node_id (cursor, node_id))
 	{
-	  ret = lw6ker_cursor_update (cursor, x, y, pot_offset, shape, rules);
+	  ret =
+	    _lw6ker_cursor_update (cursor, x, y, pot_offset, shape, rules);
 	}
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _("cursor %x already does not exist, can't update it"),
+		  _x_ ("cursor %x already does not exist, can't update it"),
 		  cursor_id);
     }
 
@@ -219,9 +221,9 @@ lw6ker_cursor_array_update (lw6ker_cursor_array_t * cursor_array,
 }
 
 int
-lw6ker_cursor_array_sanity_check (lw6ker_cursor_array_t * cursor_array,
-				  lw6sys_whd_t * shape,
-				  lw6map_rules_t * rules)
+_lw6ker_cursor_array_sanity_check (_lw6ker_cursor_array_t * cursor_array,
+				   lw6sys_whd_t * shape,
+				   lw6map_rules_t * rules)
 {
   int ret = 1;
   int i;
@@ -230,8 +232,8 @@ lw6ker_cursor_array_sanity_check (lw6ker_cursor_array_t * cursor_array,
   for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
     {
       ret = ret
-	&& lw6ker_cursor_sanity_check (&(cursor_array->cursors[i]), shape,
-				       rules);
+	&& _lw6ker_cursor_sanity_check (&(cursor_array->cursors[i]), shape,
+					rules);
       if (cursor_array->cursors[i].enabled)
 	{
 	  found++;
@@ -240,7 +242,7 @@ lw6ker_cursor_array_sanity_check (lw6ker_cursor_array_t * cursor_array,
   if (found != cursor_array->nb_cursors)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("inconsistency in cursor_array, found %d cursors but array reports %d"),
 		  found, cursor_array->nb_cursors);
       ret = 0;
