@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 
 #if LW6_GPROF || LW6_INSTRUMENT || LW6_PROFILER
 #define _CALL_IS_SLOT_FREE(A,B,C,D,E) _lw6ker_move_is_slot_free((A),(B),(C),(D),(E))
-#define _CALL_IS_ENEMY_THERE(A,B,C,D,E,F) _lw6ker_move_is_enemy_there((A),(B),(C),(D),(E),(F))
+#define _CALL_IS_ENEMY_THERE(A,B,C,D,E,F,G,H) _lw6ker_move_is_enemy_there((A),(B),(C),(D),(E),(F),(G),(H))
 #define _CALL_IS_ALLY_THERE(A,B,C,D,E,F) _lw6ker_move_is_ally_there((A),(B),(C),(D),(E),(F))
 #define _CALL_FIND_STRAIGHT_DIR(A,B,C,D) _lw6ker_move_find_straight_dir((A),(B),(C),(D))
 #define _CALL_FIND_BEST_DIR(A,B,C) _lw6ker_move_find_best_dir((A),(B),(C))
@@ -42,7 +42,7 @@
 #define _CALL_ADJUST_HEALTH(A,B) _lw6ker_move_adjust_health((A),(B))
 #else
 #define _CALL_IS_SLOT_FREE(A,B,C,D,E) _is_slot_free((A),(B),(C),(D),(E))
-#define _CALL_IS_ENEMY_THERE(A,B,C,D,E,F) _is_enemy_there((A),(B),(C),(D),(E),(F))
+#define _CALL_IS_ENEMY_THERE(A,B,C,D,E,F,G,H) _is_enemy_there((A),(B),(C),(D),(E),(F),(G),(H))
 #define _CALL_IS_ALLY_THERE(A,B,C,D,E,F) _is_ally_there((A),(B),(C),(D),(E),(F))
 #define _CALL_FIND_STRAIGHT_DIR(A,B,C,D) _find_straight_dir((A),(B),(C),(D))
 #define _CALL_FIND_BEST_DIR(A,B,C) _find_best_dir((A),(B),(C))
@@ -53,8 +53,8 @@
 #endif
 
 static inline int
-_is_slot_free (lw6ker_map_struct_t * map_struct,
-	       lw6ker_map_state_t * map_state, int32_t x, int32_t y,
+_is_slot_free (_lw6ker_map_struct_t * map_struct,
+	       _lw6ker_map_state_t * map_state, int32_t x, int32_t y,
 	       int32_t z)
 {
   /*
@@ -63,36 +63,35 @@ _is_slot_free (lw6ker_map_struct_t * map_struct,
    * more rare that free spaces, so the test will return false faster
    * and do not even call get_zone_id.
    */
-  return (lw6ker_map_state_get_fighter_id (map_state, x, y, z) < 0 &&
-	  lw6ker_map_struct_get_zone_id (map_struct, x, y, z) >= 0);
+  return (_lw6ker_map_state_get_fighter_id (map_state, x, y, z) < 0 &&
+	  _lw6ker_map_struct_get_zone_id (map_struct, x, y, z) >= 0);
 }
 
 int
-_lw6ker_move_is_slot_free (lw6ker_map_struct_t * map_struct,
-			   lw6ker_map_state_t * map_state, int32_t x,
+_lw6ker_move_is_slot_free (_lw6ker_map_struct_t * map_struct,
+			   _lw6ker_map_state_t * map_state, int32_t x,
 			   int32_t y, int32_t z)
 {
   return _is_slot_free (map_struct, map_state, x, y, z);
 }
 
 static inline int
-_is_enemy_there (lw6ker_map_struct_t * map_struct,
-		 lw6ker_map_state_t * map_state, int32_t team_color,
-		 int32_t x, int32_t y, int32_t z)
+_is_enemy_there (_lw6ker_map_struct_t * map_struct,
+		 _lw6ker_map_state_t * map_state, int32_t team_color,
+		 int32_t x, int32_t y, int32_t z, int32_t * enemy_id,
+		 int32_t * enemy_color)
 {
   int ret = 0;
 
 #ifdef LW6_PARANOID
-  if (lw6ker_map_struct_get_zone_id (map_struct, x, y, z) >= 0)
+  if (_lw6ker_map_struct_get_zone_id (map_struct, x, y, z) >= 0)
     {
 #endif // LW6_PARANOID
-      int32_t enemy_id;
-
-      enemy_id = lw6ker_map_state_get_fighter_id (map_state, x, y, z);
-      if (enemy_id >= 0)
+      *enemy_id = _lw6ker_map_state_get_fighter_id (map_state, x, y, z);
+      if (*enemy_id >= 0)
 	{
-	  ret =
-	    (map_state->armies.fighters[enemy_id].team_color != team_color);
+	  (*enemy_color) = map_state->armies.fighters[*enemy_id].team_color;
+	  ret = (*enemy_color != team_color);
 	}
 #ifdef LW6_PARANOID
     }
@@ -102,29 +101,31 @@ _is_enemy_there (lw6ker_map_struct_t * map_struct,
 }
 
 int
-_lw6ker_move_is_enemy_there (lw6ker_map_struct_t * map_struct,
-			     lw6ker_map_state_t * map_state,
+_lw6ker_move_is_enemy_there (_lw6ker_map_struct_t * map_struct,
+			     _lw6ker_map_state_t * map_state,
 			     int32_t team_color, int32_t x, int32_t y,
-			     int32_t z)
+			     int32_t z, int32_t * enemy_id,
+			     int32_t * enemy_color)
 {
-  return _is_enemy_there (map_struct, map_state, team_color, x, y, z);
+  return _is_enemy_there (map_struct, map_state, team_color, x, y, z,
+			  enemy_id, enemy_color);
 }
 
 static inline int
-_is_ally_there (lw6ker_map_struct_t * map_struct,
-		lw6ker_map_state_t * map_state, int32_t team_color, int32_t x,
-		int32_t y, int32_t z)
+_is_ally_there (_lw6ker_map_struct_t * map_struct,
+		_lw6ker_map_state_t * map_state, int32_t team_color,
+		int32_t x, int32_t y, int32_t z)
 {
   int ret = 0;
 
 #ifdef LW6_PARANOID
-  if (lw6ker_map_struct_get_zone_id (map_struct, x, y, z) >= 0)
+  if (_lw6ker_map_struct_get_zone_id (map_struct, x, y, z) >= 0)
     {
 #endif // LW6_PARANOID
 
       int32_t ally_id;
 
-      ally_id = lw6ker_map_state_get_fighter_id (map_state, x, y, z);
+      ally_id = _lw6ker_map_state_get_fighter_id (map_state, x, y, z);
       if (ally_id >= 0)
 	{
 	  ret =
@@ -138,8 +139,8 @@ _is_ally_there (lw6ker_map_struct_t * map_struct,
 }
 
 int
-_lw6ker_move_is_ally_there (lw6ker_map_struct_t * map_struct,
-			    lw6ker_map_state_t * map_state,
+_lw6ker_move_is_ally_there (_lw6ker_map_struct_t * map_struct,
+			    _lw6ker_map_state_t * map_state,
 			    int32_t team_color, int32_t x, int32_t y,
 			    int32_t z)
 {
@@ -185,14 +186,14 @@ _lw6ker_move_find_straight_dir (int from_x, int from_y, lw6sys_xyz_t to,
  * Higher potential = closer to the cursor
  */
 static inline int32_t
-_find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
+_find_best_dir (_lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
 		int parity)
 {
   int32_t ret = fighter->last_direction;
   int32_t zone_id =
-    lw6ker_map_struct_get_zone_id (map_state->map_struct, fighter->pos.x,
-				   fighter->pos.y, fighter->pos.z);
-  lw6ker_zone_state_t *zone_states =
+    _lw6ker_map_struct_get_zone_id (map_state->map_struct, fighter->pos.x,
+				    fighter->pos.y, fighter->pos.z);
+  _lw6ker_zone_state_t *zone_states =
     map_state->teams[fighter->team_color].gradient;
 
   if (zone_id >= 0)
@@ -210,9 +211,9 @@ _find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
 	   * Nothing in cache, we calculate it
 	   */
 	  int32_t i;
-	  lw6ker_zone_struct_t *zone_structs = map_state->map_struct->zones;
+	  _lw6ker_zone_struct_t *zone_structs = map_state->map_struct->zones;
 	  int32_t neighbour_zone_id;
-	  lw6ker_zone_struct_t *fighter_zone_struct;
+	  _lw6ker_zone_struct_t *fighter_zone_struct;
 	  fighter_zone_struct = &(zone_structs[zone_id]);
 	  int32_t best_potential = zone_states[zone_id].potential;
 
@@ -299,7 +300,7 @@ _find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("fighter with incorrect zone_id=%d (pos=%d,%d,%d)"),
+		  _x_ ("fighter with incorrect zone_id=%d (pos=%d,%d,%d)"),
 		  zone_id, (int) fighter->pos.x, (int) fighter->pos.y,
 		  (int) fighter->pos.z);
     }
@@ -308,7 +309,7 @@ _find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
 }
 
 int32_t
-_lw6ker_move_find_best_dir (lw6ker_map_state_t * map_state,
+_lw6ker_move_find_best_dir (_lw6ker_map_state_t * map_state,
 			    lw6ker_fighter_t * fighter, int parity)
 {
   return _find_best_dir (map_state, fighter, parity);
@@ -431,10 +432,22 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
       if (lw6ker_team_mask_is_concerned (lc.fighter_team_color, lc.team_mask))
 	{
 	  lc.place_struct =
-	    &lc.map_struct->places[lw6ker_map_struct_place_index
+	    &lc.map_struct->places[_lw6ker_map_struct_place_index
 				   (lc.map_struct, lc.fighter->pos.x,
 				    lc.fighter->pos.y)];
-	  lc.fighter->act_counter += lc.place_struct->act_incr;
+	  /*
+	   * We increment the act_counter. Depending on game rules, we might
+	   * decide to change the default value (which can already depend
+	   * on the map boost/glue settings) according to the specific
+	   * team speed (profile_fast parameter).
+	   */
+	  lc.fighter->act_counter +=
+	    lc.rules.use_team_profiles ? lw6ker_percent (lc.
+							 place_struct->act_incr,
+							 lc.
+							 rules.team_profile_fast
+							 [lc.fighter_team_color])
+	    : lc.place_struct->act_incr;
 	  while (lc.fighter->act_counter >= LW6KER_ACT_LIMIT)
 	    {
 	      lc.fighter->act_counter -= LW6KER_ACT_LIMIT;
@@ -455,7 +468,10 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
 
 	      if (lc.shape.d <= 1)
 		{
-		  for (lc.j = 0; lc.j < lc.rules.nb_move_tries; ++lc.j)
+		  for (lc.j = 0;
+		       lc.j <
+		       lc.per_team_nb_move_tries[lc.fighter_team_color];
+		       ++lc.j)
 		    {
 		      lc.test_dir = lc.move_dir_table[lc.j];
 		      _CALL_GOTO_WITH_DIR_XY (&(lc.rules), &lc.shape,
@@ -476,7 +492,10 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
 		}
 	      else
 		{
-		  for (lc.j = 0; lc.j < lc.rules.nb_move_tries; ++lc.j)
+		  for (lc.j = 0;
+		       lc.j <
+		       lc.per_team_nb_move_tries[lc.fighter_team_color];
+		       ++lc.j)
 		    {
 		      lc.test_dir = lc.move_dir_table[lc.j];
 		      _CALL_GOTO_WITH_DIR (&(lc.rules), &lc.shape, &lc.x,
@@ -536,7 +555,10 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
 
 	      if (!lc.done_with_fighter)
 		{
-		  for (lc.j = 0; lc.j < lc.rules.nb_attack_tries; ++lc.j)
+		  for (lc.j = 0;
+		       lc.j <
+		       lc.per_team_nb_attack_tries[lc.fighter_team_color];
+		       ++lc.j)
 		    {
 		      lc.test_dir = lc.move_dir_table[lc.j];
 		      _CALL_GOTO_WITH_DIR_XY (&lc.rules, &lc.shape, &lc.x,
@@ -544,16 +566,19 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
 					      lc.fighter_y, lc.test_dir);
 		      if (_CALL_IS_ENEMY_THERE
 			  (lc.map_struct, lc.map_state, lc.fighter_team_color,
-			   lc.x, lc.y, lc.z))
+			   lc.x, lc.y, lc.z, &lc.enemy_id, &lc.enemy_color))
 			{
 			  lc.done_with_fighter = 1;
 			  _lw6ker_fighter_attack (lc.fighter,
 						  lc.x, lc.y, lc.z,
 						  lc.map_state,
 						  lc.j ==
-						  0 ? lc.rules.
-						  fighter_attack : lc.
-						  fighter_side_attack,
+						  0 ? lc.fighter_attack
+						  [lc.fighter_team_color]
+						  [lc.enemy_color] :
+						  lc.fighter_side_attack
+						  [lc.fighter_team_color]
+						  [lc.enemy_color],
 						  lc.rules.
 						  fighter_new_health);
 			  break;
@@ -563,7 +588,10 @@ _lw6ker_move_update_fighters_universal (_lw6ker_move_context_t * context)
 
 	      if (!lc.done_with_fighter)
 		{
-		  for (lc.j = 0; lc.j < lc.rules.nb_defense_tries; ++lc.j)
+		  for (lc.j = 0;
+		       lc.j <
+		       lc.per_team_nb_defense_tries[lc.fighter_team_color];
+		       ++lc.j)
 		    {
 		      lc.test_dir = lc.move_dir_table[lc.j];
 		      _CALL_GOTO_WITH_DIR_XY (&lc.rules, &lc.shape, &lc.x,
