@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -70,14 +70,14 @@ _lw6ker_spread_next_dir (int32_t dir)
  * Highest potential = closest to the cursor
  */
 void
-_lw6ker_spread_update_gradient (lw6ker_team_t * team, int skip_vertical)
+_lw6ker_spread_update_gradient (_lw6ker_team_t * team, int skip_vertical)
 {
   int32_t i;
   int32_t n;
   int32_t zone_id;
   int32_t new_potential;
-  lw6ker_zone_struct_t *zone_structs;
-  lw6ker_zone_state_t *zone_states;
+  _lw6ker_zone_struct_t *zone_structs;
+  _lw6ker_zone_state_t *zone_states;
   int32_t dir;
 
   n = team->map_struct->nb_zones;
@@ -159,7 +159,7 @@ _lw6ker_spread_update_gradient (lw6ker_team_t * team, int skip_vertical)
       break;
     default:
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to spread gradient, incorrect dir=%d"), dir);
+		  _x_ ("unable to spread gradient, incorrect dir=%d"), dir);
       break;
     }
 }
