@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -31,10 +31,10 @@
 #define TEST_MAP_NB_LAYERS 5
 #define TEST_MAP_NOISE_PERCENT 20
 #define TEST_NB_ROUNDS 100
-#define TEST_GAME_STRUCT_CHECKSUM 0xbcc67d4d
-#define TEST_GAME_STATE_CHECKSUM 0xa3c8ad4d
-#define TEST_GAME_STATE_POPULATE_CHECKSUM 0xf714c77c
-#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x4c403a8c
+#define TEST_GAME_STRUCT_CHECKSUM 0x1acceb44
+#define TEST_GAME_STATE_CHECKSUM 0x96e97c98
+#define TEST_GAME_STATE_POPULATE_CHECKSUM 0xc23516a9
+#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0x331c5e34
 #define TEST_NODE_ID 0x1234123412341234LL
 #define TEST_CURSOR1_ID 0x1234
 #define TEST_CURSOR2_ID 0x2345
@@ -49,11 +49,35 @@ static void
 print_game_struct_repr (lw6ker_game_struct_t * game_struct)
 {
   char *repr = NULL;
+  lw6sys_whd_t shape;
+  int x, y, z;
+  int nb_zones;
+  int max_zone_size;
+  int is_fg, is_bg;
+  lw6sys_xyz_t zone_pos;
+  int zone_size;
+
+  lw6ker_game_struct_get_shape (game_struct, &shape);
+  x = lw6sys_random (lw6ker_game_struct_get_w (game_struct));
+  y = lw6sys_random (lw6ker_game_struct_get_h (game_struct));
+  z = lw6sys_random (lw6ker_game_struct_get_d (game_struct));
+  is_fg = lw6ker_game_struct_is_fg (game_struct, x, y, z);
+  is_bg = lw6ker_game_struct_is_bg (game_struct, x, y, z);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("%d,%d,%d is_fg=%d is_bg=%d"), x,
+	      y, z, is_fg, is_bg);
+
+  lw6ker_game_struct_get_zones_info (game_struct, &nb_zones, &max_zone_size);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("nb_zones=%d max_zone_size=%d"), nb_zones,
+	      max_zone_size);
+  lw6ker_game_struct_get_zone_info (game_struct, 0, &zone_pos, &zone_size);
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("zone_pos=%d,%d,%d zone_size=%d"),
+	      zone_pos.x, zone_pos.y, zone_pos.z, zone_size);
 
   repr = lw6ker_game_struct_repr (game_struct);
   if (repr)
     {
-      lw6sys_log (LW6SYS_LOG_NOTICE, _("game_struct repr is \"%s\""), repr);
+      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("game_struct repr is \"%s\""),
+		  repr);
       LW6SYS_FREE (repr);
     }
 }
@@ -63,14 +87,86 @@ print_game_state_repr (lw6ker_game_state_t * game_state)
 {
   char *repr = NULL;
   char *capture = NULL;
+  int i;
+  int32_t nb_cursors;
+  int32_t nb_fighters;
+  int total_fighters;
+  int fighter_id;
+  lw6ker_fighter_t *fighter1;
+  lw6ker_fighter_t *fighter2;
+  lw6ker_fighter_t *fighter3;
+  lw6sys_whd_t shape;
+  int x, y, z;
+  lw6ker_cursor_t cursor;
+  int potential;
 
   repr = lw6ker_game_state_repr (game_state);
   if (repr)
     {
-      lw6sys_log (LW6SYS_LOG_NOTICE, _("game_state repr is \"%s\""), repr);
+      lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("game_state repr is \"%s\""), repr);
       LW6SYS_FREE (repr);
     }
-  lw6ker_map_state_print_debug (&(game_state->map_state));
+
+  total_fighters = lw6ker_game_state_get_nb_active_fighters (game_state);
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("active_fighters = %d"), total_fighters);
+  if (total_fighters > 0)
+    {
+      for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+	{
+	  lw6ker_game_state_get_team_info (game_state, i, &nb_cursors,
+					   &nb_fighters);
+
+	  lw6sys_log (LW6SYS_LOG_DEBUG,
+		      _x_ ("team %d has %d cursors, %d fighters (%2.1f%%)"),
+		      i, nb_cursors, nb_fighters,
+		      ((float) nb_fighters) / ((float) total_fighters) *
+		      100.0f);
+	  /*
+	   * Do NOT remove the following calls, as lw6ker_game_state_get_fighter_X
+	   * functions really need to be compiled in.
+	   */
+	  lw6ker_game_state_get_cursor_by_index (game_state, &cursor, 0);
+	  lw6ker_game_state_get_shape (game_state, &shape);
+	  x = lw6sys_random (lw6ker_game_state_get_w (game_state));
+	  y = lw6sys_random (lw6ker_game_state_get_h (game_state));
+	  z = lw6sys_random (lw6ker_game_state_get_d (game_state));
+	  potential =
+	    lw6ker_game_state_get_zone_potential (game_state, 0,
+						  LW6MAP_TEAM_COLOR_RED);
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _("potential of zone 0 is %d"),
+		      potential);
+	  fighter_id = lw6ker_game_state_get_fighter_id (game_state, x, y, z);
+	  if (fighter_id >= 0)
+	    {
+	      fighter1 =
+		lw6ker_game_state_get_fighter_by_id (game_state, fighter_id);
+	      fighter2 =
+		lw6ker_game_state_get_fighter_safe (game_state, x, y, z);
+	      fighter3 =
+		lw6ker_game_state_get_fighter_unsafe (game_state, x, y, z);
+	      if (fighter1 == fighter2 && fighter2 == fighter3)
+		{
+		  lw6sys_log (LW6SYS_LOG_NOTICE,
+			      _x_ ("%d,%d,%d fighter has id %d"), x, y, z,
+			      fighter_id);
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _x_
+			      ("fighter pointer mismatch in %d,%d,%d %p,%p,%p"),
+			      x, y, z, fighter1, fighter2, fighter3);
+		}
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_NOTICE,
+			  _x_ ("no fighter in x,y,z (%d)"), x, y, z,
+			  fighter_id);
+	    }
+	}
+    }
+
   capture = lw6ker_capture_str (game_state);
   if (capture)
     {
@@ -78,7 +174,7 @@ print_game_state_repr (lw6ker_game_state_t * game_state)
       fflush (stdout);
       LW6SYS_FREE (capture);
     }
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("time_elapsed=%d time_left=%d"),
+  lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("time_elapsed=%d time_left=%d"),
 	      lw6ker_game_state_get_time_elapsed (game_state),
 	      lw6ker_game_state_get_time_left (game_state));
 }
@@ -106,7 +202,7 @@ test_struct ()
 	    print_game_struct_repr (game_struct);
 	    checksum = lw6ker_game_struct_checksum (game_struct);
 	    lw6sys_log (LW6SYS_LOG_NOTICE,
-			_
+			_x_
 			("game struct checksum is %08x and should be %08x"),
 			checksum, TEST_GAME_STRUCT_CHECKSUM);
 	    lw6ker_game_struct_free (game_struct);
@@ -145,16 +241,15 @@ test_state ()
 	    game_state = lw6ker_game_state_new (game_struct, NULL);
 	    if (game_state)
 	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE, _("is_over returns %d"),
+		lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("is_over returns %d"),
 			    lw6ker_game_state_is_over (game_state));
 		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _
+			    _x_
 			    ("game state checksum is %08x and should be %08x"),
 			    checksum, TEST_GAME_STATE_CHECKSUM);
-		ret = lw6ker_map_state_sanity_check (&(game_state->map_state))
-		  && (checksum == TEST_GAME_STATE_CHECKSUM);
+		ret = (checksum == TEST_GAME_STATE_CHECKSUM);
 		lw6ker_game_state_free (game_state);
 	      }
 	    lw6ker_game_struct_free (game_struct);
@@ -209,11 +304,10 @@ test_population ()
 		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _
+			    _x_
 			    ("game state checksum is %08x and should be %08x"),
 			    checksum, TEST_GAME_STATE_POPULATE_CHECKSUM);
-		ret = lw6ker_map_state_sanity_check (&(game_state->map_state))
-		  && (checksum == TEST_GAME_STATE_POPULATE_CHECKSUM);
+		ret = (checksum == TEST_GAME_STATE_POPULATE_CHECKSUM);
 		lw6ker_game_state_free (game_state);
 	      }
 	    lw6ker_game_struct_free (game_struct);
@@ -239,10 +333,7 @@ test_algorithm ()
     lw6ker_score_array_t score_array;
     int checksum;
     int i;
-    int cursor_x, cursor_y;
-    u_int64_t node_id = 0;
-    char letter = ' ';
-    int team_color = -1;
+    lw6ker_cursor_t cursor;
 
     ret = 0;
     level =
@@ -266,32 +357,28 @@ test_algorithm ()
 		lw6ker_game_state_add_cursor (game_state, TEST_NODE_ID,
 					      TEST_CURSOR3_ID, TEST_COLOR3);
 		print_game_state_repr (game_state);
-		cursor_x = game_state->map_state.shape.w / 2;
-		cursor_y = game_state->map_state.shape.h / 2;
-		lw6ker_game_state_set_cursor (game_state, TEST_NODE_ID,
-					      TEST_CURSOR1_ID, cursor_x,
-					      cursor_y);
-		lw6ker_game_state_set_cursor (game_state, TEST_NODE_ID,
-					      TEST_CURSOR2_ID, cursor_x,
-					      cursor_y);
-		lw6ker_game_state_set_cursor (game_state, TEST_NODE_ID,
-					      TEST_CURSOR3_ID, cursor_x,
-					      cursor_y);
-		lw6ker_game_state_get_cursor_info (game_state,
-						   TEST_CURSOR1_ID,
-						   &node_id, &letter,
-						   &team_color, &cursor_x,
-						   &cursor_y);
+		lw6ker_cursor_reset (&cursor);
+		cursor.pos.x = lw6ker_game_state_get_w (game_state) / 2;
+		cursor.pos.y = lw6ker_game_state_get_h (game_state) / 2;
+		cursor.node_id = TEST_NODE_ID;
+		cursor.cursor_id = TEST_CURSOR1_ID;
+		lw6ker_game_state_set_cursor (game_state, &cursor);
+		cursor.cursor_id = TEST_CURSOR2_ID;
+		lw6ker_game_state_set_cursor (game_state, &cursor);
+		cursor.cursor_id = TEST_CURSOR3_ID;
+		lw6ker_game_state_set_cursor (game_state, &cursor);
+		lw6ker_game_state_get_cursor (game_state,
+					      &cursor, TEST_CURSOR1_ID);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("cursor %x letter='%c' color=%d x=%d y=%d"),
-			    TEST_CURSOR1_ID, letter, team_color, cursor_x,
-			    cursor_y);
+			    _x_ ("cursor %x letter='%c' color=%d x=%d y=%d"),
+			    TEST_CURSOR1_ID, cursor.letter, cursor.team_color,
+			    cursor.pos.x, cursor.pos.y);
 		for (i = 0; i < TEST_NB_ROUNDS; ++i)
 		  {
 		    lw6ker_game_state_do_round (game_state);
 		    lw6sys_log (LW6SYS_LOG_NOTICE,
-				_("round %d, game_state checksum=%08x"),
-				game_state->rounds,
+				_x_ ("round %d, game_state checksum=%08x"),
+				lw6ker_game_state_get_rounds (game_state),
 				lw6ker_game_state_checksum (game_state));
 		  }
 		lw6ker_score_array_update (&score_array, game_state);
@@ -300,7 +387,7 @@ test_algorithm ()
 		    if (score_array.scores[i].fighters_absolute > 0)
 		      {
 			lw6sys_log (LW6SYS_LOG_NOTICE,
-				    _
+				    _x_
 				    ("order=%d team_color=%d score=%d%%"),
 				    i, score_array.scores[i].team_color,
 				    score_array.scores[i].fighters_percent);
@@ -312,7 +399,7 @@ test_algorithm ()
 				     (game_state)); ++i)
 		  {
 		    lw6sys_log (LW6SYS_LOG_NOTICE,
-				_
+				_x_
 				("history entry %d for team %d is global=%d latest=%d"),
 				i, TEST_HISTORY_TEAM,
 				lw6ker_game_state_get_global_history
@@ -321,7 +408,7 @@ test_algorithm ()
 				(game_state, i, TEST_HISTORY_TEAM));
 		  }
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("max history entry global=%d latest=%d"),
+			    _x_ ("max history entry global=%d latest=%d"),
 			    lw6ker_game_state_get_global_history_max
 			    (game_state),
 			    lw6ker_game_state_get_latest_history_max
@@ -329,11 +416,10 @@ test_algorithm ()
 		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _
+			    _x_
 			    ("game state checksum is %08x and should be %08x"),
 			    checksum, TEST_GAME_STATE_ALGORITHM_CHECKSUM);
-		ret = lw6ker_map_state_sanity_check (&(game_state->map_state))
-		  && (checksum == TEST_GAME_STATE_ALGORITHM_CHECKSUM);
+		ret = (checksum == TEST_GAME_STATE_ALGORITHM_CHECKSUM);
 		lw6ker_game_state_free (game_state);
 	      }
 	    lw6ker_game_struct_free (game_struct);
@@ -409,22 +495,22 @@ test_team_mask ()
     int i;
 
     lw6ker_team_mask_get (&even, &odd, TEST_TEAM_MASK_SEED);
-    lw6sys_log (LW6SYS_LOG_NOTICE, _("even team mask %x"), even);
-    lw6sys_log (LW6SYS_LOG_NOTICE, _("odd team mask %x"), odd);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("even team mask %x"), even);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("odd team mask %x"), odd);
     for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
       {
 	if (lw6ker_team_mask_is_concerned (i, even))
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE, _("team %d is even"), i);
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("team %d is even"), i);
 	  }
 	else if (lw6ker_team_mask_is_concerned (i, odd))
 	  {
-	    lw6sys_log (LW6SYS_LOG_NOTICE, _("team %d is odd"), i);
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _x_ ("team %d is odd"), i);
 	  }
 	else
 	  {
 	    lw6sys_log (LW6SYS_LOG_WARNING,
-			_("team mask inconsistency for %d"), i);
+			_x_ ("team mask inconsistency for %d"), i);
 	    ret = 0;
 	  }
       }
