@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
 		  if (color_type & PNG_COLOR_MASK_PALETTE)
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _
+				  _x_
 				  ("can't load B&W PNG file \"%s\", it is still paletted after filtering"),
 				  png_file);
 		      format_ok = 0;
@@ -110,7 +110,7 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
 		      bit_depth > 8)
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _
+				  _x_
 				  ("can't load B&W PNG file \"%s\", memory footprint is inconsistent, color_type=%d, rowbytes=%d, width=%d, step=%d, bit_depth=%d"),
 				  png_file, color_type,
 				  info_ptr->rowbytes, width, step, bit_depth);
@@ -157,8 +157,8 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
 			}
 		      else
 			{
-			  lw6sys_log (LW6SYS_LOG_ERROR,
-				      _
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _x_
 				      ("unable to allocate memory for B&W PNG file"));
 			}
 		    }
@@ -169,18 +169,19 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _("couldn't create png end info struct"));
+			  _x_ ("couldn't create png end info struct"));
 	    }
 	}
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("couldn't create png info struct"));
+		      _x_ ("couldn't create png info struct"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("couldn't create png read struct"));
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("couldn't create png read struct"));
     }
 
   png_destroy_read_struct (&png_ptr, &info_ptr, &end_info);
@@ -247,14 +248,16 @@ _lw6ldr_bw_gray_level (_lw6ldr_image_bw_t * image)
   if (ret > 1.0f)
     {
       ret = 1.0f;
-      lw6sys_log (LW6SYS_LOG_WARNING, _("gray_level=%f, can't be >1"), ret);
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("gray_level=%f, can't be >1"),
+		  ret);
     }
   if (ret < 0.0f)
     {
       ret = 0.0f;
-      lw6sys_log (LW6SYS_LOG_WARNING, _("gray_level=%f, can't be <0"), ret);
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("gray_level=%f, can't be <0"),
+		  ret);
     }
-  lw6sys_log (LW6SYS_LOG_DEBUG, _("gray_level=%f"), ret);
+  lw6sys_log (LW6SYS_LOG_DEBUG, _x_ ("gray_level=%f"), ret);
 
   return ret;
 }
