@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ read_callback (void *callback_data, char *element, char *key, char *value)
   if (!strcmp (element, LW6CFG_XML_FLOAT))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("map rules should not use floats, XML entry %s=%s is not correct"),
 		  key, value);
     }
@@ -77,7 +77,7 @@ read_callback (void *callback_data, char *element, char *key, char *value)
   if (!strcmp (element, LW6CFG_XML_STRING))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("map rules should not use strings, XML entry %s=%s is not correct"),
 		  key, value);
     }
@@ -107,7 +107,7 @@ lw6ldr_rules_read (lw6map_rules_t * rules, char *dirname)
     {
       if (lw6sys_file_exists (buf))
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("reading rules \"%s\""), buf);
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("reading rules \"%s\""), buf);
 	  ret =
 	    lw6cfg_read_key_value_xml_file (buf, read_callback,
 					    (void *) rules);
@@ -123,7 +123,7 @@ lw6ldr_rules_read (lw6map_rules_t * rules, char *dirname)
 
   if (!ret)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to read map rules"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to read map rules"));
     }
 
   return ret;
@@ -135,7 +135,6 @@ rules_update_callback (void *func_data, void *data)
   rules_update_data_t *update_data;
   char *key;
   char *value;
-  char *about;
   char *element;
   lw6hlp_type_t type = LW6HLP_TYPE_VOID;
 
@@ -144,7 +143,7 @@ rules_update_callback (void *func_data, void *data)
 
   if (lw6sys_assoc_has_key (update_data->values, key))
     {
-      about = lw6hlp_about (&type, NULL, NULL, NULL, key);
+      lw6hlp_about (&type, NULL, NULL, NULL, key);
       value = lw6sys_assoc_get (update_data->values, key);
       element = lw6cfg_xml_element (type);
       read_callback (update_data->rules, element, key, value);
