@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
  * This is the main Liquid War 6 header file.
  */
 
-#define LW6_VERSION "0.0.9beta"
+#define LW6_VERSION "0.0.10beta"
 
 #include <pthread.h>
 #include <libguile.h>
@@ -51,8 +51,11 @@
 #include "pil/pil.h"
 #include "net/net.h"
 #include "nod/nod.h"
+#include "cnx/cnx.h"
+#include "msg/msg.h"
 #include "cli/cli.h"
 #include "srv/srv.h"
+#include "dat/dat.h"
 #include "p2p/p2p.h"
 
 typedef struct lw6_smob_types_s
@@ -234,7 +237,7 @@ extern void lw6_print_list_map_rules ();
 extern void lw6_print_list_map_style ();
 extern void lw6_print_list_funcs ();
 extern void lw6_print_list_hooks ();
-extern void lw6_print_list_tuning ();
+extern void lw6_print_list_advanced ();
 extern void lw6_print_list_aliases ();
 extern void lw6_print_list ();
 extern void lw6_print_about (char *keyword);
