@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -74,6 +74,9 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
   char *path = NULL;
   char *value = NULL;
   char *log_file = NULL;
+  char *pid_file = NULL;
+  char *input = NULL;
+  char *output = NULL;
 
   (*run_game) = 1;
   for (i = 1; i < argc; ++i)
@@ -87,6 +90,27 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6sys_log (LW6SYS_LOG_ERROR, _("unknown option \"%s\""), argv[i]);
 	  (*run_game) = 0;
 	}
+      else if (lw6sys_arg_match (LW6DEF_DAEMON, argv[i]))
+	{
+	  /*
+	   * DAEMON mode is one of the first check we make for we want to switch
+	   * into this mode as soon as possible.
+	   */
+	  pid_file = lw6sys_daemon_pid_file (argc, argv);
+	  if (pid_file)
+	    {
+	      if (lw6sys_daemon_start (pid_file))
+		{
+		  // OK
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_ERROR, _("unable to start daemon"));
+		  (*run_game) = 0;
+		}
+	      LW6SYS_FREE (pid_file);
+	    }
+	}
       else if (lw6sys_arg_match (LW6DEF_HELP, argv[i]) ||
 	       lw6sys_arg_match ("h", argv[i])
 	       || lw6sys_arg_match ("?", argv[i]))
@@ -127,8 +151,8 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 		&& lw6tsk_test (1) && lw6gui_test (1) && lw6gfx_test (1)
 		&& lw6dsp_test (1) && lw6snd_test (1) && lw6img_test (1)
 		&& lw6pil_test (1) && lw6net_test (1) && lw6nod_test (1)
-		&& lw6msg_test (1)
-		&& lw6cli_test (1) && lw6srv_test (1) && lw6p2p_test (1)
+		&& lw6cnx_test (1) && lw6msg_test (1) && lw6cli_test (1)
+		&& lw6srv_test (1) && lw6dat_test (1) && lw6p2p_test (1)
 		&& lw6_test (1);
 	      if (ret)
 		{
@@ -161,13 +185,14 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 		&& lw6tsk_test (0) && lw6gui_test (0) && lw6gfx_test (0)
 		&& lw6dsp_test (0) && lw6snd_test (0) && lw6img_test (0)
 		&& lw6pil_test (0) && lw6net_test (0) && lw6nod_test (0)
-		&& lw6msg_test (0)
-		&& lw6cli_test (0) && lw6srv_test (0) && lw6p2p_test (0)
+		&& lw6cnx_test (0) && lw6msg_test (0) && lw6cli_test (0)
+		&& lw6srv_test (0) && lw6dat_test (0) && lw6p2p_test (0)
 		&& lw6_test (0);
 	      if (ret)
 		{
 		  lw6sys_log (LW6SYS_LOG_NOTICE,
-			      _("all tests SUCCESSFULL! (check-only mode)"));
+			      _x_
+			      ("all tests SUCCESSFULL! (check-only mode)"));
 		}
 	      else
 		{
@@ -176,7 +201,7 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 		   * interactive operation to finish
 		   */
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _
+			      _x_
 			      ("check FAILED, see log file \"%s\" for details"),
 			      log_file);
 		}
@@ -316,9 +341,9 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  lw6_print_list_hooks ();
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_LIST_TUNING, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_LIST_ADVANCED, argv[i]))
 	{
-	  lw6_print_list_tuning ();
+	  lw6_print_list_advanced ();
 	  (*run_game) = 0;
 	}
       else if (lw6sys_arg_match (LW6DEF_LIST_ALIASES, argv[i]))
@@ -394,7 +419,8 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	  printf ("%s\n", lw6sys_build_get_url ());
 	  (*run_game) = 0;
 	}
-      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_CONFIGURE_ARGS, argv[i]))
+      else if (lw6sys_arg_match (LW6DEF_SHOW_BUILD_CONFIGURE_ARGS, argv[i])
+	       || lw6sys_arg_match (LW6DEF_CONFIGURE_ARGS, argv[i]))
 	{
 	  printf ("%s\n", lw6sys_build_get_configure_args ());
 	  (*run_game) = 0;
@@ -859,6 +885,71 @@ lw6_process_non_run_options (int argc, char *argv[], int *run_game)
 	    }
 	  (*run_game) = 0;
 	}
+      /*
+       * Decode/encode debugging routines
+       */
+      else if (lw6sys_arg_match (LW6DEF_BASE64_ENCODE, argv[i]))
+	{
+	  input = lw6sys_stream_file_to_str (stdin);
+	  if (input)
+	    {
+	      output = lw6glb_base64_encode_str (input);
+	      if (output)
+		{
+		  lw6sys_stream_str_to_file (stdout, output);
+		  LW6SYS_FREE (output);
+		  printf ("\n");
+		}
+	      LW6SYS_FREE (input);
+	    }
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_BASE64_DECODE, argv[i]))
+	{
+	  input = lw6sys_stream_file_to_str (stdin);
+	  if (input)
+	    {
+	      output = lw6glb_base64_decode_str (input);
+	      if (output)
+		{
+		  lw6sys_stream_str_to_file (stdout, output);
+		  LW6SYS_FREE (output);
+		}
+	      LW6SYS_FREE (input);
+	    }
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_Z_ENCODE, argv[i]))
+	{
+	  input = lw6sys_stream_file_to_str (stdin);
+	  if (input)
+	    {
+	      output = lw6msg_z_encode (input, 0);
+	      if (output)
+		{
+		  lw6sys_stream_str_to_file (stdout, output);
+		  LW6SYS_FREE (output);
+		  printf ("\n");
+		}
+	      LW6SYS_FREE (input);
+	    }
+	  (*run_game) = 0;
+	}
+      else if (lw6sys_arg_match (LW6DEF_Z_DECODE, argv[i]))
+	{
+	  input = lw6sys_stream_file_to_str (stdin);
+	  if (input)
+	    {
+	      output = lw6msg_z_decode (input);
+	      if (output)
+		{
+		  lw6sys_stream_str_to_file (stdout, output);
+		  LW6SYS_FREE (output);
+		}
+	      LW6SYS_FREE (input);
+	    }
+	  (*run_game) = 0;
+	}
     }
 
   return ret;
