@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -111,7 +111,7 @@ lw6_print_long_copyright ()
   printf
     ("%s",
      "Liquid War 6 is a unique multiplayer wargame.\n"
-     "Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>\n"
+     "Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>\n"
      "\n"
      "This program is free software; you can redistribute it and/or modify\n"
      "it under the terms of the GNU General Public License as published by\n"
@@ -742,18 +742,18 @@ lw6_print_list_hooks ()
 }
 
 /**
- * lw6_print_list_tuning
+ * lw6_print_list_advanced
  *
- * Displays the list of 'tuning' options.
+ * Displays the list of 'advanced' options.
  *
  * Return value: none
  */
 void
-lw6_print_list_tuning ()
+lw6_print_list_advanced ()
 {
   lw6sys_list_t *list;
 
-  list = lw6hlp_list_tuning ();
+  list = lw6hlp_list_advanced ();
   if (list)
     {
       lw6hlp_print_keyword (&list, stdout);
