@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -153,6 +153,41 @@ push_texture (lw6sys_hexa_serializer_t * hexa_serializer,
   return ret;
 }
 
+static int
+push_cursor_texture (lw6sys_hexa_serializer_t * hexa_serializer,
+		     lw6map_cursor_texture_t * cursor_texture)
+{
+  int ret = 1;
+  int x, y;
+
+  for (y = 0; y < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++y)
+    {
+      for (x = 0; x < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++x)
+	{
+	  ret = ret
+	    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+						  lw6map_cursor_texture_layer_get
+						  (&
+						   (cursor_texture->fg_bg_layer),
+						   x, y));
+	}
+    }
+  for (y = 0; y < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++y)
+    {
+      for (x = 0; x < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++x)
+	{
+	  ret = ret
+	    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+						  lw6map_cursor_texture_layer_get
+						  (&
+						   (cursor_texture->color_layer),
+						   x, y));
+	}
+    }
+
+  return ret;
+}
+
 static int
 push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 	    lw6map_param_t * param)
@@ -202,6 +237,18 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
   ret = ret
     && lw6sys_hexa_serializer_push_float (hexa_serializer,
 					  param->style.animation_speed);
+  ret = ret
+    && lw6sys_hexa_serializer_push_float (hexa_serializer,
+					  param->style.cursor_size);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.colorize_cursor);
+  ret = ret
+    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
+					  param->style.blink_cursor);
+  ret = ret
+    && lw6sys_hexa_serializer_push_float (hexa_serializer,
+					  param->style.hidden_layer_alpha);
   ret = ret
     && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
 					  param->style.colorize);
@@ -351,6 +398,8 @@ lw6map_to_hexa (lw6map_level_t * level)
       ok = ok && push_metadata (hexa_serializer, &(level->metadata));
       ok = ok && push_body (hexa_serializer, &(level->body));
       ok = ok && push_texture (hexa_serializer, &(level->texture));
+      ok = ok
+	&& push_cursor_texture (hexa_serializer, &(level->cursor_texture));
       ok = ok && push_param (hexa_serializer, &(level->param));
       if (ok)
 	{
@@ -410,8 +459,9 @@ pop_layer (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_layer_t * layer,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("bad layer shape (%dx%d != %dx%d)"),
-		  layer->shape.w, layer->shape.h, shape->w, shape->h);
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("bad layer shape (%dx%d != %dx%d)"), layer->shape.w,
+		  layer->shape.h, shape->w, shape->h);
       ret = 0;
     }
 
@@ -459,7 +509,7 @@ pop_meta_layer (lw6sys_hexa_serializer_t * hexa_serializer,
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("bad meta_layer shape (%dx%d != %dx%d)"),
+		      _x_ ("bad meta_layer shape (%dx%d != %dx%d)"),
 		      meta_layer->shape.w, meta_layer->shape.h, shape->w,
 		      shape->h);
 	  ret = 0;
@@ -491,8 +541,9 @@ pop_body (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_body_t * body)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("map shape out of range (%dx%dx%d)"),
-		  body->shape.w, body->shape.h, body->shape.d);
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("map shape out of range (%dx%dx%d)"), body->shape.w,
+		  body->shape.h, body->shape.d);
       ret = 0;
     }
   ret = ret
@@ -563,8 +614,9 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("texture shape out of range (%dx%d)"),
-		  texture->w, texture->h);
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("texture shape out of range (%dx%d)"), texture->w,
+		  texture->h);
       ret = 0;
     }
   ret = ret
@@ -585,6 +637,38 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
   return ret;
 }
 
+static int
+pop_cursor_texture (lw6sys_hexa_serializer_t * hexa_serializer,
+		    lw6map_cursor_texture_t * cursor_texture)
+{
+  int ret = 1;
+  int x, y;
+  lw6sys_color_8_t color = { 0, 0, 0, 0 };
+
+  for (y = 0; y < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++y)
+    {
+      for (x = 0; x < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++x)
+	{
+	  ret = ret
+	    && lw6sys_hexa_serializer_pop_color (hexa_serializer, &color);
+	  lw6map_cursor_texture_layer_set (&(cursor_texture->fg_bg_layer), x,
+					   y, color);
+	}
+    }
+  for (y = 0; y < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++y)
+    {
+      for (x = 0; x < LW6MAP_CURSOR_TEXTURE_SIZE && ret; ++x)
+	{
+	  ret = ret
+	    && lw6sys_hexa_serializer_pop_color (hexa_serializer, &color);
+	  lw6map_cursor_texture_layer_set (&(cursor_texture->color_layer), x,
+					   y, color);
+	}
+    }
+
+  return ret;
+}
+
 static int
 pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
 {
@@ -638,6 +722,18 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   ret = ret
     && lw6sys_hexa_serializer_pop_float (hexa_serializer,
 					 &(param->style.animation_speed));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_float (hexa_serializer,
+					 &(param->style.cursor_size));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.colorize_cursor));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
+					 &(param->style.blink_cursor));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_float (hexa_serializer,
+					 &(param->style.hidden_layer_alpha));
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
 					 &(param->style.colorize));
@@ -791,11 +887,13 @@ lw6map_from_hexa (char *hexa)
 	  ok = ok && pop_metadata (hexa_serializer, &(level->metadata));
 	  ok = ok && pop_body (hexa_serializer, &(level->body));
 	  ok = ok && pop_texture (hexa_serializer, &(level->texture));
+	  ok = ok
+	    && pop_cursor_texture (hexa_serializer, &(level->cursor_texture));
 	  ok = ok && pop_param (hexa_serializer, &(level->param));
 	  if (!lw6sys_hexa_serializer_eof (hexa_serializer))
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _("expected EOF in serialized level"));
+			  _x_ ("expected EOF in serialized level"));
 	      ok = 0;
 	    }
 	  if (!ok)
