@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -53,6 +53,8 @@ lw6map_style_defaults (lw6map_style_t * style)
   style->animation_density = LW6MAP_STYLE_DEFAULT_ANIMATION_DENSITY;
   style->animation_speed = LW6MAP_STYLE_DEFAULT_ANIMATION_SPEED;
   style->cursor_size = LW6MAP_STYLE_DEFAULT_CURSOR_SIZE;
+  style->colorize_cursor = LW6MAP_STYLE_DEFAULT_COLORIZE_CURSOR;
+  style->blink_cursor = LW6MAP_STYLE_DEFAULT_BLINK_CURSOR;
   style->hidden_layer_alpha = LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA;
   style->colorize = LW6MAP_STYLE_DEFAULT_COLORIZE;
   style->pixelize = LW6MAP_STYLE_DEFAULT_PIXELIZE;
@@ -298,6 +300,14 @@ lw6map_style_set (lw6map_style_t * style, char *key, char *value)
 	{
 	  style->cursor_size = lw6sys_atof (value);
 	}
+      else if (!strcmp (LW6DEF_COLORIZE_CURSOR, formatted_key))
+	{
+	  style->colorize_cursor = lw6sys_atob (value);
+	}
+      else if (!strcmp (LW6DEF_BLINK_CURSOR, formatted_key))
+	{
+	  style->blink_cursor = lw6sys_atob (value);
+	}
       else if (!strcmp (LW6DEF_HIDDEN_LAYER_ALPHA, formatted_key))
 	{
 	  style->hidden_layer_alpha = lw6sys_atof (value);
@@ -569,6 +579,14 @@ lw6map_style_get (lw6map_style_t * style, char *key)
 	{
 	  ret = lw6sys_ftoa (style->cursor_size);
 	}
+      else if (!strcmp (LW6DEF_COLORIZE_CURSOR, formatted_key))
+	{
+	  ret = lw6sys_btoa (style->colorize_cursor);
+	}
+      else if (!strcmp (LW6DEF_BLINK_CURSOR, formatted_key))
+	{
+	  ret = lw6sys_btoa (style->blink_cursor);
+	}
       else if (!strcmp (LW6DEF_HIDDEN_LAYER_ALPHA, formatted_key))
 	{
 	  ret = lw6sys_ftoa (style->hidden_layer_alpha);
@@ -781,7 +799,8 @@ lw6map_style_get_default (char *key)
   if (!ret)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to get default value for style parameter \"%s\""),
+		  _x_
+		  ("unable to get default value for style parameter \"%s\""),
 		  key);
     }
 
@@ -819,6 +838,8 @@ lw6map_style_is_same (lw6map_style_t * style_a, lw6map_style_t * style_b)
   ret = ret && style_a->animation_density == style_b->animation_density;
   ret = ret && style_a->animation_speed == style_b->animation_speed;
   ret = ret && style_a->cursor_size == style_b->cursor_size;
+  ret = ret && style_a->colorize_cursor == style_b->colorize_cursor;
+  ret = ret && style_a->blink_cursor == style_b->blink_cursor;
   ret = ret && style_a->hidden_layer_alpha == style_b->hidden_layer_alpha;
   ret = ret && style_a->colorize == style_b->colorize;
   ret = ret && style_a->pixelize == style_b->pixelize;
