@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #define LW6MAP_MAX_NB_CURSORS 26
 #define LW6MAP_MAX_NB_NODES 26
 #define LW6MAP_MAX_NB_DIR_TRIES 7
+#define LW6MAP_CURSOR_TEXTURE_SIZE 64
 
 #define LW6MAP_RULES_POSITION_MODE_PREDEFINED 0
 #define LW6MAP_RULES_POSITION_MODE_PICK_EXISTING 1
@@ -183,78 +184,78 @@
 #define LW6MAP_RULES_MIN_START_RED_X 0
 #define LW6MAP_RULES_MAX_START_RED_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_RED_Y 10
-#define LW6MAP_RULES_MIN_START_RED_Y 0
-#define LW6MAP_RULES_MAX_START_RED_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_GREEN_X 90
 #define LW6MAP_RULES_MIN_START_GREEN_X 0
 #define LW6MAP_RULES_MAX_START_GREEN_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_GREEN_Y 90
-#define LW6MAP_RULES_MIN_START_GREEN_Y 0
-#define LW6MAP_RULES_MAX_START_GREEN_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_BLUE_X 90
 #define LW6MAP_RULES_MIN_START_BLUE_X 0
 #define LW6MAP_RULES_MAX_START_BLUE_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_BLUE_Y 10
-#define LW6MAP_RULES_MIN_START_BLUE_Y 0
-#define LW6MAP_RULES_MAX_START_BLUE_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_YELLOW_X 10
 #define LW6MAP_RULES_MIN_START_YELLOW_X 0
 #define LW6MAP_RULES_MAX_START_YELLOW_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_YELLOW_Y 90
-#define LW6MAP_RULES_MIN_START_YELLOW_Y 0
-#define LW6MAP_RULES_MAX_START_YELLOW_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_CYAN_X 35
 #define LW6MAP_RULES_MIN_START_CYAN_X 0
 #define LW6MAP_RULES_MAX_START_CYAN_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_CYAN_Y 10
-#define LW6MAP_RULES_MIN_START_CYAN_Y 0
-#define LW6MAP_RULES_MAX_START_CYAN_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_MAGENTA_X 65
 #define LW6MAP_RULES_MIN_START_MAGENTA_X 0
 #define LW6MAP_RULES_MAX_START_MAGENTA_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_MAGENTA_Y 90
-#define LW6MAP_RULES_MIN_START_MAGENTA_Y 0
-#define LW6MAP_RULES_MAX_START_MAGENTA_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_ORANGE_X 65
 #define LW6MAP_RULES_MIN_START_ORANGE_X 0
 #define LW6MAP_RULES_MAX_START_ORANGE_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_ORANGE_Y 10
-#define LW6MAP_RULES_MIN_START_ORANGE_Y 0
-#define LW6MAP_RULES_MAX_START_ORANGE_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_LIGHTBLUE_X 35
 #define LW6MAP_RULES_MIN_START_LIGHTBLUE_X 0
 #define LW6MAP_RULES_MAX_START_LIGHTBLUE_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_LIGHTBLUE_Y 90
-#define LW6MAP_RULES_MIN_START_LIGHTBLUE_Y 0
-#define LW6MAP_RULES_MAX_START_LIGHTBLUE_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_PURPLE_X 90
 #define LW6MAP_RULES_MIN_START_PURPLE_X 0
 #define LW6MAP_RULES_MAX_START_PURPLE_X 100
 
-#define LW6MAP_RULES_DEFAULT_START_PURPLE_Y 50
-#define LW6MAP_RULES_MIN_START_PURPLE_Y 0
-#define LW6MAP_RULES_MAX_START_PURPLE_Y 100
-
 #define LW6MAP_RULES_DEFAULT_START_PINK_X 10
 #define LW6MAP_RULES_MIN_START_PINK_X 0
 #define LW6MAP_RULES_MAX_START_PINK_X 100
 
+#define LW6MAP_RULES_DEFAULT_START_RED_Y 10
+#define LW6MAP_RULES_MIN_START_RED_Y 0
+#define LW6MAP_RULES_MAX_START_RED_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_GREEN_Y 90
+#define LW6MAP_RULES_MIN_START_GREEN_Y 0
+#define LW6MAP_RULES_MAX_START_GREEN_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_BLUE_Y 10
+#define LW6MAP_RULES_MIN_START_BLUE_Y 0
+#define LW6MAP_RULES_MAX_START_BLUE_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_YELLOW_Y 90
+#define LW6MAP_RULES_MIN_START_YELLOW_Y 0
+#define LW6MAP_RULES_MAX_START_YELLOW_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_CYAN_Y 10
+#define LW6MAP_RULES_MIN_START_CYAN_Y 0
+#define LW6MAP_RULES_MAX_START_CYAN_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_MAGENTA_Y 90
+#define LW6MAP_RULES_MIN_START_MAGENTA_Y 0
+#define LW6MAP_RULES_MAX_START_MAGENTA_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_ORANGE_Y 10
+#define LW6MAP_RULES_MIN_START_ORANGE_Y 0
+#define LW6MAP_RULES_MAX_START_ORANGE_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_LIGHTBLUE_Y 90
+#define LW6MAP_RULES_MIN_START_LIGHTBLUE_Y 0
+#define LW6MAP_RULES_MAX_START_LIGHTBLUE_Y 100
+
+#define LW6MAP_RULES_DEFAULT_START_PURPLE_Y 50
+#define LW6MAP_RULES_MIN_START_PURPLE_Y 0
+#define LW6MAP_RULES_MAX_START_PURPLE_Y 100
+
 #define LW6MAP_RULES_DEFAULT_START_PINK_Y 50
 #define LW6MAP_RULES_MIN_START_PINK_Y 0
 #define LW6MAP_RULES_MAX_START_PINK_Y 100
@@ -299,6 +300,170 @@
 #define LW6MAP_RULES_MIN_FRAGS_FADE_OUT 10
 #define LW6MAP_RULES_MAX_FRAGS_FADE_OUT 100
 
+#define LW6MAP_RULES_DEFAULT_USE_TEAM_PROFILES 1
+#define LW6MAP_RULES_MIN_USE_TEAM_PROFILES 0
+#define LW6MAP_RULES_MAX_USE_TEAM_PROFILES 1
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_AGGRESSIVE 120
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_RED_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_RED_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_AGGRESSIVE 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_GREEN_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_GREEN_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_AGGRESSIVE 110
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_BLUE_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_BLUE_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_AGGRESSIVE 50
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_YELLOW_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_YELLOW_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_AGGRESSIVE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_CYAN_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_CYAN_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_AGGRESSIVE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_MAGENTA_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_MAGENTA_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_AGGRESSIVE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_ORANGE_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_ORANGE_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE 90
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_LIGHTBLUE_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_AGGRESSIVE 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PURPLE_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PURPLE_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_AGGRESSIVE 130
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PINK_AGGRESSIVE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PINK_AGGRESSIVE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_VULNERABLE 120
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_RED_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_RED_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_VULNERABLE 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_GREEN_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_GREEN_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_VULNERABLE 90
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_BLUE_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_BLUE_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_VULNERABLE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_YELLOW_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_YELLOW_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_VULNERABLE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_CYAN_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_CYAN_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_VULNERABLE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_MAGENTA_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_MAGENTA_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_VULNERABLE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_ORANGE_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_ORANGE_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_VULNERABLE 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_LIGHTBLUE_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_LIGHTBLUE_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_VULNERABLE 60
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PURPLE_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PURPLE_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_VULNERABLE 160
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PINK_VULNERABLE 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PINK_VULNERABLE 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_MOBILE 0
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_RED_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_RED_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_MOBILE 0
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_GREEN_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_GREEN_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_MOBILE 0
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_BLUE_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_BLUE_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_MOBILE 0
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_YELLOW_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_YELLOW_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_MOBILE 2
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_CYAN_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_CYAN_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_MOBILE -1
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_MAGENTA_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_MAGENTA_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_MOBILE 0
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_ORANGE_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_ORANGE_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_MOBILE 3
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_LIGHTBLUE_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_LIGHTBLUE_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_MOBILE 0
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PURPLE_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PURPLE_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_MOBILE 1
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PINK_MOBILE -3
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PINK_MOBILE 3
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_RED_FAST 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_RED_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_RED_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_GREEN_FAST 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_GREEN_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_GREEN_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_BLUE_FAST 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_BLUE_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_BLUE_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_YELLOW_FAST 150
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_YELLOW_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_YELLOW_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_CYAN_FAST 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_CYAN_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_CYAN_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_MAGENTA_FAST 110
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_MAGENTA_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_MAGENTA_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_ORANGE_FAST 100
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_ORANGE_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_ORANGE_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_LIGHTBLUE_FAST 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_LIGHTBLUE_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_LIGHTBLUE_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PURPLE_FAST 80
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PURPLE_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PURPLE_FAST 1000
+
+#define LW6MAP_RULES_DEFAULT_TEAM_PROFILE_PINK_FAST 120
+#define LW6MAP_RULES_MIN_TEAM_PROFILE_PINK_FAST 10
+#define LW6MAP_RULES_MAX_TEAM_PROFILE_PINK_FAST 1000
+
 /*
  * Note: it's important that floats are never ever used in map rules.
  * In fact, we need maps to be 100,00 (lots of zeroes) predictable,
@@ -340,26 +505,8 @@ typedef struct lw6map_rules_s
   int32_t max_cursor_pot;
   int32_t cursor_pot_init;
   int32_t max_cursor_pot_offset;
-  int32_t start_red_x;
-  int32_t start_red_y;
-  int32_t start_green_x;
-  int32_t start_green_y;
-  int32_t start_blue_x;
-  int32_t start_blue_y;
-  int32_t start_yellow_x;
-  int32_t start_yellow_y;
-  int32_t start_cyan_x;
-  int32_t start_cyan_y;
-  int32_t start_magenta_x;
-  int32_t start_magenta_y;
-  int32_t start_orange_x;
-  int32_t start_orange_y;
-  int32_t start_lightblue_x;
-  int32_t start_lightblue_y;
-  int32_t start_purple_x;
-  int32_t start_purple_y;
-  int32_t start_pink_x;
-  int32_t start_pink_y;
+  int32_t start_x[LW6MAP_MAX_NB_TEAMS];
+  int32_t start_y[LW6MAP_MAX_NB_TEAMS];
   int32_t start_position_mode;
   int32_t color_conflict_mode;
   int32_t spread_thread;
@@ -370,6 +517,11 @@ typedef struct lw6map_rules_s
   int32_t frags_mode;
   int32_t frags_to_distribute;
   int32_t frags_fade_out;
+  int32_t use_team_profiles;
+  int32_t team_profile_aggressive[LW6MAP_MAX_NB_TEAMS];
+  int32_t team_profile_vulnerable[LW6MAP_MAX_NB_TEAMS];
+  int32_t team_profile_mobile[LW6MAP_MAX_NB_TEAMS];
+  int32_t team_profile_fast[LW6MAP_MAX_NB_TEAMS];
 } lw6map_rules_t;
 extern char *LW6MAP_RULES_LIST[];
 
@@ -395,6 +547,8 @@ extern char *LW6MAP_RULES_LIST[];
 #define LW6MAP_STYLE_DEFAULT_ANIMATION_DENSITY 1.0f
 #define LW6MAP_STYLE_DEFAULT_ANIMATION_SPEED 1.0f
 #define LW6MAP_STYLE_DEFAULT_CURSOR_SIZE 1.0f
+#define LW6MAP_STYLE_DEFAULT_COLORIZE_CURSOR 1
+#define LW6MAP_STYLE_DEFAULT_BLINK_CURSOR 0
 #define LW6MAP_STYLE_DEFAULT_HIDDEN_LAYER_ALPHA 0.1f
 #define LW6MAP_STYLE_DEFAULT_COLORIZE 1
 #define LW6MAP_STYLE_DEFAULT_PIXELIZE 0
@@ -531,6 +685,18 @@ typedef struct lw6map_texture_s
   lw6map_color_couple_t guessed_color_alternate;
 } lw6map_texture_t;
 
+typedef struct lw6map_cursor_texture_layer_s
+{
+  lw6sys_color_8_t
+    data[LW6MAP_CURSOR_TEXTURE_SIZE][LW6MAP_CURSOR_TEXTURE_SIZE];
+} lw6map_cursor_texture_layer_t;
+
+typedef struct lw6map_cursor_texture_s
+{
+  lw6map_cursor_texture_layer_t fg_bg_layer;
+  lw6map_cursor_texture_layer_t color_layer;
+} lw6map_cursor_texture_t;
+
 typedef struct lw6map_color_set_s
 {
   lw6map_color_couple_t color_base;
@@ -564,6 +730,8 @@ typedef struct lw6map_style_s
   float animation_density;
   float animation_speed;
   float cursor_size;
+  int colorize_cursor;
+  int blink_cursor;
   float hidden_layer_alpha;
   int colorize;
   int pixelize;
@@ -586,6 +754,7 @@ typedef struct lw6map_level_s
   lw6map_local_info_t local_info;
   lw6map_body_t body;
   lw6map_texture_t texture;
+  lw6map_cursor_texture_t cursor_texture;
   lw6map_param_t param;
 } lw6map_level_t;
 
@@ -660,6 +829,18 @@ extern void lw6map_coords_fix_xy (lw6map_rules_t * rules,
 extern void lw6map_coords_fix_z (lw6map_rules_t * rules,
 				 lw6sys_whd_t * shape, int *z);
 
+/* map-cursortexture.c */
+extern void lw6map_cursor_texture_layer_set (lw6map_cursor_texture_layer_t *
+					     cursor_texture, int x, int y,
+					     lw6sys_color_8_t color);
+extern lw6sys_color_8_t
+lw6map_cursor_texture_layer_get (lw6map_cursor_texture_layer_t *
+				 cursor_texture, int x, int y);
+extern void lw6map_cursor_texture_clear (lw6map_cursor_texture_t *
+					 cursor_texture);
+extern void lw6map_cursor_texture_builtin (lw6map_cursor_texture_t *
+					   cursor_texture);
+
 /* map-dup.c */
 extern lw6map_level_t *lw6map_dup (lw6map_level_t * source,
 				   lw6sys_progress_t * progress);
