@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,7 +32,11 @@
 _lw6net_context_t *_lw6net_global_context = NULL;
 
 /**
- * lw6net_init:
+ * lw6net_init
+ *
+ * @argc: argc as passed to @main
+ * @argv: argv as passed to @main
+ * @net_log: 1 if you want to enable net log, 0 if not
  * 
  * Initializes the low-level network API, you must call this before
  * calling any other network related function, for it allocates a dynamic
@@ -41,11 +45,11 @@ _lw6net_context_t *_lw6net_global_context = NULL;
  * Return value: non-zero if success
  */
 int
-lw6net_init (int argc, char *argv[])
+lw6net_init (int argc, char *argv[], int net_log)
 {
   int ok = 0;
 
-  lw6sys_log (LW6SYS_LOG_INFO, _("net init"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("net init"));
 
   _lw6net_global_context =
     (_lw6net_context_t *) LW6SYS_CALLOC (sizeof (_lw6net_context_t));
@@ -61,13 +65,13 @@ lw6net_init (int argc, char *argv[])
       err = WSAStartup (version_requested, &wsa_data);
       if (err == 0)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("WSAStartup() OK, returned 0"));
+	  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("WSAStartup() OK, returned 0"));
 	  ok = 1;
 	}
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("WSAStartup() failed with code %d \"%s\""), err,
+		      _x_ ("WSAStartup() failed with code %d \"%s\""), err,
 		      _lw6net_wsa_str (err));
 	}
 #else
@@ -83,13 +87,23 @@ lw6net_init (int argc, char *argv[])
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("signal() failed"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("signal() failed"));
 	}
 #endif
 
-      ok = _lw6net_const_init (argc, argv)
-	&& _lw6net_socket_init () && _lw6net_thread_init ()
-	&& _lw6net_dns_init () && ok;
+      ok = ok
+	&& _lw6net_const_init (argc, argv,
+			       &(_lw6net_global_context->const_data));
+      ok = ok
+	&& _lw6net_counters_init (argc, argv,
+				  &(_lw6net_global_context->counters));
+      ok = ok
+	&& _lw6net_log_init (argc, argv, &(_lw6net_global_context->log),
+			     net_log);
+      ok = ok
+	&& _lw6net_dns_init (&(_lw6net_global_context->dns),
+			     _lw6net_global_context->
+			     const_data.dns_cache_hash_size);
     }
 
   if (!ok)
@@ -115,7 +129,7 @@ lw6net_init (int argc, char *argv[])
 void
 lw6net_quit ()
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _("net quit"));
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("net quit"));
 
 #ifdef LW6_MS_WINDOWS
   WSACleanup ();
@@ -123,10 +137,10 @@ lw6net_quit ()
 
   if (_lw6net_global_context)
     {
-      _lw6net_dns_quit ();
-      _lw6net_thread_quit ();
-      _lw6net_socket_quit ();
-      _lw6net_const_quit ();
+      _lw6net_dns_quit (&(_lw6net_global_context->dns));
+      _lw6net_log_quit (&(_lw6net_global_context->log));
+      _lw6net_counters_quit (&(_lw6net_global_context->counters));
+      _lw6net_const_quit (&(_lw6net_global_context->const_data));
       LW6SYS_FREE (_lw6net_global_context);
     }
 
