@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,6 +32,15 @@
 #include "net.h"
 #include "net-internal.h"
 
+void
+_lw6net_delay_msec_to_timeval (struct timeval *tv, int delay_msec)
+{
+  memset (tv, 0, sizeof (struct timeval));
+
+  tv->tv_sec = delay_msec / 1000;
+  tv->tv_usec = delay_msec % 1000;
+}
+
 int
 lw6net_tcp_listen (char *ip, int port)
 {
@@ -47,7 +56,7 @@ lw6net_tcp_listen (char *ip, int port)
       if (listen (sock, backlog) < 0)
 	{
 	  lw6net_last_error ();
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("listen() failed"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("listen() failed"));
 
 	  lw6net_socket_close (sock);
 	  sock = -1;
@@ -59,7 +68,7 @@ lw6net_tcp_listen (char *ip, int port)
 
 int
 lw6net_tcp_accept (char **incoming_ip,
-		   int *incoming_port, int listening_sock, float delay)
+		   int *incoming_port, int listening_sock, int delay_msec)
 {
   int new_sock = -1;
   int accepted = 0;
@@ -87,8 +96,7 @@ lw6net_tcp_accept (char **incoming_ip,
     {
       FD_ZERO (&read);
       FD_SET (listening_sock, &read);
-      tv.tv_sec = (int) delay;
-      tv.tv_usec = (int) (delay / 1000000.0f);
+      _lw6net_delay_msec_to_timeval (&tv, delay_msec);
 
       res = select (listening_sock + 1, &read, NULL, NULL, &tv);
       if (res >= 1)
@@ -104,21 +112,21 @@ lw6net_tcp_accept (char **incoming_ip,
 			      (char *) &enable, sizeof (int)))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _("setsockopt(SO_KEEPALIVE) failed"));
+			      _x_ ("setsockopt(SO_KEEPALIVE) failed"));
 		  lw6net_last_error ();
 		}
 	      if (setsockopt (new_sock, SOL_SOCKET, SO_OOBINLINE,
 			      (char *) &disable, sizeof (int)))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _("setsockopt(SO_OOBINLINE) failed"));
+			      _x_ ("setsockopt(SO_OOBINLINE) failed"));
 		  lw6net_last_error ();
 		}
 	      if (setsockopt (new_sock, SOL_SOCKET, SO_LINGER,
 			      (char *) &li, sizeof (struct linger)))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _("setsockopt(SO_LINGER) failed"));
+			      _x_ ("setsockopt(SO_LINGER) failed"));
 		  lw6net_last_error ();
 		}
 
@@ -129,7 +137,9 @@ lw6net_tcp_accept (char **incoming_ip,
 		  (*incoming_ip) = _lw6net_inet_ntoa (name.sin_addr);
 		  if (*incoming_ip)
 		    {
-		      _lw6net_global_context->socket_counters.open_counter++;
+		      _lw6net_counters_register_socket (&
+							(_lw6net_global_context->
+							 counters));
 		      accepted = 1;
 		    }
 		}
@@ -142,13 +152,13 @@ lw6net_tcp_accept (char **incoming_ip,
 		  && (*incoming_port) >= 0)
 		{
 		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _("socket %d accepted from %s:%d"), new_sock,
+			      _x_ ("socket %d accepted from %s:%d"), new_sock,
 			      *incoming_ip, *incoming_port);
 		}
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, _("accept() failed"));
+	      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("accept() failed"));
 	      lw6net_last_error ();
 	    }
 
@@ -175,7 +185,7 @@ lw6net_tcp_accept (char **incoming_ip,
       if (close (new_sock))
 #endif
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("close() failed"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("close() failed"));
 	  lw6net_last_error ();
 	}
       new_sock = -1;
@@ -185,90 +195,166 @@ lw6net_tcp_accept (char **incoming_ip,
 }
 
 int
-lw6net_tcp_connect (char *ip, int port)
+lw6net_tcp_connect (char *ip, int port, int delay_msec)
 {
   int sock = -1;
+  int connect_ret = 0;
+  int connect_async = 0;
+  int select_ret = 0;
   int connected = 0;
   struct sockaddr_in name;
   int enable = 1;
   int disable = 0;
   struct linger li;
+  fd_set write;
+  struct timeval tv;
+  int64_t origin = 0;
+#ifdef LW6_MS_WINDOWS
+  int winerr = 0;
+#endif
 
   sock = socket (AF_INET, SOCK_STREAM, 0);
   if (sock >= 0)
     {
-      name.sin_family = AF_INET;
-      name.sin_addr.s_addr = INADDR_ANY;
-      name.sin_port = 0;
-      if (bind (sock, (struct sockaddr *) &name, sizeof (name)) >= 0)
+      if (lw6net_socket_set_blocking_mode (sock, 0))
 	{
 	  name.sin_family = AF_INET;
-	  if (_lw6net_inet_aton (&name.sin_addr, ip))
+	  name.sin_addr.s_addr = INADDR_ANY;
+	  name.sin_port = 0;
+	  if (bind (sock, (struct sockaddr *) &name, sizeof (name)) >= 0)
 	    {
-	      name.sin_port = htons (port);
-	      if (connect (sock, (struct sockaddr *) &name, sizeof (name)) >=
-		  0)
+	      name.sin_family = AF_INET;
+	      if (_lw6net_inet_aton (&name.sin_addr, ip))
 		{
-		  /*
-		   * Added this code copied/paste from accept.
-		   * don't know if it's usefull
-		   */
-		  li.l_onoff = 0;
-		  li.l_linger = 0;
-		  if (setsockopt (sock, SOL_SOCKET, SO_KEEPALIVE,
-				  (char *) &enable, sizeof (int)))
+		  name.sin_port = htons (port);
+		  connect_ret =
+		    connect (sock, (struct sockaddr *) &name, sizeof (name));
+		  if (connect_ret >= 0)
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _("setsockopt(SO_KEEPALIVE) failed"));
-		      lw6net_last_error ();
+				  _x_
+				  ("connect on \"%s:%d\" returned with a successfull code %d, this is very strange since we should be in non-blocking mode"),
+				  ip, port, connect_ret);
 		    }
-		  if (setsockopt (sock, SOL_SOCKET, SO_OOBINLINE,
-				  (char *) &disable, sizeof (int)))
+		  else
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _("setsockopt(SO_OOBINLINE) failed"));
-		      lw6net_last_error ();
+#ifdef LW6_MS_WINDOWS
+		      winerr = WSAGetLastError ();
+		      if (winerr == WSAEINPROGRESS)
+			{
+			  connect_async = 1;
+			}
+		      else
+			{
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _x_
+				      ("connect on \"%s:%d\" failed, did not return WSAEINPROGRESS (code=%d)"),
+				      ip, port, winerr);
+			  lw6net_last_error ();
+			}
+#else
+		      if (errno == EINPROGRESS)
+			{
+			  connect_async = 1;
+			}
+		      else
+			{
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _x_
+				      ("connect on \"%s:%d\" failed, did not return WSAEINPROGRESS (code=%d)"),
+				      ip, port);
+			  lw6net_last_error ();
+			}
+#endif
+		      if (connect_async)
+			{
+			  FD_ZERO (&write);
+			  FD_SET (sock, &write);
+			  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
+
+			  origin = lw6sys_get_timestamp ();
+			  while (!connected
+				 && (lw6sys_get_timestamp () <
+				     (origin + delay_msec)))
+			    {
+			      select_ret =
+				select (sock + 1, NULL, &write, NULL, &tv);
+
+			      if (select_ret > 0)
+				{
+				  if (FD_ISSET (sock, &write))
+				    {
+				      connected = 1;
+				    }
+				}
+			    }
+			}
 		    }
-		  if (setsockopt (sock, SOL_SOCKET, SO_LINGER,
-				  (char *) &li, sizeof (struct linger)))
+
+		  if (connected)
 		    {
-		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _("setsockopt(SO_LINGER) failed"));
-		      lw6net_last_error ();
+		      /*
+		       * Added this code copied/paste from accept.
+		       * don't know if it's usefull
+		       */
+		      li.l_onoff = 0;
+		      li.l_linger = 0;
+		      if (setsockopt (sock, SOL_SOCKET, SO_KEEPALIVE,
+				      (char *) &enable, sizeof (int)))
+			{
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _x_
+				      ("setsockopt(SO_KEEPALIVE) failed"));
+			  lw6net_last_error ();
+			}
+		      if (setsockopt (sock, SOL_SOCKET, SO_OOBINLINE,
+				      (char *) &disable, sizeof (int)))
+			{
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _x_
+				      ("setsockopt(SO_OOBINLINE) failed"));
+			  lw6net_last_error ();
+			}
+		      if (setsockopt (sock, SOL_SOCKET, SO_LINGER,
+				      (char *) &li, sizeof (struct linger)))
+			{
+			  lw6sys_log (LW6SYS_LOG_WARNING,
+				      _x_ ("setsockopt(SO_LINGER) failed"));
+			  lw6net_last_error ();
+			}
+
+		      lw6sys_log (LW6SYS_LOG_INFO,
+				  _x_ ("socket %d connected on %s:%d"), sock,
+				  ip, port);
+
+		      _lw6net_counters_register_socket (&
+							(_lw6net_global_context->
+							 counters));
+		    }
+		  else
+		    {
+		      /*
+		       * Here, no peculiar warning, connect() is definitely
+		       * the kind of function which *will* fail very
+		       * often, we certainly don't want this to fill our
+		       * log...
+		       */
 		    }
-
-		  //fcntl (sock, F_SETFL, O_NONBLOCK, 0);
-
-		  lw6sys_log (LW6SYS_LOG_INFO,
-			      _("socket %d connected on %s:%d"), sock, ip,
-			      port);
-
-		  _lw6net_global_context->socket_counters.open_counter++;
-		  connected = 1;
-		}
-	      else
-		{
-		  /*
-		   * Here, no peculiar warning, connect() is definitely
-		   * the kind of function which *will* fail very
-		   * often, we certainly don't want this to fill our
-		   * log...
-		   */
 		}
 	    }
-	}
-      else
-	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("bind() failed"));
-	  lw6net_last_error ();
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("bind() failed"));
+	      lw6net_last_error ();
+	    }
 	}
     }
 
-  if (sock >= 0 && !connected)
+  if (lw6net_socket_is_valid (sock) && !connected)
     {
       if (close (sock))
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("close() failed"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("close() failed"));
 	  lw6net_last_error ();
 	}
       sock = -1;
@@ -277,131 +363,21 @@ lw6net_tcp_connect (char *ip, int port)
   return sock;
 }
 
-static void
-async_connect_callback_func (void *callback_data)
-{
-  char *state = NULL;
-  _lw6net_socket_async_connect_data_t *async_connect_data;
-
-  async_connect_data = (_lw6net_socket_async_connect_data_t *) callback_data;
-
-  async_connect_data->sock =
-    lw6net_tcp_connect (async_connect_data->ip, async_connect_data->port);
-
-  if (async_connect_data->sock >= 0)
-    {
-      state = _("connected");
-    }
-  else
-    {
-      state = _("connexion failed");
-    }
-
-  lw6sys_log (LW6SYS_LOG_INFO,
-	      _("async connect on %s:%d has terminated, %s"),
-	      async_connect_data->ip, async_connect_data->port, state);
-}
-
-static void
-async_connect_callback_join (void *callback_data)
-{
-  _lw6net_socket_async_connect_data_t *async_connect_data;
-
-  async_connect_data = (_lw6net_socket_async_connect_data_t *) callback_data;
-
-  /*
-   * It's important to have this here, nowhere else but at the very end
-   * of the connect thread can we close the socket, it ever "got connected"
-   * after we waited "long enough".
-   */
-  if (async_connect_data->close && async_connect_data->sock >= 0)
-    {
-      lw6net_socket_close (async_connect_data->sock);
-    }
-
-  LW6SYS_FREE (async_connect_data);
-}
-
-void *
-lw6net_tcp_async_connect_init (char *ip, int port)
-{
-  void *ret = NULL;
-  _lw6net_socket_async_connect_data_t *async_connect_data = NULL;
-
-  async_connect_data =
-    LW6SYS_CALLOC (sizeof (_lw6net_socket_async_connect_data_t));
-  if (async_connect_data)
-    {
-      strncpy (async_connect_data->ip, ip, _LW6NET_IP_SIZE - 1);
-      async_connect_data->ip[_LW6NET_IP_SIZE - 1] = '\0';
-      async_connect_data->port = port;
-      async_connect_data->sock = -1;
-      async_connect_data->close = 1;
-      // all other values set to 0 (calloc)
-      ret =
-	lw6sys_thread_create (&async_connect_callback_func,
-			      &async_connect_callback_join,
-			      (void *) async_connect_data);
-      if (ret)
-	{
-	  // ok
-	  _lw6net_thread_register (ret);
-	}
-      else
-	{
-	  LW6SYS_FREE (async_connect_data);
-	}
-    }
-
-  return ret;
-}
-
 int
-lw6net_tcp_async_connect_get (int *sock, void *handler)
-{
-  int ret = 0;
-  _lw6net_socket_async_connect_data_t *async_connect_data;
-
-  if (lw6sys_thread_is_callback_done (handler))
-    {
-      async_connect_data =
-	(_lw6net_socket_async_connect_data_t *)
-	lw6sys_thread_get_data (handler);
-      (*sock) = async_connect_data->sock;
-      async_connect_data->close = 0;
-      ret = 1;
-    }
-
-  return ret;
-}
-
-void
-lw6net_tcp_async_connect_exit (void *handler)
-{
-  /*
-   * Unregister should automatically call
-   * lw6sys_thread_join(handler); but the advantage is that
-   * this way, at the end of the program, we can join all threads
-   * together and garbage collect things "properly".
-   */
-  _lw6net_thread_unregister (handler);
-}
-
-int
-lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
+lw6net_tcp_send (int sock, char *buf, int len, int delay_msec, int loop)
 {
   int ret = 0;
   fd_set write;
   struct timeval tv;
   int select_ret;
-  int total_sent;
+  int total_sent = 0;
   int sent = 0;
   int chunk_size;
 #ifdef LW6_MS_WINDOWS
   int winerr = 0;
 #endif
 
-  if (sock >= 0)
+  if (lw6net_socket_is_valid (sock))
     {
       ret = 1;
 
@@ -411,8 +387,7 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 	{
 	  FD_ZERO (&write);
 	  FD_SET (sock, &write);
-	  tv.tv_sec = (int) delay;
-	  tv.tv_usec = (int) ((delay - tv.tv_sec) * 1000000.0f);
+	  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
 
 	  select_ret = select (sock + 1, NULL, &write, NULL, &tv);
 
@@ -424,14 +399,14 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 	      if (winerr != WSAEINTR && winerr != WSAENOBUFS)
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _("select() failed, code=%d"), winerr);
+			      _x_ ("select() failed, code=%d"), winerr);
 		  lw6net_last_error ();
 		  ret = 0;
 		}
 #else
 	      if (errno != EINTR && errno != ENOBUFS)
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, _("select() failed"));
+		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("select() failed"));
 		  lw6net_last_error ();
 		  ret = 0;
 		}
@@ -446,14 +421,14 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 		  if (sent > 0 && sent <= len - total_sent)
 		    {
 		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _("%d bytes sent on TCP socket %d"), sent,
-				  sock);
+				  _x_ ("%d bytes sent on TCP socket %d"),
+				  sent, sock);
 		      total_sent += sent;
 		    }
 		  else
 		    {
 		      lw6sys_log (LW6SYS_LOG_INFO,
-				  _
+				  _x_
 				  ("can't send data on TCP socket %d (%d bytes put)"),
 				  sock, sent);
 		      ret = 0;
@@ -462,7 +437,7 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 	      break;
 	    default:
 	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _
+			  _x_
 			  ("can't send data on socket %d (select returned %d)"),
 			  sock, select_ret);
 	      ret = 0;
@@ -471,18 +446,27 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 	  if ((!loop) && (total_sent != len))
 	    {
 	      lw6sys_log (LW6SYS_LOG_INFO,
-			  _("can't send data on socket %d (%d/%d)"), sock,
+			  _x_ ("can't send data on socket %d (%d/%d)"), sock,
 			  total_sent, len);
 	      ret = 0;
 	    }
 	}
+
+      if (total_sent > 0)
+	{
+	  _lw6net_counters_register_send (&
+					  (_lw6net_global_context->counters),
+					  total_sent);
+	  _lw6net_log_tcp_send (&(_lw6net_global_context->log),
+				buf, total_sent);
+	}
     }
 
   return ret;
 }
 
 int
-lw6net_tcp_peek (int sock, char *buf, int len, float delay)
+lw6net_tcp_peek (int sock, char *buf, int len, int delay_msec)
 {
   fd_set read;
   struct timeval tv;
@@ -504,8 +488,7 @@ lw6net_tcp_peek (int sock, char *buf, int len, float delay)
 	{
 	  FD_ZERO (&read);
 	  FD_SET (sock, &read);
-	  tv.tv_sec = (int) delay;
-	  tv.tv_usec = (int) ((delay - tv.tv_sec) * 1000000.0f);
+	  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
 
 	  select_ret = select (sock + 1, &read, NULL, NULL, &tv);
 
@@ -515,7 +498,7 @@ lw6net_tcp_peek (int sock, char *buf, int len, float delay)
 		{
 		  available = recv (sock, buf2, len, MSG_PEEK);
 		  lw6sys_log (LW6SYS_LOG_DEBUG,
-			      _("%d bytes available on TCP socket %d"),
+			      _x_ ("%d bytes available on TCP socket %d"),
 			      available, sock);
 		}
 	    }
@@ -536,17 +519,17 @@ lw6net_tcp_peek (int sock, char *buf, int len, float delay)
 }
 
 int
-lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
+lw6net_tcp_recv (int sock, char *buf, int len, int delay_msec, int loop)
 {
   int ret = 0;
   fd_set read;
   struct timeval tv;
   int select_ret;
-  int total_received;
+  int total_received = 0;
   int received;
   int chunk_size;
 
-  if (sock >= 0)
+  if (lw6net_socket_is_valid (sock))
     {
       ret = 1;
       chunk_size = _lw6net_global_context->const_data.chunk_size;
@@ -556,8 +539,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 	{
 	  FD_ZERO (&read);
 	  FD_SET (sock, &read);
-	  tv.tv_sec = (int) delay;
-	  tv.tv_usec = (int) ((delay - tv.tv_sec) * 1000000.0f);
+	  _lw6net_delay_msec_to_timeval (&tv, delay_msec);
 
 	  select_ret = select (sock + 1, &read, NULL, NULL, &tv);
 
@@ -567,7 +549,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 	      if (errno != EINTR)
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING,
-			      _
+			      _x_
 			      ("error receiving data on socket %d (select error %d)"),
 			      sock, errno);
 		  lw6net_last_error ();
@@ -584,14 +566,14 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 		  if (received > 0 && received <= len - total_received)
 		    {
 		      lw6sys_log (LW6SYS_LOG_DEBUG,
-				  _("%d bytes received on TCP socket %d"),
+				  _x_ ("%d bytes received on TCP socket %d"),
 				  received, sock);
 		      total_received += received;
 		    }
 		  else
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
-				  _
+				  _x_
 				  ("can't recv data on socket %d (got %d bytes)"),
 				  sock, received);
 		      lw6net_last_error ();
@@ -601,7 +583,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 	      break;
 	    default:
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _
+			  _x_
 			  ("can't recv data on socket %d (select returned %d)"),
 			  sock, select_ret);
 	      lw6net_last_error ();
@@ -611,12 +593,21 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 	  if ((!loop) && (total_received != len))
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _("can't recv data on socket %d (%d/%d)"), sock,
+			  _x_ ("can't recv data on socket %d (%d/%d)"), sock,
 			  total_received, len);
 	      lw6net_last_error ();
 	      ret = 0;
 	    }
 	}
+
+      if (total_received > 0)
+	{
+	  _lw6net_counters_register_recv (&
+					  (_lw6net_global_context->counters),
+					  total_received);
+	  _lw6net_log_tcp_recv (&(_lw6net_global_context->log),
+				buf, total_received);
+	}
     }
 
   return ret;
