@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #define LIQUIDWAR6P2P_INTERNAL_H
 
 #include "p2p.h"
+
 #include <sqlite3.h>
 
 #define _LW6P2P_DB_FALSE 0
@@ -45,7 +46,7 @@
 #define _LW6P2P_SELECT_OTHER_NODE_SQL "select-other-node.sql"
 #define _LW6P2P_UPDATE_NODE_SQL "update-node.sql"
 
-#define _LW6P2P_DB_NODE_NB_FIELDS 22
+#define _LW6P2P_DB_NODE_NB_FIELDS 25
 #define _LW6P2P_DB_NODE_ORDER_CREATION_TIMESTAMP 0
 #define _LW6P2P_DB_NODE_ORDER_VERSION 1
 #define _LW6P2P_DB_NODE_ORDER_CODENAME 2
@@ -54,20 +55,23 @@
 #define _LW6P2P_DB_NODE_ORDER_URL 5
 #define _LW6P2P_DB_NODE_ORDER_TITLE 6
 #define _LW6P2P_DB_NODE_ORDER_DESCRIPTION 7
-#define _LW6P2P_DB_NODE_ORDER_PASSWORD 8
+#define _LW6P2P_DB_NODE_ORDER_HAS_PASSWORD 8
 #define _LW6P2P_DB_NODE_ORDER_BENCH 9
-#define _LW6P2P_DB_NODE_ORDER_LEVEL 10
-#define _LW6P2P_DB_NODE_ORDER_REQUIRED_BENCH 11
-#define _LW6P2P_DB_NODE_ORDER_NB_COLORS 12
-#define _LW6P2P_DB_NODE_ORDER_MAX_NB_COLORS 13
-#define _LW6P2P_DB_NODE_ORDER_NB_CURSORS 14
-#define _LW6P2P_DB_NODE_ORDER_MAX_NB_CURSORS 15
-#define _LW6P2P_DB_NODE_ORDER_NB_NODES 16
-#define _LW6P2P_DB_NODE_ORDER_MAX_NB_NODES 17
-#define _LW6P2P_DB_NODE_ORDER_IP 18
-#define _LW6P2P_DB_NODE_ORDER_PORT 19
-#define _LW6P2P_DB_NODE_ORDER_LAST_PING_TIMESTAMP 20
-#define _LW6P2P_DB_NODE_ORDER_PING_DELAY_MSEC 21
+#define _LW6P2P_DB_NODE_ORDER_OPEN_RELAY 10
+#define _LW6P2P_DB_NODE_ORDER_COMMUNITY_ID 11
+#define _LW6P2P_DB_NODE_ORDER_ROUND 12
+#define _LW6P2P_DB_NODE_ORDER_REQUIRED_BENCH 13
+#define _LW6P2P_DB_NODE_ORDER_LEVEL 14
+#define _LW6P2P_DB_NODE_ORDER_NB_COLORS 15
+#define _LW6P2P_DB_NODE_ORDER_MAX_NB_COLORS 16
+#define _LW6P2P_DB_NODE_ORDER_NB_CURSORS 17
+#define _LW6P2P_DB_NODE_ORDER_MAX_NB_CURSORS 18
+#define _LW6P2P_DB_NODE_ORDER_NB_NODES 19
+#define _LW6P2P_DB_NODE_ORDER_MAX_NB_NODES 20
+#define _LW6P2P_DB_NODE_ORDER_IP 21
+#define _LW6P2P_DB_NODE_ORDER_PORT 22
+#define _LW6P2P_DB_NODE_ORDER_LAST_PING_TIMESTAMP 23
+#define _LW6P2P_DB_NODE_ORDER_PING_DELAY_MSEC 24
 
 typedef int (*_lw6p2p_db_callback_t) (void *func_data, int nb_fields,
 				      char **fields_values,
@@ -83,6 +87,8 @@ typedef struct _lw6p2p_consts_s
   int node_expire_soft_delay;
   int node_expire_hard_delay;
   int node_verify_max_at_once;
+  int foo_delay;
+  int ticket_table_hash_size;
 }
 _lw6p2p_consts_t;
 
@@ -132,6 +138,35 @@ typedef struct _lw6p2p_explore_s
 }
 _lw6p2p_explore_t;
 
+typedef struct _lw6p2p_backends_s
+{
+  int nb_cli_backends;
+  lw6cli_backend_t **cli_backends;
+  int nb_srv_backends;
+  lw6srv_backend_t **srv_backends;
+} _lw6p2p_backends_t;
+
+typedef struct _lw6p2p_tentacle_s
+{
+  _lw6p2p_backends_t *backends;
+  char *local_url;
+  char *remote_url;
+  char *remote_ip;
+  int remote_port;
+  char *password;
+  u_int64_t local_id_int;
+  char *local_id_str;
+  u_int64_t remote_id_int;
+  char *remote_id_str;
+  int hello_sent;
+  int data_exchanged;
+  int dns_ok;
+  int nb_cli_connections;
+  lw6cnx_connection_t **cli_connections;
+  int nb_srv_connections;
+  lw6cnx_connection_t **srv_connections;
+} _lw6p2p_tentacle_t;
+
 typedef struct _lw6p2p_node_s
 {
   u_int32_t id;
@@ -139,21 +174,23 @@ typedef struct _lw6p2p_node_s
   _lw6p2p_db_t *db;
   char *bind_ip;
   int bind_port;
+  int broadcast;
   u_int64_t node_id_int;
   char *node_id_str;
   char *public_url;
   char *password;
   lw6nod_info_t *node_info;
   char *known_nodes;
-  int nb_cli_backends;
-  lw6cli_backend_t **cli_backends;
+  int network_reliability;
+  int trojan;
   lw6srv_listener_t *listener;
-  int nb_srv_backends;
-  lw6srv_backend_t **srv_backends;
+  _lw6p2p_backends_t backends;
   lw6sys_list_t *srv_oobs;
   lw6sys_list_t *cli_oobs;
   _lw6p2p_flush_t flush;
   _lw6p2p_explore_t explore;
+  lw6cnx_ticket_table_t ticket_table;
+  _lw6p2p_tentacle_t tentacles[LW6P2P_MAX_NB_TENTACLES];
 } _lw6p2p_node_t;
 
 typedef struct _lw6p2p_srv_oob_callback_data_s
@@ -170,6 +207,17 @@ typedef struct _lw6p2p_cli_oob_callback_data_s
   lw6cli_oob_t *cli_oob;
 } _lw6p2p_cli_oob_callback_data_t;
 
+/* p2p-backends.c */
+extern int _lw6p2p_backends_init_cli (int argc, char *argv[],
+				      _lw6p2p_backends_t * backends,
+				      char *client_backends);
+extern int _lw6p2p_backends_init_srv (int argc, char *argv[],
+				      _lw6p2p_backends_t * backends,
+				      char *server_backends,
+				      lw6srv_listener_t * listener);
+extern void _lw6p2p_backends_clear_cli (_lw6p2p_backends_t * backends);
+extern void _lw6p2p_backends_clear_srv (_lw6p2p_backends_t * backends);
+
 /* p2p-clioob.c */
 extern _lw6p2p_cli_oob_callback_data_t
   * _lw6p2p_cli_oob_callback_data_new (lw6cli_backend_t * backend,
@@ -223,16 +271,57 @@ extern _lw6p2p_node_t *_lw6p2p_node_new (int argc, char *argv[],
 					 char *client_backends,
 					 char *server_backends,
 					 char *bind_ip,
-					 int bind_port, u_int64_t node_id,
-					 char *public_url, char *password,
-					 char *title, char *description,
-					 int bench, char *known_nodes);
+					 int bind_port, int broadcast,
+					 char *public_url,
+					 char *title,
+					 char *description, char *password,
+					 int bench, int open_relay,
+					 char *known_nodes,
+					 int network_reliability, int trojan);
 extern void _lw6p2p_node_free (_lw6p2p_node_t * node);
 extern char *_lw6p2p_node_repr (_lw6p2p_node_t * node);
 extern int _lw6p2p_node_poll (_lw6p2p_node_t * node);
 extern void _lw6p2p_node_close (_lw6p2p_node_t * node);
+extern u_int64_t _lw6p2p_node_get_id (_lw6p2p_node_t * node);
 extern int _lw6p2p_node_insert_discovered (_lw6p2p_node_t * node,
 					   char *public_url);
+extern int _lw6p2p_node_update_peer (_lw6p2p_node_t * node, char *version,
+				     char *codename, int stamp, char *id,
+				     char *url, char *title,
+				     char *description, int password,
+				     int bench, int open_relay,
+				     int creation_timestamp,
+				     char *community_id, int round,
+				     char *level, int required_bench,
+				     int nb_colors, int max_nb_colors,
+				     int nb_cursors, int max_nb_cursors,
+				     int nb_nodes, int max_nb_nodes, char *ip,
+				     int port, int last_ping_timestamp,
+				     int ping_delay_msec);
+extern int _lw6p2p_node_find_free_tentacle (_lw6p2p_node_t * node);
+extern int _lw6p2p_node_find_tentacle (_lw6p2p_node_t * node,
+				       u_int64_t remote_id);
+extern int _lw6p2p_node_register_tentacle (_lw6p2p_node_t * node,
+					   char *remote_url,
+					   char *real_remote_ip,
+					   u_int64_t remote_id);
+extern int _lw6p2p_node_unregister_tentacle (_lw6p2p_node_t * node,
+					     u_int64_t remote_id);
+
+/* p2p-recv.c */
+extern void _lw6p2p_recv_process (_lw6p2p_node_t * node,
+				  lw6cnx_connection_t * cnx,
+				  u_int64_t logical_from_id, char *message);
+extern void _lw6p2p_recv_forward (_lw6p2p_node_t * node,
+				  lw6cnx_connection_t * cnx,
+				  u_int32_t logical_ticket_sig,
+				  u_int64_t logical_from_id,
+				  u_int64_t logical_to_id, char *message);
+extern void _lw6p2p_recv_callback (void *recv_callback_data, void *connection,
+				   u_int32_t physical_ticket_sig,
+				   u_int32_t logical_ticket_sig,
+				   u_int64_t logical_from_id,
+				   u_int64_t logical_to_id, char *message);
 
 /* p2p-srvoob.c */
 extern _lw6p2p_srv_oob_callback_data_t
@@ -246,4 +335,42 @@ _lw6p2p_srv_oob_callback_data_free (_lw6p2p_srv_oob_callback_data_t *
 extern int _lw6p2p_srv_oob_filter (_lw6p2p_srv_oob_callback_data_t * srv_oob);
 extern void _lw6p2p_srv_oob_callback (void *callback_data);
 
+/* p2p-tentacle.c */
+extern int _lw6p2p_tentacle_init (_lw6p2p_tentacle_t * tentacle,
+				  _lw6p2p_backends_t * backends,
+				  lw6srv_listener_t * listener,
+				  char *local_url,
+				  char *remote_url,
+				  char *real_remote_ip,
+				  char *password,
+				  u_int64_t local_id, u_int64_t remote_id,
+				  int network_reliability,
+				  lw6cnx_recv_callback_t recv_callback_func,
+				  void *recv_callback_data);
+extern void _lw6p2p_tentacle_clear (_lw6p2p_tentacle_t * tentacle);
+extern int _lw6p2p_tentacle_enabled (_lw6p2p_tentacle_t * tentacle);
+extern void _lw6p2p_tentacle_poll (_lw6p2p_tentacle_t * tentacle,
+				   lw6nod_info_t * node_info,
+				   lw6cnx_ticket_table_t * ticket_table,
+				   int foo_delay);
+extern int _lw6p2p_tentacle_send_best (_lw6p2p_tentacle_t * tentacle,
+				       lw6cnx_ticket_table_t * ticket_table,
+				       u_int32_t logical_ticket_sig,
+				       u_int64_t logical_from_id,
+				       u_int64_t logical_to_id, char *msg);
+extern int _lw6p2p_tentacle_send_redundant (_lw6p2p_tentacle_t * tentacle,
+					    lw6cnx_ticket_table_t *
+					    ticket_table,
+					    u_int32_t logical_ticket_sig,
+					    u_int64_t logical_from_id,
+					    u_int64_t logical_to_id,
+					    char *msg);
+extern lw6cnx_connection_t
+  * _lw6p2p_tentacle_find_connection_with_foo_bar_key (_lw6p2p_tentacle_t *
+						       tentacle,
+						       u_int32_t foo_bar_key);
+extern lw6cnx_connection_t
+  * _lw6p2p_tentacle_find_connection_with_lowest_ping (_lw6p2p_tentacle_t *
+						       tentacle);
+
 #endif
