@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,8 +28,16 @@
 #include "mod-ogg.h"
 #include "mod-ogg-internal.h"
 
+/*
+ * http://www.gnu.org/prep/standards/html_node/Dynamic-Plug_002dIn-Interfaces.html
+ */
+void
+mod_ogg_is_GPL_compatible ()
+{
+}
+
 static int
-_play_sound (void *snd_context, int sound_id)
+_play_fx (void *snd_context, int fx_id)
 {
   int ret = 0;
 
@@ -37,7 +45,7 @@ _play_sound (void *snd_context, int sound_id)
 
   if (mod_ogg_context)
     {
-      ret = _mod_ogg_play_sound (mod_ogg_context, sound_id);
+      ret = _mod_ogg_play_fx (mod_ogg_context, fx_id);
     }
 
   return ret;
@@ -103,22 +111,34 @@ _stop_music (void *snd_context)
 }
 
 static void *
-_init (int argc, char *argv[], float sound_volume, float music_volume)
+_init (int argc, char *argv[], float fx_volume, float water_volume,
+       float music_volume)
 {
   _mod_ogg_context_t *mod_ogg_context =
-    _mod_ogg_init (argc, argv, sound_volume, music_volume);
+    _mod_ogg_init (argc, argv, fx_volume, water_volume, music_volume);
 
   return (void *) mod_ogg_context;
 }
 
 static void
-_set_sound_volume (void *snd_context, float volume)
+_set_fx_volume (void *snd_context, float volume)
 {
   _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
 
   if (mod_ogg_context)
     {
-      _mod_ogg_set_sound_volume (mod_ogg_context, volume);
+      _mod_ogg_set_fx_volume (mod_ogg_context, volume);
+    }
+}
+
+static void
+_set_water_volume (void *snd_context, float volume)
+{
+  _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
+
+  if (mod_ogg_context)
+    {
+      _mod_ogg_set_water_volume (mod_ogg_context, volume);
     }
 }
 
@@ -133,6 +153,17 @@ _set_music_volume (void *snd_context, float volume)
     }
 }
 
+static void
+_poll (void *snd_context)
+{
+  _mod_ogg_context_t *mod_ogg_context = (_mod_ogg_context_t *) snd_context;
+
+  if (mod_ogg_context)
+    {
+      _mod_ogg_poll (mod_ogg_context);
+    }
+}
+
 static void
 _quit (void *snd_context)
 {
@@ -170,13 +201,13 @@ mod_ogg_get_pedigree ()
     {
       module_pedigree->id = "ogg";
       module_pedigree->category = "snd";
-      module_pedigree->name = _("Ogg Vorbis");
+      module_pedigree->name = _x_ ("Ogg Vorbis");
       module_pedigree->readme =
-	_
+	_x_
 	("This sound backend uses Ogg Vorbis (through SDL) to handle sound effects and music. This is the only working sound backend for now.");
       module_pedigree->version = VERSION;
       module_pedigree->copyright =
-	"Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>";
+	"Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -195,14 +226,16 @@ mod_ogg_create_backend ()
     {
       memset (backend, 0, sizeof (lw6snd_backend_t));
 
-      backend->play_sound = _play_sound;
+      backend->play_fx = _play_fx;
       backend->is_music_file = _is_music_file;
       backend->play_music_file = _play_music_file;
       backend->play_music_random = _play_music_random;
       backend->stop_music = _stop_music;
       backend->init = _init;
-      backend->set_sound_volume = _set_sound_volume;
+      backend->set_fx_volume = _set_fx_volume;
+      backend->set_water_volume = _set_water_volume;
       backend->set_music_volume = _set_music_volume;
+      backend->poll = _poll;
       backend->quit = _quit;
       backend->repr = _repr;
     }
