@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,15 +28,41 @@
 #include <SDL/SDL.h>
 #include <SDL/SDL_mixer.h>
 
+#define _MOD_OGG_CHANNEL_WATER1 0
+#define _MOD_OGG_CHANNEL_WATER2 1
+#define _MOD_OGG_CHANNEL_FX0 2
+#define _MOD_OGG_CHANNEL_GROUP_FX 1
+#define _MOD_OGG_CHANNEL_GROUP_WATER 2
+
+#define _MOD_OGG_NB_WATER 6
+typedef enum _mod_ogg_water_enum_e
+{
+  _MOD_OGG_WATER1 = 0,
+  _MOD_OGG_WATER2 = 1,
+  _MOD_OGG_WATER3 = 2,
+  _MOD_OGG_WATER4 = 3,
+  _MOD_OGG_WATER5 = 4,
+  _MOD_OGG_WATER6 = 5
+}
+_mod_ogg_water_enum_t;
+
 typedef struct _mod_ogg_path_s
 {
   char *data_dir;
 }
 _mod_ogg_path_t;
 
+typedef struct _mod_ogg_mixer_s
+{
+  int nb_channels;
+  int last_channel;
+}
+_mod_ogg_mixer_t;
+
 typedef struct _mod_ogg_volume_s
 {
-  float sound;
+  float fx;
+  float water;
   float music;
 }
 _mod_ogg_volume_t;
@@ -47,14 +73,37 @@ typedef struct _mod_ogg_const_data_s
   int bits;
   int channels;
   int chunksize;
+  float water_pan1;
+  float water_pan2;
+  char *file_splash;
+  char *file_valid;
+  char *file_select;
+  char *file_start;
+  char *file_death;
+  char *file_bell;
+  char *file_score;
+  char *file_hello;
+  char *file_goodbye;
+  char *file_water1;
+  char *file_water2;
+  char *file_water3;
+  char *file_water4;
+  char *file_water5;
+  char *file_water6;
 }
 _mod_ogg_const_data_t;
 
-typedef struct _mod_ogg_sounds_s
+typedef struct _mod_ogg_fx_s
 {
-  Mix_Chunk *sounds[LW6SND_NB_SOUNDS];
+  Mix_Chunk *fx[LW6SND_NB_FX];
 }
-_mod_ogg_sounds_t;
+_mod_ogg_fx_t;
+
+typedef struct _mod_ogg_water_s
+{
+  Mix_Chunk *water[_MOD_OGG_NB_WATER];
+}
+_mod_ogg_water_t;
 
 typedef struct _mod_ogg_music_s
 {
@@ -67,9 +116,11 @@ _mod_ogg_music_t;
 typedef struct _mod_ogg_context_s
 {
   _mod_ogg_path_t path;
+  _mod_ogg_mixer_t mixer;
   _mod_ogg_volume_t volume;
   _mod_ogg_const_data_t const_data;
-  _mod_ogg_sounds_t sounds;
+  _mod_ogg_fx_t fx;
+  _mod_ogg_water_t water;
   _mod_ogg_music_t music;
 }
 _mod_ogg_context_t;
@@ -81,12 +132,11 @@ extern int _mod_ogg_load_consts (_mod_ogg_context_t * ogg_context);
 extern void _mod_ogg_unload_consts (_mod_ogg_context_t * ogg_context);
 
 /*
- * In sound.c
+ * In fx.c
  */
-extern int _mod_ogg_play_sound (_mod_ogg_context_t * ogg_context,
-				int sound_id);
-extern int _mod_ogg_load_sounds (_mod_ogg_context_t * ogg_context);
-extern void _mod_ogg_unload_sounds (_mod_ogg_context_t * ogg_context);
+extern int _mod_ogg_play_fx (_mod_ogg_context_t * ogg_context, int fx_id);
+extern int _mod_ogg_load_fx (_mod_ogg_context_t * ogg_context);
+extern void _mod_ogg_unload_fx (_mod_ogg_context_t * ogg_context);
 
 /*
  * In music.c
@@ -116,16 +166,26 @@ extern char *_mod_ogg_repr (_mod_ogg_context_t * gfx_context, u_int32_t id);
  * In setup.c
  */
 extern _mod_ogg_context_t *_mod_ogg_init (int argc, char *argv[],
-					  float sound_volume,
+					  float fx_volume, float water_volume,
 					  float music_volume);
+extern void _mod_ogg_poll (_mod_ogg_context_t * ogg_context);
 extern void _mod_ogg_quit (_mod_ogg_context_t * ogg_context);
 
 /*
  * In volume.c
  */
-extern void _mod_ogg_set_sound_volume (_mod_ogg_context_t * ogg_context,
+extern void _mod_ogg_set_fx_volume (_mod_ogg_context_t * ogg_context,
+				    float volume);
+extern void _mod_ogg_set_water_volume (_mod_ogg_context_t * ogg_context,
 				       float volume);
 extern void _mod_ogg_set_music_volume (_mod_ogg_context_t * ogg_context,
 				       float volume);
 
+/*
+ * In water.c
+ */
+extern void _mod_ogg_poll_water (_mod_ogg_context_t * ogg_context);
+extern int _mod_ogg_load_water (_mod_ogg_context_t * ogg_context);
+extern void _mod_ogg_unload_water (_mod_ogg_context_t * ogg_context);
+
 #endif
