@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,19 +30,19 @@ static void
 _warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
-	      _("snd backend function \"%s\" is not defined"), func_name);
+	      _x_ ("snd backend function \"%s\" is not defined"), func_name);
 }
 
 int
-lw6snd_play_sound (lw6snd_backend_t * backend, int sound_id)
+lw6snd_play_fx (lw6snd_backend_t * backend, int fx_id)
 {
   int ret = 0;
 
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->play_sound)
+  if (backend->play_fx)
     {
-      ret = backend->play_sound (backend->snd_context, sound_id);
+      ret = backend->play_fx (backend->snd_context, fx_id);
     }
   else
     {
@@ -101,7 +101,7 @@ lw6snd_play_music_file (lw6snd_backend_t * backend, char *map_dir,
       if (strlen (music_file) > 0)
 	{
 	  lw6sys_log (LW6SYS_LOG_DEBUG,
-		      _
+		      _x_
 		      ("trying song \"%s\" with map_dir=\"%s\" and music_path=\"%d\""),
 		      music_file, map_dir, music_path);
 	  found_path =
@@ -131,7 +131,7 @@ lw6snd_play_music_random (lw6snd_backend_t * backend, char *music_path,
   if (backend->play_music_random)
     {
       lw6sys_log (LW6SYS_LOG_DEBUG,
-		  _
+		  _x_
 		  ("picking a random song in \"%s\" using filter \"%s\" and exclude \"%s\""),
 		  music_path, music_filter, music_exclude);
       ret =
@@ -166,7 +166,7 @@ lw6snd_stop_music (lw6snd_backend_t * backend)
 }
 
 int
-lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
+lw6snd_init (lw6snd_backend_t * backend, float fx_volume, float water_volume,
 	     float music_volume)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
@@ -174,7 +174,7 @@ lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
   if (backend->init)
     {
       backend->snd_context =
-	backend->init (backend->argc, backend->argv, sound_volume,
+	backend->init (backend->argc, backend->argv, fx_volume, water_volume,
 		       music_volume);
     }
   else
@@ -188,13 +188,30 @@ lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
 }
 
 void
-lw6snd_set_sound_volume (lw6snd_backend_t * backend, float volume)
+lw6snd_set_fx_volume (lw6snd_backend_t * backend, float volume)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->set_sound_volume)
+  if (backend->set_fx_volume)
     {
-      backend->set_sound_volume (backend->snd_context, volume);
+      backend->set_fx_volume (backend->snd_context, volume);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
+void
+lw6snd_set_water_volume (lw6snd_backend_t * backend, float volume)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->set_water_volume)
+    {
+      backend->set_water_volume (backend->snd_context, volume);
     }
   else
     {
@@ -221,6 +238,26 @@ lw6snd_set_music_volume (lw6snd_backend_t * backend, float volume)
   LW6SYS_BACKEND_FUNCTION_END;
 }
 
+void
+lw6snd_poll (lw6snd_backend_t * backend)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->poll)
+    {
+      if (backend->snd_context)
+	{
+	  backend->poll (backend->snd_context);
+	}
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
 void
 lw6snd_quit (lw6snd_backend_t * backend)
 {
