@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,16 +27,20 @@
 #include "../dyn/dyn.h"
 #include "../cfg/cfg.h"
 
-#define LW6SND_NB_SOUNDS 4
-typedef enum lw6snd_sound_enum_e
+#define LW6SND_NB_FX 9
+typedef enum lw6snd_fx_enum_e
 {
-  LW6SND_SOUND_SPLASH = 0,
-  LW6SND_SOUND_BEEP_VALID = 1,
-  LW6SND_SOUND_BEEP_SELECT = 2,
-  LW6SND_SOUND_START = 3
+  LW6SND_FX_SPLASH = 0,
+  LW6SND_FX_VALID = 1,
+  LW6SND_FX_SELECT = 2,
+  LW6SND_FX_START = 3,
+  LW6SND_FX_DEATH = 4,
+  LW6SND_FX_BELL = 5,
+  LW6SND_FX_SCORE = 6,
+  LW6SND_FX_HELLO = 7,
+  LW6SND_FX_GOODBYE = 8
 }
-lw6snd_sound_enum_t;
-
+lw6snd_fx_enum_t;
 
 typedef struct lw6snd_backend_s
 {
@@ -46,16 +50,18 @@ typedef struct lw6snd_backend_s
   char **argv;
   u_int32_t id;
 
-  int (*play_sound) (void *snd_context, int sound_id);
+  int (*play_fx) (void *snd_context, int fx_id);
   int (*is_music_file) (void *snd_context, char *music_file);
   int (*play_music_file) (void *snd_context, char *music_file);
   int (*play_music_random) (void *snd_context, char *music_path,
 			    char *music_filter, char *music_exclude);
   void (*stop_music) (void *snd_context);
-  void *(*init) (int argc, char *argv[], float sound_volume,
+  void *(*init) (int argc, char *argv[], float fx_volume, float water_volume,
 		 float music_volume);
-  void (*set_sound_volume) (void *snd_context, float volume);
+  void (*set_fx_volume) (void *snd_context, float volume);
+  void (*set_water_volume) (void *snd_context, float volume);
   void (*set_music_volume) (void *snd_context, float volume);
+  void (*poll) (void *snd_context);
   void (*quit) (void *snd_context);
   char *(*repr) (void *snd_context, u_int32_t id);
 }
@@ -64,7 +70,7 @@ lw6snd_backend_t;
 /*
  * In api.c
  */
-extern int lw6snd_play_sound (lw6snd_backend_t * backend, int sound_id);
+extern int lw6snd_play_fx (lw6snd_backend_t * backend, int fx_id);
 extern int lw6snd_is_music_file (lw6snd_backend_t * backend,
 				 char *map_dir,
 				 char *music_path, char *music_file);
@@ -76,12 +82,14 @@ extern int lw6snd_play_music_random (lw6snd_backend_t * backend,
 				     char *music_exclude);
 extern void lw6snd_stop_music (lw6snd_backend_t * backend);
 extern char *lw6snd_repr (lw6snd_backend_t * snd_backend);
-extern int lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
-			float music_volume);
-extern void lw6snd_set_sound_volume (lw6snd_backend_t * backend,
+extern int lw6snd_init (lw6snd_backend_t * backend, float fx_volume,
+			float water_volume, float music_volume);
+extern void lw6snd_set_fx_volume (lw6snd_backend_t * backend, float volume);
+extern void lw6snd_set_water_volume (lw6snd_backend_t * backend,
 				     float volume);
 extern void lw6snd_set_music_volume (lw6snd_backend_t * backend,
 				     float volume);
+extern void lw6snd_poll (lw6snd_backend_t * backend);
 extern void lw6snd_quit (lw6snd_backend_t * backend);
 extern char *lw6snd_repr (lw6snd_backend_t * backend);
 
