@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,10 +28,19 @@
 #include "mod-httpd.h"
 #include "mod-httpd-internal.h"
 
+/*
+ * http://www.gnu.org/prep/standards/html_node/Dynamic-Plug_002dIn-Interfaces.html
+ */
+void
+mod_httpd_is_GPL_compatible ()
+{
+}
+
 static void *
 _init (int argc, char *argv[], lw6srv_listener_t * listener)
 {
-  _httpd_context_t *httpd_context = _mod_httpd_init (argc, argv, listener);
+  _mod_httpd_context_t *httpd_context =
+    _mod_httpd_init (argc, argv, listener);
 
   return (void *) httpd_context;
 }
@@ -39,7 +48,7 @@ _init (int argc, char *argv[], lw6srv_listener_t * listener)
 static void
 _quit (void *srv_context)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
 
   if (httpd_context)
     {
@@ -48,28 +57,36 @@ _quit (void *srv_context)
 }
 
 static int
-_analyse_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter)
+_analyse_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
+	      lw6nod_info_t * node_info,
+	      u_int64_t * remote_id, char **remote_url)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   int ret = 0;
 
   if (httpd_context)
     {
-      ret = _mod_httpd_analyse_tcp (httpd_context, tcp_accepter);
+      ret =
+	_mod_httpd_analyse_tcp (httpd_context, tcp_accepter, node_info,
+				remote_id, remote_url);
     }
 
   return ret;
 }
 
 static int
-_analyse_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer)
+_analyse_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer,
+	      lw6nod_info_t * node_info,
+	      u_int64_t * remote_id, char **remote_url)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   int ret = 0;
 
   if (httpd_context)
     {
-      ret = _mod_httpd_analyse_udp (httpd_context, udp_buffer);
+      ret =
+	_mod_httpd_analyse_udp (httpd_context, udp_buffer, node_info,
+				remote_id, remote_url);
     }
 
   return ret;
@@ -79,7 +96,7 @@ static int
 _process_oob (void *srv_context, lw6nod_info_t * node_info,
 	      lw6srv_oob_data_t * oob_data)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   int ret = 0;
 
   if (httpd_context)
@@ -90,72 +107,64 @@ _process_oob (void *srv_context, lw6nod_info_t * node_info,
   return ret;
 }
 
-static lw6srv_connection_t *
-_accept_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
-	     char *password)
+static lw6cnx_connection_t *
+_open (void *srv_context, lw6srv_listener_t * listener, char *local_url,
+       char *remote_url, char *remote_ip,
+       int remote_port, char *password,
+       u_int64_t local_id, u_int64_t remote_id, int dns_ok,
+       int network_reliability, lw6cnx_recv_callback_t recv_callback_func,
+       void *recv_callback_data)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
-  lw6srv_connection_t *ret = NULL;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
+  lw6cnx_connection_t *ret = NULL;
 
   if (httpd_context)
     {
-      ret = _mod_httpd_accept_tcp (httpd_context, tcp_accepter, password);
-    }
-
-  return ret;
-}
-
-static lw6srv_connection_t *
-_new_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer, char *password)
-{
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
-  lw6srv_connection_t *ret = NULL;
-
-  if (httpd_context)
-    {
-      ret = _mod_httpd_new_udp (httpd_context, udp_buffer, password);
+      ret =
+	_mod_httpd_open (httpd_context, listener, local_url, remote_url,
+			 remote_ip, remote_port, password, local_id,
+			 remote_id, dns_ok, network_reliability,
+			 recv_callback_func, recv_callback_data);
     }
 
   return ret;
 }
 
 static int
-_is_associated_with_udp (void *srv_context, lw6srv_connection_t * connection,
-			 lw6srv_udp_buffer_t * udp_buffer)
+_feed_with_tcp (void *srv_context, lw6cnx_connection_t * connection,
+		lw6srv_tcp_accepter_t * tcp_accepter)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   int ret = 0;
 
   if (connection)
     {
       ret =
-	_mod_httpd_is_associated_with_udp (httpd_context, connection,
-					   udp_buffer);
+	_mod_httpd_feed_with_tcp (httpd_context, connection, tcp_accepter);
     }
 
   return ret;
 }
 
 static int
-_update_with_udp (void *srv_context, lw6srv_connection_t * connection,
-		  lw6srv_udp_buffer_t * udp_buffer)
+_feed_with_udp (void *srv_context, lw6cnx_connection_t * connection,
+		lw6srv_udp_buffer_t * udp_buffer)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   int ret = 0;
 
   if (connection)
     {
-      ret =
-	_mod_httpd_update_with_udp (httpd_context, connection, udp_buffer);
+      ret = _mod_httpd_feed_with_udp (httpd_context, connection, udp_buffer);
     }
 
   return ret;
 }
 
 static void
-_close (void *srv_context, lw6srv_connection_t * connection)
+_close (void *srv_context, lw6cnx_connection_t * connection)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
 
   if (connection)
     {
@@ -164,51 +173,39 @@ _close (void *srv_context, lw6srv_connection_t * connection)
 }
 
 static int
-_send (void *srv_context, lw6srv_connection_t * connection, char *message)
+_send (void *srv_context, lw6cnx_connection_t * connection,
+       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
+       u_int64_t logical_from_id, u_int64_t logical_to_id, char *message)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   int ret = 0;
 
   if (connection)
     {
-      ret = _mod_httpd_send (httpd_context, connection, message);
+      ret =
+	_mod_httpd_send (httpd_context, connection, physical_ticket_sig,
+			 logical_ticket_sig, logical_from_id, logical_to_id,
+			 message);
     }
 
   return ret;
 }
 
-static char *
-_recv (void *srv_context, lw6srv_connection_t * connection)
+static void
+_poll (void *srv_context, lw6cnx_connection_t * connection)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
-  char *ret = NULL;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
 
   if (connection)
     {
-      ret = _mod_httpd_recv (httpd_context, connection);
+      _mod_httpd_poll (httpd_context, connection);
     }
-
-  return ret;
-}
-
-static int
-_is_alive (void *srv_context, lw6srv_connection_t * connection)
-{
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
-  int ret = 0;
-
-  if (connection)
-    {
-      ret = _mod_httpd_is_alive (httpd_context, connection);
-    }
-
-  return ret;
 }
 
 static char *
-_repr (void *srv_context, lw6srv_connection_t * connection)
+_repr (void *srv_context, lw6cnx_connection_t * connection)
 {
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
+  _mod_httpd_context_t *httpd_context = (_mod_httpd_context_t *) srv_context;
   char *ret = NULL;
 
   if (connection)
@@ -219,20 +216,6 @@ _repr (void *srv_context, lw6srv_connection_t * connection)
   return ret;
 }
 
-static char *
-_error (void *srv_context, lw6srv_connection_t * connection)
-{
-  _httpd_context_t *httpd_context = (_httpd_context_t *) srv_context;
-  char *ret = NULL;
-
-  if (connection)
-    {
-      ret = _mod_httpd_error (httpd_context, connection);
-    }
-
-  return ret;
-}
-
 lw6sys_module_pedigree_t *
 mod_httpd_get_pedigree ()
 {
@@ -245,13 +228,13 @@ mod_httpd_get_pedigree ()
     {
       module_pedigree->id = "httpd";
       module_pedigree->category = "srv";
-      module_pedigree->name = _("HTTPD");
+      module_pedigree->name = _x_ ("HTTPD");
       module_pedigree->readme =
-	_
+	_x_
 	("Custom HTTP server, allows HTTP clients to connect, and also exposes game status to standard web browsers.");
       module_pedigree->version = VERSION;
       module_pedigree->copyright =
-	"Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>";
+	"Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -275,16 +258,13 @@ mod_httpd_create_backend ()
       backend->analyse_tcp = _analyse_tcp;
       backend->analyse_udp = _analyse_udp;
       backend->process_oob = _process_oob;
-      backend->accept_tcp = _accept_tcp;
-      backend->new_udp = _new_udp;
-      backend->is_associated_with_udp = _is_associated_with_udp;
-      backend->update_with_udp = _update_with_udp;
+      backend->open = _open;
+      backend->feed_with_tcp = _feed_with_tcp;
+      backend->feed_with_udp = _feed_with_udp;
       backend->close = _close;
       backend->send = _send;
-      backend->recv = _recv;
-      backend->is_alive = _is_alive;
+      backend->poll = _poll;
       backend->repr = _repr;
-      backend->error = _error;
     }
 
   return backend;
