@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,25 +29,13 @@
 
 char *
 _mod_tcpd_repr (_tcpd_context_t * tcpd_context,
-		lw6srv_connection_t * connection)
+		lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
   ret =
-    lw6sys_new_sprintf (_("tcpd connexion with %s:%d"),
-			connection->client_id.client_ip,
-			connection->client_id.client_port);
-
-  return ret;
-}
-
-char *
-_mod_tcpd_error (_tcpd_context_t * tcpd_context,
-		 lw6srv_connection_t * connection)
-{
-  char *ret = NULL;
-
-  // todo
+    lw6sys_new_sprintf (_x_ ("tcpd connexion with %s:%d"),
+			connection->remote_ip, connection->remote_port);
 
   return ret;
 }
