@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,14 @@
 #include "mod-udpd.h"
 #include "mod-udpd-internal.h"
 
+/*
+ * http://www.gnu.org/prep/standards/html_node/Dynamic-Plug_002dIn-Interfaces.html
+ */
+void
+mod_udpd_is_GPL_compatible ()
+{
+}
+
 static void *
 _init (int argc, char *argv[], lw6srv_listener_t * listener)
 {
@@ -48,28 +56,36 @@ _quit (void *srv_context)
 }
 
 static int
-_analyse_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter)
+_analyse_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
+	      lw6nod_info_t * node_info,
+	      u_int64_t * remote_id, char **remote_url)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
 
   if (udpd_context)
     {
-      ret = _mod_udpd_analyse_tcp (udpd_context, tcp_accepter);
+      ret =
+	_mod_udpd_analyse_tcp (udpd_context, tcp_accepter, node_info,
+			       remote_id, remote_url);
     }
 
   return ret;
 }
 
 static int
-_analyse_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer)
+_analyse_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer,
+	      lw6nod_info_t * node_info,
+	      u_int64_t * remote_id, char **remote_url)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
 
   if (udpd_context)
     {
-      ret = _mod_udpd_analyse_udp (udpd_context, udp_buffer);
+      ret =
+	_mod_udpd_analyse_udp (udpd_context, udp_buffer, node_info, remote_id,
+			       remote_url);
     }
 
   return ret;
@@ -90,69 +106,61 @@ _process_oob (void *srv_context, lw6nod_info_t * node_info,
   return ret;
 }
 
-static lw6srv_connection_t *
-_accept_tcp (void *srv_context, lw6srv_tcp_accepter_t * tcp_accepter,
-	     char *password)
+static lw6cnx_connection_t *
+_open (void *srv_context, lw6srv_listener_t * listener, char *local_url,
+       char *remote_url, char *remote_ip,
+       int remote_port, char *password,
+       u_int64_t local_id, u_int64_t remote_id, int dns_ok,
+       int network_reliability, lw6cnx_recv_callback_t recv_callback_func,
+       void *recv_callback_data)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
-  lw6srv_connection_t *ret = NULL;
-
-  if (udpd_context)
-    {
-      ret = _mod_udpd_accept_tcp (udpd_context, tcp_accepter, password);
-    }
-
-  return ret;
-}
-
-static lw6srv_connection_t *
-_new_udp (void *srv_context, lw6srv_udp_buffer_t * udp_buffer, char *password)
-{
-  _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
-  lw6srv_connection_t *ret = NULL;
-
-  if (udpd_context)
-    {
-      ret = _mod_udpd_new_udp (udpd_context, udp_buffer, password);
-    }
-
-  return ret;
-}
-
-static int
-_is_associated_with_udp (void *srv_context, lw6srv_connection_t * connection,
-			 lw6srv_udp_buffer_t * udp_buffer)
-{
-  _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
-  int ret = 0;
+  lw6cnx_connection_t *ret = NULL;
 
   if (udpd_context)
     {
       ret =
-	_mod_udpd_is_associated_with_udp (udpd_context, connection,
-					  udp_buffer);
+	_mod_udpd_open (udpd_context, listener, local_url, remote_url,
+			remote_ip, remote_port, password, local_id, remote_id,
+			dns_ok, network_reliability, recv_callback_func,
+			recv_callback_data);
     }
 
   return ret;
 }
 
 static int
-_update_with_udp (void *srv_context, lw6srv_connection_t * connection,
-		  lw6srv_udp_buffer_t * udp_buffer)
+_feed_with_tcp (void *srv_context, lw6cnx_connection_t * connection,
+		lw6srv_tcp_accepter_t * tcp_accepter)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
 
-  if (udpd_context)
+  if (connection)
     {
-      ret = _mod_udpd_update_with_udp (udpd_context, connection, udp_buffer);
+      ret = _mod_udpd_feed_with_tcp (udpd_context, connection, tcp_accepter);
+    }
+
+  return ret;
+}
+
+static int
+_feed_with_udp (void *srv_context, lw6cnx_connection_t * connection,
+		lw6srv_udp_buffer_t * udp_buffer)
+{
+  _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
+  int ret = 0;
+
+  if (connection)
+    {
+      ret = _mod_udpd_feed_with_udp (udpd_context, connection, udp_buffer);
     }
 
   return ret;
 }
 
 static void
-_close (void *srv_context, lw6srv_connection_t * connection)
+_close (void *srv_context, lw6cnx_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
 
@@ -163,49 +171,37 @@ _close (void *srv_context, lw6srv_connection_t * connection)
 }
 
 static int
-_send (void *srv_context, lw6srv_connection_t * connection, char *message)
+_send (void *srv_context, lw6cnx_connection_t * connection,
+       u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
+       u_int64_t logical_from_id, u_int64_t logical_to_id, char *message)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   int ret = 0;
 
   if (udpd_context)
     {
-      ret = _mod_udpd_send (udpd_context, connection, message);
+      ret =
+	_mod_udpd_send (udpd_context, connection, physical_ticket_sig,
+			logical_ticket_sig, logical_from_id, logical_to_id,
+			message);
     }
 
   return ret;
 }
 
-static char *
-_recv (void *srv_context, lw6srv_connection_t * connection)
+static void
+_poll (void *srv_context, lw6cnx_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
-  char *ret = NULL;
 
   if (udpd_context)
     {
-      ret = _mod_udpd_recv (udpd_context, connection);
+      _mod_udpd_poll (udpd_context, connection);
     }
-
-  return ret;
-}
-
-static int
-_is_alive (void *srv_context, lw6srv_connection_t * connection)
-{
-  _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
-  int ret = 0;
-
-  if (udpd_context)
-    {
-      ret = _mod_udpd_is_alive (udpd_context, connection);
-    }
-
-  return ret;
 }
 
 static char *
-_repr (void *srv_context, lw6srv_connection_t * connection)
+_repr (void *srv_context, lw6cnx_connection_t * connection)
 {
   _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
   char *ret = NULL;
@@ -218,20 +214,6 @@ _repr (void *srv_context, lw6srv_connection_t * connection)
   return ret;
 }
 
-static char *
-_error (void *srv_context, lw6srv_connection_t * connection)
-{
-  _udpd_context_t *udpd_context = (_udpd_context_t *) srv_context;
-  char *ret = NULL;
-
-  if (udpd_context)
-    {
-      ret = _mod_udpd_error (udpd_context, connection);
-    }
-
-  return ret;
-}
-
 lw6sys_module_pedigree_t *
 mod_udpd_get_pedigree ()
 {
@@ -244,12 +226,12 @@ mod_udpd_get_pedigree ()
     {
       module_pedigree->id = "udpd";
       module_pedigree->category = "srv";
-      module_pedigree->name = _("UDPD");
+      module_pedigree->name = _x_ ("UDPD");
       module_pedigree->readme =
-	_("Basic UDP/IP server, the fastest way to communicate.");
+	_x_ ("Basic UDP/IP server, the fastest way to communicate.");
       module_pedigree->version = VERSION;
       module_pedigree->copyright =
-	"Copyright (C)  2009  Christian Mauduit <ufoot@ufoot.org>";
+	"Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>";
       module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
       module_pedigree->date = __DATE__;
       module_pedigree->time = __TIME__;
@@ -273,16 +255,13 @@ mod_udpd_create_backend ()
       backend->analyse_tcp = _analyse_tcp;
       backend->analyse_udp = _analyse_udp;
       backend->process_oob = _process_oob;
-      backend->accept_tcp = _accept_tcp;
-      backend->new_udp = _new_udp;
-      backend->is_associated_with_udp = _is_associated_with_udp;
-      backend->update_with_udp = _update_with_udp;
+      backend->open = _open;
+      backend->feed_with_tcp = _feed_with_tcp;
+      backend->feed_with_udp = _feed_with_udp;
       backend->close = _close;
       backend->send = _send;
-      backend->recv = _recv;
-      backend->is_alive = _is_alive;
+      backend->poll = _poll;
       backend->repr = _repr;
-      backend->error = _error;
     }
 
   return backend;
