@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ static void
 _warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
-	      _("srv backend function \"%s\" is not defined"), func_name);
+	      _x_ ("srv backend function \"%s\" is not defined"), func_name);
 }
 
 int
@@ -80,7 +80,9 @@ lw6srv_quit (lw6srv_backend_t * backend)
 
 int
 lw6srv_analyse_tcp (lw6srv_backend_t * backend,
-		    lw6srv_tcp_accepter_t * tcp_accepter)
+		    lw6srv_tcp_accepter_t * tcp_accepter,
+		    lw6nod_info_t * node_info,
+		    u_int64_t * remote_id, char **remote_url)
 {
   int ret = 0;
 
@@ -88,7 +90,9 @@ lw6srv_analyse_tcp (lw6srv_backend_t * backend,
 
   if (backend->analyse_tcp)
     {
-      ret = backend->analyse_tcp (backend->srv_context, tcp_accepter);
+      ret =
+	backend->analyse_tcp (backend->srv_context, tcp_accepter, node_info,
+			      remote_id, remote_url);
     }
   else
     {
@@ -102,7 +106,9 @@ lw6srv_analyse_tcp (lw6srv_backend_t * backend,
 
 int
 lw6srv_analyse_udp (lw6srv_backend_t * backend,
-		    lw6srv_udp_buffer_t * udp_buffer)
+		    lw6srv_udp_buffer_t * udp_buffer,
+		    lw6nod_info_t * node_info, u_int64_t * remote_id,
+		    char **remote_url)
 {
   int ret = 0;
 
@@ -110,7 +116,9 @@ lw6srv_analyse_udp (lw6srv_backend_t * backend,
 
   if (backend->analyse_udp)
     {
-      ret = backend->analyse_udp (backend->srv_context, udp_buffer);
+      ret =
+	backend->analyse_udp (backend->srv_context, udp_buffer, node_info,
+			      remote_id, remote_url);
     }
   else
     {
@@ -144,40 +152,25 @@ lw6srv_process_oob (lw6srv_backend_t * backend, lw6nod_info_t * node_info,
   return ret;
 }
 
-lw6srv_connection_t *
-lw6srv_accept_tcp (lw6srv_backend_t * backend,
-		   lw6srv_tcp_accepter_t * tcp_accepter, char *password)
+lw6cnx_connection_t *
+lw6srv_open (lw6srv_backend_t * backend, lw6srv_listener_t * listener,
+	     char *local_url, char *remote_url, char *remote_ip,
+	     int remote_port, char *password, u_int64_t local_id,
+	     u_int64_t remote_id, int dns_ok, int network_reliability,
+	     lw6cnx_recv_callback_t recv_callback_func,
+	     void *recv_callback_data)
 {
-  lw6srv_connection_t *ret = NULL;
+  lw6cnx_connection_t *ret = NULL;
 
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->accept_tcp)
+  if (backend->open)
     {
       ret =
-	backend->accept_tcp (backend->srv_context, tcp_accepter, password);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
-
-lw6srv_connection_t *
-lw6srv_new_udp (lw6srv_backend_t * backend, lw6srv_udp_buffer_t * udp_buffer,
-		char *password)
-{
-  lw6srv_connection_t *ret = NULL;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->new_udp)
-    {
-      ret = backend->new_udp (backend->srv_context, udp_buffer, password);
+	backend->open (backend->srv_context, listener, local_url, remote_url,
+		       remote_ip, remote_port, password, local_id, remote_id,
+		       dns_ok, network_reliability, recv_callback_func,
+		       recv_callback_data);
     }
   else
     {
@@ -190,19 +183,19 @@ lw6srv_new_udp (lw6srv_backend_t * backend, lw6srv_udp_buffer_t * udp_buffer,
 }
 
 int
-lw6srv_is_associated_with_udp (lw6srv_backend_t * backend,
-			       lw6srv_connection_t * connection,
-			       lw6srv_udp_buffer_t * udp_buffer)
+lw6srv_feed_with_tcp (lw6srv_backend_t * backend,
+		      lw6cnx_connection_t * connection,
+		      lw6srv_tcp_accepter_t * tcp_accepter)
 {
   int ret = 0;
 
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->is_associated_with_udp)
+  if (backend->feed_with_tcp)
     {
       ret =
-	backend->is_associated_with_udp (backend->srv_context, connection,
-					 udp_buffer);
+	backend->feed_with_tcp (backend->srv_context, connection,
+				tcp_accepter);
     }
   else
     {
@@ -215,19 +208,18 @@ lw6srv_is_associated_with_udp (lw6srv_backend_t * backend,
 }
 
 int
-lw6srv_update_with_udp (lw6srv_backend_t * backend,
-			lw6srv_connection_t * connection,
-			lw6srv_udp_buffer_t * udp_buffer)
+lw6srv_feed_with_udp (lw6srv_backend_t * backend,
+		      lw6cnx_connection_t * connection,
+		      lw6srv_udp_buffer_t * udp_buffer)
 {
   int ret = 0;
 
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->update_with_udp)
+  if (backend->feed_with_udp)
     {
       ret =
-	backend->update_with_udp (backend->srv_context, connection,
-				  udp_buffer);
+	backend->feed_with_udp (backend->srv_context, connection, udp_buffer);
     }
   else
     {
@@ -240,7 +232,7 @@ lw6srv_update_with_udp (lw6srv_backend_t * backend,
 }
 
 void
-lw6srv_close (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
+lw6srv_close (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 {
   LW6SYS_BACKEND_FUNCTION_BEGIN;
 
@@ -257,8 +249,10 @@ lw6srv_close (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 }
 
 int
-lw6srv_send (lw6srv_backend_t * backend, lw6srv_connection_t * connection,
-	     char *message)
+lw6srv_send (lw6srv_backend_t * backend, lw6cnx_connection_t * connection,
+	     u_int32_t physical_ticket_sig, u_int32_t logical_ticket_sig,
+	     u_int64_t logical_from_id,
+	     u_int64_t logical_to_id, char *message)
 {
   int ret = 0;
 
@@ -266,7 +260,21 @@ lw6srv_send (lw6srv_backend_t * backend, lw6srv_connection_t * connection,
 
   if (backend->send)
     {
-      ret = backend->send (backend->srv_context, connection, message);
+      if (lw6cnx_connection_reliability_filter (connection))
+	{
+	  ret =
+	    backend->send (backend->srv_context, connection,
+			   physical_ticket_sig, logical_ticket_sig,
+			   logical_from_id, logical_to_id, message);
+	}
+      else
+	{
+	  /*
+	   * Yes, we return true, the idea is to pretend success
+	   * but in fact real send failed.
+	   */
+	  ret = 1;
+	}
     }
   else
     {
@@ -278,50 +286,25 @@ lw6srv_send (lw6srv_backend_t * backend, lw6srv_connection_t * connection,
   return ret;
 }
 
+void
+lw6srv_poll (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->poll)
+    {
+      backend->poll (backend->srv_context, connection);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
 char *
-lw6srv_recv (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
-{
-  char *ret = NULL;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->recv)
-    {
-      ret = backend->recv (backend->srv_context, connection);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
-
-int
-lw6srv_is_alive (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
-{
-  int ret = 0;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->is_alive)
-    {
-      ret = backend->is_alive (backend->srv_context, connection);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
-
-char *
-lw6srv_repr (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
+lw6srv_repr (lw6srv_backend_t * backend, lw6cnx_connection_t * connection)
 {
   char *ret = NULL;
 
@@ -340,24 +323,3 @@ lw6srv_repr (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 
   return ret;
 }
-
-char *
-lw6srv_error (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
-{
-  char *ret = NULL;
-
-  LW6SYS_BACKEND_FUNCTION_BEGIN;
-
-  if (backend->error)
-    {
-      ret = backend->error (backend->srv_context, connection);
-    }
-  else
-    {
-      _warning (__FUNCTION__);
-    }
-
-  LW6SYS_BACKEND_FUNCTION_END;
-
-  return ret;
-}
