@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "sys.h"
 #include "sys-build.h"
 
-#define COPYRIGHT "Copyright (C)  2010  Christian Mauduit <ufoot@ufoot.org>"
+#define COPYRIGHT "Copyright (C)  2011  Christian Mauduit <ufoot@ufoot.org>"
 #define LICENSE "GPLv3+ (GNU GPL version 3 or later)"
 #define URL "http://www.gnu.org/software/liquidwar6/"
 #define TOP_SRCDIR_TEST_FILE "liquidwar6.spec.in"
@@ -241,7 +241,7 @@ lw6sys_build_get_configure_args ()
 char *
 lw6sys_build_get_gcc_version ()
 {
-#ifdef __GNUC__
+#ifdef __GNUC__x_
   return __VERSION__;
 #else
   return "?";
@@ -992,96 +992,96 @@ lw6sys_build_get_bin_id ()
 void
 lw6sys_build_log_all ()
 {
-  lw6sys_log (LW6SYS_LOG_INFO, _("build package tarname is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build package tarname is \"%s\""),
 	      lw6sys_build_get_package_tarname ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build package name is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build package name is \"%s\""),
 	      lw6sys_build_get_package_name ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build package string is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build package string is \"%s\""),
 	      lw6sys_build_get_package_string ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build version is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build version is \"%s\""),
 	      lw6sys_build_get_version ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build codename is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build codename is \"%s\""),
 	      lw6sys_build_get_codename ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build stamp is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build stamp is \"%s\""),
 	      lw6sys_build_get_stamp ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build md5sum is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build md5sum is \"%s\""),
 	      lw6sys_build_get_md5sum ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build copyright is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build copyright is \"%s\""),
 	      lw6sys_build_get_copyright ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build license is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build license is \"%s\""),
 	      lw6sys_build_get_license ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build url is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build url is \"%s\""),
 	      lw6sys_build_get_url ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build configure args is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build configure args is \"%s\""),
 	      lw6sys_build_get_configure_args ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build gcc_version is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build gcc_version is \"%s\""),
 	      lw6sys_build_get_gcc_version ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build cflags is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build cflags is \"%s\""),
 	      lw6sys_build_get_cflags ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build ldflags is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build ldflags is \"%s\""),
 	      lw6sys_build_get_ldflags ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build date is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build date is \"%s\""),
 	      lw6sys_build_get_date ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build time is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build time is \"%s\""),
 	      lw6sys_build_get_time ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build host cpu is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build host cpu is \"%s\""),
 	      lw6sys_build_get_host_cpu ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build endianness is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build endianness is \"%s\""),
 	      lw6sys_build_get_endianness ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build pointer size is %d"),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build pointer size is %d"),
 	      lw6sys_build_get_pointer_size ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build host os is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build host os is \"%s\""),
 	      lw6sys_build_get_host_os ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build ms windows is %d"),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build ms windows is %d"),
 	      lw6sys_build_is_ms_windows ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build mac os x is %d"),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build mac os x is %d"),
 	      lw6sys_build_is_mac_os_x ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build gp2x is %d"),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build gp2x is %d"),
 	      lw6sys_build_is_gp2x ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build top_srcdir is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build top_srcdir is \"%s\""),
 	      lw6sys_build_get_top_srcdir ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build prefix is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build prefix is \"%s\""),
 	      lw6sys_build_get_prefix ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build datadir is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build datadir is \"%s\""),
 	      lw6sys_build_get_datadir ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build libdir is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build libdir is \"%s\""),
 	      lw6sys_build_get_libdir ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build includedir is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build includedir is \"%s\""),
 	      lw6sys_build_get_includedir ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build localedir is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build localedir is \"%s\""),
 	      lw6sys_build_get_localedir ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build docdir is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build docdir is \"%s\""),
 	      lw6sys_build_get_docdir ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable console is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable console is \"%s\""),
 	      lw6sys_build_get_enable_console ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable gtk is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable gtk is \"%s\""),
 	      lw6sys_build_get_enable_gtk ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-gl is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable mod-gl is \"%s\""),
 	      lw6sys_build_get_enable_mod_gl ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-csound is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable mod-csound is \"%s\""),
 	      lw6sys_build_get_enable_mod_csound ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-ogg is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable mod-ogg is \"%s\""),
 	      lw6sys_build_get_enable_mod_ogg ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-http is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable mod-http is \"%s\""),
 	      lw6sys_build_get_enable_mod_http ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable optimize is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable optimize is \"%s\""),
 	      lw6sys_build_get_enable_optimize ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable allinone is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable allinone is \"%s\""),
 	      lw6sys_build_get_enable_allinone ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable fullstatic is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable fullstatic is \"%s\""),
 	      lw6sys_build_get_enable_fullstatic ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable paranoid is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable paranoid is \"%s\""),
 	      lw6sys_build_get_enable_paranoid ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable gprof is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable gprof is \"%s\""),
 	      lw6sys_build_get_enable_gprof ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable instrument is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable instrument is \"%s\""),
 	      lw6sys_build_get_enable_instrument ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable profiler is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable profiler is \"%s\""),
 	      lw6sys_build_get_enable_profiler ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable gcov is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable gcov is \"%s\""),
 	      lw6sys_build_get_enable_gcov ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build enable valgrind is \"%s\""),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build enable valgrind is \"%s\""),
 	      lw6sys_build_get_enable_valgrind ());
-  lw6sys_log (LW6SYS_LOG_INFO, _("build bin-id is %d"),
+  lw6sys_log (LW6SYS_LOG_INFO, _x_ ("build bin-id is %d"),
 	      lw6sys_build_get_bin_id ());
 }
