@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ lw6sys_hexa_serializer_eof (lw6sys_hexa_serializer_t * hexa_serializer)
   else if (hexa_serializer->pos > len)
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("hexa serializer pos past end (%d/%d)"),
+		  _x_ ("hexa serializer pos past end (%d/%d)"),
 		  hexa_serializer->pos, len);
     }
 
@@ -197,7 +197,7 @@ resize (lw6sys_hexa_serializer_t * hexa_serializer, int required)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _
+		      _x_
 		      ("can't resize hexa_serializer (new_size=%d), expect serious trouble"),
 		      new_size);
 	}
@@ -233,7 +233,7 @@ push_raw (lw6sys_hexa_serializer_t * hexa_serializer, u_int8_t * buf,
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _
+		      _x_
 		      ("inconsistent hexa_serializer after push, pos=%d, buf_size=%d"),
 		      hexa_serializer->pos, hexa_serializer->buf_size);
 	}
@@ -272,7 +272,7 @@ pop_raw (lw6sys_hexa_serializer_t * hexa_serializer, u_int8_t * buf, int size)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _
+		      _x_
 		      ("inconsistent hexa_serializer after pop, pos=%d, buf_size=%d"),
 		      hexa_serializer->pos, hexa_serializer->buf_size);
 	}
@@ -521,7 +521,7 @@ lw6sys_hexa_serializer_pop_int64 (lw6sys_hexa_serializer_t * hexa_serializer,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to pop int64 from hexa_serializer"));
+		  _x_ ("unable to pop int64 from hexa_serializer"));
     }
 
   return ret;
@@ -555,7 +555,7 @@ lw6sys_hexa_serializer_pop_int32 (lw6sys_hexa_serializer_t * hexa_serializer,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to pop int32 from hexa_serializer"));
+		  _x_ ("unable to pop int32 from hexa_serializer"));
     }
 
   return ret;
@@ -589,7 +589,7 @@ lw6sys_hexa_serializer_pop_int16 (lw6sys_hexa_serializer_t * hexa_serializer,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to pop int16 from hexa_serializer"));
+		  _x_ ("unable to pop int16 from hexa_serializer"));
     }
 
   return ret;
@@ -621,7 +621,7 @@ lw6sys_hexa_serializer_pop_int8 (lw6sys_hexa_serializer_t * hexa_serializer,
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to pop int8 from hexa_serializer"));
+		  _x_ ("unable to pop int8 from hexa_serializer"));
     }
 
   return ret;
@@ -717,7 +717,7 @@ lw6sys_hexa_serializer_pop_str (lw6sys_hexa_serializer_t * hexa_serializer,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("unable to find \"%s\""), HEXA_0);
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("unable to find \"%s\""), HEXA_0);
     }
 
   if (buf && !ret)
@@ -844,8 +844,20 @@ lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
   return ret;
 }
 
-static int
-_hexa_str_to_buf (void *buf, int size, char *str)
+/**
+ * lw6sys_hexa_str_to_buf
+ *
+ * @buf: binary buffer to convert
+ * @size: binary buffer length
+ * @str: the source string
+ *
+ * Converts the stringified hexa representation of a string to
+ * its source binary buffer. Buffer must be exactly @strlen(str)/2
+ *
+ * Return value: 1 on success
+ */
+int
+lw6sys_hexa_str_to_buf (void *buf, int size, char *str)
 {
   char *buffer = (char *) buf;
   int ret = 0;
@@ -859,7 +871,6 @@ _hexa_str_to_buf (void *buf, int size, char *str)
 	  memcpy (hexa2, str + 2 * i, 2);
 	  sscanf (hexa2, "%02x", &j);
 	  buffer[i] = (u_int8_t) j;
-	  TMP3 ("s2b %s %d %d", hexa2, j, (int) buffer[i]);
 	}
       str[2 * size] = '\0';
       ret = 1;
@@ -867,7 +878,7 @@ _hexa_str_to_buf (void *buf, int size, char *str)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _
+		  _x_
 		  ("incorrect string (bad size) \"%s\" expected %d but got %d"),
 		  str, 2 * size, strlen (str));
     }
@@ -875,8 +886,18 @@ _hexa_str_to_buf (void *buf, int size, char *str)
   return ret;
 }
 
-static char *
-_hexa_buf_to_str (void *buf, int size)
+/**
+ * lw6sys_hexa_buf_to_str
+ *
+ * @buf: the buffer to stringify
+ * @size: the length of the buffer
+ *
+ * Transforms a binary buffer into its hexa representation.
+ *
+ * Return value: newly allocated string.
+ */
+char *
+lw6sys_hexa_buf_to_str (void *buf, int size)
 {
   char *buffer = (char *) buf;
   char *str = NULL;
@@ -918,7 +939,7 @@ lw6sys_hexa_str_to_ptr (char *str)
 {
   void *ptr = NULL;
 
-  if (!_hexa_str_to_buf (&ptr, sizeof (void *), str))
+  if (!lw6sys_hexa_str_to_buf (&ptr, sizeof (void *), str))
     {
       ptr = NULL;
     }
@@ -947,8 +968,7 @@ lw6sys_hexa_ptr_to_str (void *ptr)
 {
   char *str = NULL;
 
-  TMP2 ("p2s ptr=%p &ptr=%p", ptr, &ptr);
-  str = _hexa_buf_to_str (&ptr, sizeof (void *));
+  str = lw6sys_hexa_buf_to_str (&ptr, sizeof (void *));
 
   return str;
 }
