@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -109,7 +109,7 @@ lw6sys_list_free (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to free NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("trying to free NULL list"));
     }
 }
 
@@ -134,7 +134,7 @@ lw6sys_list_next (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling next on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling next on NULL list"));
     }
 
   return ret;
@@ -163,7 +163,7 @@ lw6sys_list_is_empty (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling is_empty on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling is_empty on NULL list"));
     }
 
   return empty;
@@ -194,7 +194,7 @@ lw6sys_list_length (lw6sys_list_t * list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling length on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling length on NULL list"));
     }
 
   return ret;
@@ -236,7 +236,7 @@ lw6sys_list_map (lw6sys_list_t * list,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling map on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling map on NULL list"));
     }
 }
 
@@ -303,7 +303,7 @@ lw6sys_list_filter (lw6sys_list_t ** list,
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling filter on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling filter on NULL list"));
     }
 }
 
@@ -344,7 +344,8 @@ lw6sys_list_push_front (lw6sys_list_t ** list, void *data)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling push_front on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _x_ ("calling push_front on NULL list"));
     }
 }
 
@@ -392,7 +393,7 @@ lw6sys_list_pop_front (lw6sys_list_t ** list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling pop_front on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling pop_front on NULL list"));
     }
 
   return data;
@@ -443,12 +444,12 @@ lw6sys_list_push_back (lw6sys_list_t ** list, void *data)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("list push_back bug"));
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("list push_back bug"));
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling push_back on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling push_back on NULL list"));
     }
 }
 
@@ -522,7 +523,7 @@ lw6sys_list_pop_back (lw6sys_list_t ** list)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling pop_back on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling pop_back on NULL list"));
     }
 
   return data;
@@ -604,7 +605,7 @@ lw6sys_list_dup (lw6sys_list_t * list, lw6sys_dup_func_t dup_func)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("calling dup on NULL list"));
+      lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("calling dup on NULL list"));
     }
 
   return ret;
