@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@
 #define STR_EOL "\n"
 #endif
 
+#define _STR_BIN_TEXT_OTHER ".,:;!?()'\"-+*/=_ \t\r\n"
+#define _STR_BIN_TEXT_MIN_PERCENT 75
+
 /**
  * lw6sys_str_copy
  *
@@ -183,6 +186,77 @@ lw6sys_new_sprintf (char *fmt, ...)
   return ret;
 }
 
+int
+_lw6sys_buf_vsnprintf (char *buf, int len, char *fmt, va_list ap)
+{
+  int ret = 0;
+
+  /*
+   * buf has at least one char for it's len+1 so even
+   * with len=0 buf[0] is fine.
+   */
+  buf[0] = '\0';
+
+  /*
+   * Always call this first to call a segfault if buf is badly
+   * sized, better have this error right now than later
+   * "we don't know when".
+   */
+  buf[len] = '\0';
+
+  /*
+   * Note: it's important here *not* to log anything,
+   * this function is typically called by internal
+   * low-level function which do not want to lock
+   * anything calling malloc or something.
+   */
+  ret = (vsnprintf (buf, len, fmt, ap) >= 0);
+
+  return ret;
+}
+
+/**
+ * lw6sys_buf_sprintf
+ *
+ * @buf: a buffer of len+1 chars
+ * @len: the max length of string
+ * @fmt: a format string, like the one you would pass to @printf
+ * @...: optional arguments, like the ones you would pass to @printf
+ *
+ * Almost like snprintf except that it will *always* append a
+ * char 0 ('\0') at the end of the string. Therefore buf
+ * must be of size len+1.
+ *
+ * Return value: 1 if success, 0 if failed.
+ */
+int
+lw6sys_buf_sprintf (char *buf, int len, char *fmt, ...)
+{
+  int ret = 0;
+  va_list ap;
+
+  /*
+   * buf has at least one char for it's len+1 so even
+   * with len=0 buf[0] is fine.
+   */
+  buf[0] = '\0';
+
+  if (fmt != NULL)
+    {
+      va_start (ap, fmt);
+      /*
+       * Note: it's important here *not* to log anything,
+       * this function is typically called by internal
+       * low-level function which do not want to lock
+       * anything calling malloc or something.
+       */
+      ret = _lw6sys_buf_vsnprintf (buf, len, fmt, ap);
+      va_end (ap);
+    }
+
+  return ret;
+}
+
 /**
  * lw6sys_str_is_blank
  *
@@ -217,6 +291,36 @@ lw6sys_str_is_blank (char *str)
   return ret;
 }
 
+/**
+ * lw6sys_str_is_null_or_empty
+ *
+ * @str: the string to test
+ *
+ * Tests wether a string is NULL or empty (string with 0 chars "").
+ *
+ * Return value: 1 if NULL or empty, 0 if contains something.
+ */
+int
+lw6sys_str_is_null_or_empty (char *str)
+{
+  return (str == NULL || str[0] == '\0');
+}
+
+/**
+ * lw6sys_str_empty_if_null
+ *
+ * @str: the string to test
+ *
+ * Returns always a non-NULL string, if string is NULL, returns ""
+ *
+ * Return value: source string or "" if it was NULL
+ */
+char *
+lw6sys_str_empty_if_null (char *str)
+{
+  return str ? str : LW6SYS_STR_EMPTY;
+}
+
 /**
  * lw6sys_str_is_same
  *
@@ -513,7 +617,7 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
 		}
 	      else
 		{
-		  lw6sys_log (LW6SYS_LOG_WARNING, _("reformat problem"));
+		  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("reformat problem"));
 		  line_start += i;
 		}
 	      i = 0;
@@ -537,6 +641,45 @@ lw6sys_str_reformat (char *str, char *prefix, int nb_columns)
   return ret;
 }
 
+/**
+ * lw6sys_str_reformat_this
+ *
+ * @str: a pointer to the string we want to modify
+ * @nb_colummns: number of columns to use, without prefix.
+ *
+ * Reformats a string, that is, insert newline characters in the
+ * right places to that it fits in a given number of columns.
+ * This function will modify the buffer so @str must be writeable.
+ * Will not handle strings which already contain newline
+ * characters perfectly.
+ *
+ * Return value: none
+ */
+void
+lw6sys_str_reformat_this (char *str, int nb_columns)
+{
+  int i = 0;
+  char *pos = NULL;
+  char *last_space = NULL;
+
+  pos = str;
+  while (*pos)
+    {
+      if (i > nb_columns && last_space)
+	{
+	  (*last_space) = '\n';
+	  i = (pos - last_space);
+	  last_space = NULL;
+	}
+      if (lw6sys_chr_is_space (*pos))
+	{
+	  last_space = pos;
+	}
+      pos++;
+      i++;
+    }
+}
+
 /**
  * lw6sys_eol
  *
@@ -748,3 +891,72 @@ lw6sys_str_truncate (char *str, int len)
       str[len] = '\0';
     }
 }
+
+/**
+ * lw6sys_str_random
+ *
+ * @len: the length of the random string to generate.
+ *
+ * Generates a random string, this is usefull for testing.
+ *
+ * Return value: newly allocated string
+ */
+char *
+lw6sys_str_random (int len)
+{
+  unsigned char *ret = NULL;
+  int i = 0;
+
+  ret = (unsigned char *) LW6SYS_MALLOC (len + 1);
+  for (i = 0; i < len; ++i)
+    {
+      ret[i] = lw6sys_random (254) + 1;
+    }
+  ret[len] = 0;
+
+  return (char *) ret;
+}
+
+static int
+_chr_is_text (char c)
+{
+  return (c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || (c >= '0'
+							      && c <= '9')
+    || (strchr (_STR_BIN_TEXT_OTHER, c) != NULL);
+}
+
+/**
+ * lw6sys_str_is_bin
+ *
+ * @buf: the buffer to test
+ * @len: the length of the buffer
+ *
+ * Tests wether a buffer is likely to contain a string. This is not
+ * a bulletproof function, just a simple heuristic based estimator.
+ *
+ * Return value: 1 if probably binary, 0 if probably text
+ */
+int
+lw6sys_str_is_bin (char *buf, int len)
+{
+  int ret = 0;
+  int text_chars = 0;
+  int i = 0;
+
+  if (len > 0)
+    {
+      for (i = 0; i < len; ++i)
+	{
+	  if (_chr_is_text (buf[i]))
+	    {
+	      text_chars++;
+	    }
+	}
+      if (((text_chars * 100) / len) < _STR_BIN_TEXT_MIN_PERCENT)
+	{
+	  ret = 1;
+	}
+    }
+
+  return ret;
+}
