@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -36,8 +36,6 @@
 #define _TIMER_CYCLE_MASK 0xFFFFFL
 #define _RFC1123_SIZE 33
 #define _CLF_SIZE 40
-#define _SLEEP_DELAY 1
-#define _SNOOZE_DELAY 100
 
 static int64_t timestamp_0 = 0;
 
@@ -224,7 +222,7 @@ lw6sys_delay (int msec)
 void
 lw6sys_idle ()
 {
-  lw6sys_delay (_SLEEP_DELAY);
+  lw6sys_delay (LW6SYS_SLEEP_DELAY);
 }
 
 /**
@@ -238,7 +236,7 @@ lw6sys_idle ()
 void
 lw6sys_snooze ()
 {
-  lw6sys_delay (_SNOOZE_DELAY);
+  lw6sys_delay (LW6SYS_SNOOZE_DELAY);
 }
 
 /**
@@ -316,7 +314,7 @@ lw6sys_date_rfc1123 (int seconds_from_now)
 	strftime (ret, _RFC1123_SIZE, "%a, %d %b %Y %H:%M:%S +0000", tm_ptr);
       if (strflen >= _RFC1123_SIZE)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("buffer exceeded %d>=%d"),
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("buffer exceeded %d>=%d"),
 		      strflen, _RFC1123_SIZE);
 	}
       // called with old_tz=NULL, will unset
@@ -384,7 +382,7 @@ lw6sys_date_clf ()
       strflen = strftime (ret, _CLF_SIZE, "%d/%b/%Y:%H:%M:%S %z", tm_ptr);
       if (strflen >= _CLF_SIZE)
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, _("buffer exceeded %d>=%d"),
+	  lw6sys_log (LW6SYS_LOG_WARNING, _x_ ("buffer exceeded %d>=%d"),
 		      strflen, _CLF_SIZE);
 	}
       if (old_locale)
