@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,6 +32,18 @@
 #define _(string) string
 #endif
 
+/*
+ * Because program has so many strings, it's not reasonnable to
+ * translate them all (at least for now) as most of them are
+ * debugging messages. However it's important not to loose a
+ * trace of "potentially translatable" candidates, so we mark
+ * them with _x_ instead of _ this way they don't appear in
+ * .po files but at the same time a trivial sed command can make
+ * them appear back again. Additionnally, not using gettext
+ * on never-translated debugging messages does save time.
+ */
+#define _x_(string) string
+
 #ifndef bindtextdomain
 #include <libintl.h>
 #endif
@@ -89,7 +101,10 @@ typedef char *char_ptr_t;
 #endif
 
 #define LW6SYS_QUOTE(STR) #STR
+#define LW6SYS_STR_EMPTY ""
 #define LW6SYS_TICKS_PER_SEC 1000L
+#define LW6SYS_SLEEP_DELAY 1
+#define LW6SYS_SNOOZE_DELAY 100
 
 /*
  * Yet another MS-windows hack, printf %ll doesn't work
@@ -229,6 +244,14 @@ typedef struct lw6sys_module_pedigree_s
 
 #define LW6SYS_SIZEOF_XYZ 4
 
+#define LW6SYS_LEN_ID_16 4
+#define LW6SYS_LEN_ID_32 8
+#define LW6SYS_LEN_ID_64 16
+
+#define LW6SYS_BROADCAST_ID_16 0xffff
+#define LW6SYS_BROADCAST_ID_32 0xffffffff
+#define LW6SYS_BROADCAST_ID_64 0xffffffffffffffffLL
+
 typedef void (*lw6sys_free_func_t) (void *data);
 typedef void (*lw6sys_assoc_callback_func_t) (void *func_data, char *key,
 					      void *value);
@@ -328,6 +351,10 @@ extern lw6sys_color_hsv_t LW6SYS_COLOR_HSV_BLUE;
 #define TMP3(message,arg1,arg2,arg3) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3)
 #define TMP4(message,arg1,arg2,arg3,arg4) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4)
 #define TMP5(message,arg1,arg2,arg3,arg4,arg5) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5)
+#define TMP6(message,arg1,arg2,arg3,arg4,arg5,arg6) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5, arg6)
+#define TMP7(message,arg1,arg2,arg3,arg4,arg5,arg6,arg7) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5, arg6, arg7)
+#define TMP8(message,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8)
+#define TMP9(message,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8,arg9) lw6sys_log(LW6SYS_LOG_TMP, message, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9)
 
 /*
  * Common indenting parameters
@@ -520,6 +547,11 @@ extern char *lw6sys_itoa (int value);
 extern char *lw6sys_btoa (int value);
 extern char *lw6sys_ftoa (float value);
 
+/* sys-daemon.c */
+extern char *lw6sys_daemon_pid_file (int argc, char *argv[]);
+extern int lw6sys_daemon_start (char *pid_file);
+extern int lw6sys_daemon_stop (char *pid_file);
+
 /* sys-debug.c */
 extern int lw6sys_debug_get ();
 extern void lw6sys_debug_set (int mode);
@@ -551,6 +583,7 @@ extern char *lw6sys_escape_sql_value (char *src);
 extern char *lw6sys_exec_find_myself (int argc, char *argv[]);
 extern int lw6sys_is_executed_again (int argc, char *argv[]);
 extern int lw6sys_exec_again (int argc, char *argv[]);
+extern int lw6sys_exec_restart (int argc, char *argv[]);
 
 /* sys-file.c */
 extern int lw6sys_clear_file (char *filename);
@@ -635,6 +668,8 @@ extern int lw6sys_hexa_serializer_pop_whd (lw6sys_hexa_serializer_t *
 extern int lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
 					     hexa_serializer,
 					     lw6sys_color_8_t * value);
+extern int lw6sys_hexa_str_to_buf (void *buf, int size, char *str);
+extern char *lw6sys_hexa_buf_to_str (void *buf, int size);
 extern void *lw6sys_hexa_str_to_ptr (char *str);
 extern char *lw6sys_hexa_ptr_to_str (void *ptr);
 
@@ -768,11 +803,6 @@ extern char *lw6sys_get_map_path (int argc, char *argv[]);
 extern char *lw6sys_get_script_file (int argc, char *argv[]);
 extern void lw6sys_options_log (int argc, char *argv[]);
 
-/* sys-password.c */
-extern char *lw6sys_password_checksum (char *seed, char *password);
-extern int lw6sys_password_verify (char *seed, char *password_here,
-				   char *password_received);
-
 /* sys-path.c */
 extern int lw6sys_file_exists (char *filename);
 extern int lw6sys_dir_exists (char *dirname);
@@ -855,6 +885,15 @@ extern int lw6sys_shape_is_same (lw6sys_whd_t * shape_a,
 extern int lw6sys_shape_is_same_xy (lw6sys_whd_t * shape_a,
 				    lw6sys_whd_t * shape_b);
 
+/* sys-signal.c */
+extern void lw6sys_signal_custom ();
+extern void lw6sys_signal_default ();
+extern void lw6sys_signal_term_handler (int signum);
+extern void lw6sys_signal_int_handler (int signum);
+extern void lw6sys_signal_hup_handler (int signum);
+extern void lw6sys_signal_send_quit ();
+extern int lw6sys_signal_poll_quit ();
+
 /* sys-sort.c */
 extern int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
 				     lw6sys_list_t ** list_b);
@@ -882,7 +921,10 @@ extern int lw6sys_spinlock_unlock (void *spinlock);
 extern char *lw6sys_str_copy (char *src);
 extern char *lw6sys_str_concat (char *str1, char *str2);
 extern char *lw6sys_new_sprintf (char *fmt, ...);
+extern int lw6sys_buf_sprintf (char *buf, int len, char *fmt, ...);
 extern int lw6sys_str_is_blank (char *str);
+extern int lw6sys_str_is_null_or_empty (char *str);
+extern char *lw6sys_str_empty_if_null (char *str);
 extern int lw6sys_str_is_same (char *str_a, char *str_b);
 extern int lw6sys_str_is_same_no_case (char *str_a, char *str_b);
 extern int lw6sys_str_starts_with (char *str, char *beginning);
@@ -891,6 +933,7 @@ extern int lw6sys_skip_blanks (char **str_ptr);
 extern void lw6sys_str_cleanup (char *str);
 extern void lw6sys_str_cleanup_ascii7 (char *str);
 extern char *lw6sys_str_reformat (char *str, char *prefix, int nb_columns);
+extern void lw6sys_str_reformat_this (char *str, int nb_columns);
 extern char *lw6sys_eol ();
 extern lw6sys_list_t *lw6sys_str_split (char *str, char c);
 extern lw6sys_list_t *lw6sys_str_split_no_0 (char *str, char c);
@@ -898,6 +941,12 @@ extern lw6sys_list_t *lw6sys_str_split_config_item (char *str);
 extern void lw6sys_str_toupper (char *str);
 extern void lw6sys_str_tolower (char *str);
 extern void lw6sys_str_truncate (char *str, int len);
+extern char *lw6sys_str_random (int len);
+extern int lw6sys_str_is_bin (char *buf, int len);
+
+/* sys-stream.c */
+extern char *lw6sys_stream_file_to_str (FILE * f);
+extern void lw6sys_stream_str_to_file (FILE * f, char *str);
 
 /* sys-test.c */
 extern int lw6sys_test_exec (int argc, char *argv[], int mode);
