@@ -1,6 +1,6 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007, 2008, 2009, 2010, 2011  Christian Mauduit <ufoot@ufoot.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ test_manager ()
 		    if (repr)
 		      {
 			lw6sys_log (LW6SYS_LOG_NOTICE,
-				    _("waiting for manager \"%s\""), repr);
+				    _x_ ("waiting for manager \"%s\""), repr);
 			LW6SYS_FREE (repr);
 		      }
 		    if (lw6tsk_loader_pop
@@ -104,7 +104,7 @@ test_manager ()
 			    if (repr)
 			      {
 				lw6sys_log (LW6SYS_LOG_NOTICE,
-					    _("loaded game_struct \"%s\""),
+					    _x_ ("loaded game_struct \"%s\""),
 					    repr);
 				LW6SYS_FREE (repr);
 			      }
@@ -112,7 +112,7 @@ test_manager ()
 			    if (repr)
 			      {
 				lw6sys_log (LW6SYS_LOG_NOTICE,
-					    _("loaded game_state \"%s\""),
+					    _x_ ("loaded game_state \"%s\""),
 					    repr);
 				LW6SYS_FREE (repr);
 			      }
@@ -129,7 +129,7 @@ test_manager ()
 			    if (repr)
 			      {
 				lw6sys_log (LW6SYS_LOG_NOTICE,
-					    _("loaded map \"%s\""), repr);
+					    _x_ ("loaded map \"%s\""), repr);
 				LW6SYS_FREE (repr);
 			      }
 			    lw6map_free (level);
